<?php
/**
 * @copyright      Copyright (C) 2009-2020 ACYBA SAS - All rights reserved.
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingDPCalendar extends JPlugin
{
    var $searchFields = ['a.id', 'a.catid', 'a.title', 'a.start_date', 'a.end_date', 'a.alias'];
    var $selectedFields = ['a.*'];

    function __construct(&$subject, $config)
    {
        parent::__construct($subject, $config);
        $this->subject = $subject;
        if (!isset($this->params)) {
            $plugin = JPluginHelper::getPlugin('acymailing', 'dpcalendar');
            $this->params = new acyParameter($plugin->params);
        }

        //check if the component is installed
        $this->component_installed = file_exists(JPATH_SITE.DS.'components'.DS.'com_dpcalendar');
    }

    function acymailing_getPluginType()
    {
        if (!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;
        $onePlugin = new stdClass();
        $onePlugin->name = 'DPCalendar';
        $onePlugin->function = 'acymailingDPCalendar_show';
        $onePlugin->help = 'plugin-dpcalendar';

        return $onePlugin;
    }

    function acymailingDPCalendar_show()
    {
        $config = acymailing_config();
        if (version_compare($config->get('version'), '5.9.6', '<')) {
            acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');

            return;
        }

        $pageInfo = new stdClass();
        $pageInfo->filter = new stdClass();
        $pageInfo->filter->order = new stdClass();
        $pageInfo->limit = new stdClass();
        $pageInfo->elements = new stdClass();

        $paramBase = ACYMAILING_COMPONENT.'.dpcalendar';
        $pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'a.id', 'cmd');
        $pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'desc', 'word');
        if (strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
        $pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
        $pageInfo->search = strtolower(trim($pageInfo->search));
        $pageInfo->lang = acymailing_getUserVar($paramBase.".lang", 'lang', '', 'string');
        $pageInfo->langauto = acymailing_getUserVar($paramBase.".langauto", 'langauto', '', 'string');
        $pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
        $pageInfo->readmoreauto = acymailing_getUserVar($paramBase.".readmoreauto", 'readmoreauto', '1', 'string');
        $pageInfo->clickable = acymailing_getUserVar($paramBase.".clickable", 'clickable', '1', 'string');
        $pageInfo->clickableauto = acymailing_getUserVar($paramBase.".clickableauto", 'clickableauto', '1', 'string');
        $pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');
        $pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', '150', 'string');
        $pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', '150', 'string');

        $pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
        $pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');

        if (!empty($pageInfo->search)) {
            $searchVal = '\'%'.acymailing_getEscaped($pageInfo->search).'%\'';
            $filters[] = implode(" LIKE $searchVal OR ", $this->searchFields)." LIKE $searchVal";
        }

        //we hide past events but we remove one day just to make sure we won't hide something we should not!
        if ($this->params->get('hidepastevents', 'yes') == 'yes') {
            $filters[] = 'a.`end_date` >= '.acymailing_escapeDB(date('Y-m-d', time() - 86400));
        }

        $whereQuery = '';
        if (!empty($filters)) {
            $whereQuery = ' WHERE ('.implode(') AND (', $filters).')';
        }

        $query = 'SELECT SQL_CALC_FOUND_ROWS '.implode(',', $this->selectedFields).' FROM `#__dpcalendar_events` as a';
        if (!empty($whereQuery)) $query .= $whereQuery;
        if (!empty($pageInfo->filter->order->value)) {
            $query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;
        }

        $rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

        if (!empty($pageInfo->search)) {
            $rows = acymailing_search($pageInfo->search, $rows);
        }

        $pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
        $pageInfo->elements->page = count($rows);

        $pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

        $picts = [];
        $picts[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
        $pictureHelper = acymailing_get('helper.acypict');
        if ($pictureHelper->available()) {
            $picts[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
            $pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', 'resized', 'string');
            $pageInfo->pictauto = acymailing_getUserVar($paramBase.".pictauto", 'pictauto', 'resized', 'string');
        } else {
            $pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
            $pageInfo->pictauto = acymailing_getUserVar($paramBase.".pictauto", 'pictauto', '1', 'string');
        }
        $picts[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

        // Load language file

        acymailing_loadLanguageFile('com_dpcalendar', JPATH_ADMINISTRATOR.'/components/com_dpcalendar');

        $attributes = [];

        $attributes["title"] = acymailing_translation('FIELD_TITLE');
        $attributes["description"] = acymailing_translation('ACY_DESCRIPTION');
        $attributes["location"] = acymailing_translation('COM_DPCALENDAR_LOCATION');
        $attributes["date"] = acymailing_translation('FIELD_DATE');
        $attributes["url"] = acymailing_translation('URL');

        $choice = [];
        $choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
        $choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

        $column = [];
        for ($i = 1 ; $i < 11 ; $i++) {
            $column[] = acymailing_selectOption("$i", $i);
        }

        $tabs = acymailing_get('helper.acytabs');
        echo $tabs->startPane('jevents_tab');
        echo $tabs->startPanel(acymailing_translation('JOOMEXT_EVENT'), 'jevents_event');

        ?>
		<script language="javascript" type="text/javascript">
            <!--
            var selectedContents = new Array();

            function applyEvent(eventid, rowClass) {
                var tmp = selectedContents.indexOf(eventid);
                if (tmp != -1) {
                    window.document.getElementById('content' + eventid).className = rowClass;
                    delete selectedContents[tmp];
                } else {
                    window.document.getElementById('content' + eventid).className = 'selectedrow';
                    selectedContents.push(eventid);
                }

                updateEventTag();
            }

            function updateEventTag() {
                var tag = '';
                var otherinfo = '';
                var tmp = 0;
                var i = 0;

                for (i = 0 ; i < document.adminForm.contenttype.length ; i++) {
                    if (document.adminForm.contenttype[i].checked) {
                        if (tmp == 0) {
                            tmp += 1;
                            otherinfo += '| display:';
                            otherinfo += document.adminForm.contenttype[i].value;
                        } else {
                            otherinfo += ', ';
                            otherinfo += document.adminForm.contenttype[i].value;
                        }
                    }
                }

                otherinfo += '| v2';

                for (i = 0 ; i < document.adminForm.pict.length ; i++) {
                    if (!document.adminForm.pict[i].checked) continue;
                    otherinfo += '| pict:' + document.adminForm.pict[i].value;

                    if (document.adminForm.pict[i].value == 'resized') {
                        document.getElementById('pictsize').style.display = '';
                        if (document.adminForm.pictwidth.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidth.value;
                        if (document.adminForm.pictheight.value) otherinfo += '| maxheight:' + document.adminForm.pictheight.value;
                    } else {
                        document.getElementById('pictsize').style.display = 'none';
                    }
                }

                for (var i = 0 ; i < document.adminForm.clickable.length ; i++) {
                    if (document.adminForm.clickable[i].checked && document.adminForm.clickable[i].value == '0') {
                        otherinfo += '| nolink';
                    }
                }

                if (document.adminForm.wrap.value && document.adminForm.wrap.value != 0 && !isNaN(document.adminForm.wrap.value)) {
                    otherinfo += '| wrap:' + document.adminForm.wrap.value;
                }

                for (var i = 0 ; i < document.adminForm.readmore.length ; i++) {
                    if (document.adminForm.readmore[i].checked && document.adminForm.readmore[i].value == '0') {
                        otherinfo += '| noreadmore';
                    }
                }

                if (window.document.getElementById('jflang') && window.document.getElementById('jflang').value != '') {
                    otherinfo += '| lang:';
                    otherinfo += window.document.getElementById('jflang').value;
                }

                for (var i in selectedContents) {
                    if (selectedContents[i] && !isNaN(i)) {
                        tag = tag + '{DPCalendarevent:' + selectedContents[i] + otherinfo + '}<br />';
                    }
                }
                setTag(tag);
            }

            //-->
		</script>
		<br style="font-size:1px" />
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
                    <?php
                    $i = 1;
                    foreach ($attributes as $id => $title) {
                        if ($i == 4) {
                            $i = 1;
                            echo '</tr><tr><td/>';
                        }
                        echo '<td><input '.(($id != 'url') ? 'checked="checked"' : '').' value="'.$id.'" name="contenttype" id="attr_'.$id.'" type="checkbox" onclick="updateEventTag();" />';
                        echo ' <label for="attr_'.$id.'">'.$title.'</label></td>';
                        $i++;
                    }

                    while ($i != 4) {
                        $i++;
                        echo '<td/>';
                    }
                    ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'clickable', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->clickable); ?></td>

					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->readmore); ?>
				</tr>
				<tr>
					<td><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td>
                        <?php echo acymailing_radio($picts, 'pict', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->pict); ?>
						<span id="pictsize" <?php if ($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?> ><br />
							<label for="pictwidth"><?php echo acymailing_translation('CAPTCHA_WIDTH') ?></label>
							<input id="pictwidth" name="pictwidth" type="text" onchange="updateEventTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;" />
							x <label for="pictheight"><?php echo acymailing_translation('CAPTCHA_HEIGHT') ?></label>
							<input id="pictheight" name="pictheight" type="text" onchange="updateEventTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;" />
						</span>
					</td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateEventTag();"/>'); ?></td>
				</tr>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table_options">
				<tr>
					<td width="100%">
						<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();" />
						<button class="acymailing_button" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
						<button class="acymailing_button" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
					</td>
					<td nowrap="nowrap">

					</td>
				</tr>
			</table>

			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
					<tr>
						<th class="title"></th>
						<th class="title">
                            <?php echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'a.title', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
						</th>
						<th class="title">
                            <?php echo acymailing_gridSort(acymailing_translation('ACY_DESCRIPTION'), 'a.description', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
						</th>
						<th class="title">
                            <?php
                            echo acymailing_gridSort(acymailing_translation('FIELD_DATE'), 'a.start_date', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
                            ?>
						</th>
						<th class="title titleid">
                            <?php echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'a.id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
						</th>
					</tr>
				</thead>
				<tfoot>
					<tr>
						<td colspan="5">
                            <?php echo $pagination->getListFooter(); ?>
                            <?php echo $pagination->getResultsCounter(); ?>
						</td>
					</tr>
				</tfoot>
				<tbody>
                    <?php
                    $k = 0;

                    for ($i = 0, $a = count($rows) ; $i < $a ; $i++) {
                        $row =& $rows[$i];

                        $description = substr(strip_tags($row->description), 0, 100);
                        $description .= '...';
                        ?>
						<tr id="content<?php echo $row->id; ?>" class="<?php echo "row$k"; ?>" onclick="applyEvent(<?php echo $row->id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
							<td class="acytdcheckbox"></td>
							<td>
                                <?php echo $row->title; ?>
							</td>
							<td>
                                <?php echo acymailing_absoluteURL($description); ?>
							</td>
							<td align="center" style="text-align:center">
                                <?php echo acymailing_getDate(acymailing_getTime($row->start_date), acymailing_translation('DATE_FORMAT_LC')); ?>
							</td>
							<td align="center" style="text-align:center">
                                <?php echo $row->id; ?>
							</td>
						</tr>
                        <?php
                        $k = 1 - $k;
                    }
                    ?>
				</tbody>
			</table>
		</div>
		<input type="hidden" name="boxchecked" value="0" />
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>" />
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>" />
        <?php
        echo $tabs->endPanel();
        echo $tabs->startPanel(acymailing_translation('UPCOMING_EVENTS'), 'dpcalendar_auto');
        $type = acymailing_getVar('string', 'type');

        ?>
		<br style="font-size:1px" />
		<script language="javascript" type="text/javascript">
            <!--
            var selectedCat = new Array();

            function applyAutoEvent(catid, rowClass) {
                if (catid == 'all') {
                    if (window.document.getElementById('event_cat' + catid).className == 'selectedrow') {
                        window.document.getElementById('event_catall').className = rowClass;
                    } else {
                        window.document.getElementById('event_cat' + catid).className = 'selectedrow';
                        for (key in selectedCat) {
                            if (!isNaN(key)) {
                                window.document.getElementById('event_cat' + key).className = rowClass;
                                delete selectedCat[key];
                            }
                        }
                    }
                } else {
                    window.document.getElementById('event_catall').className = 'row0';
                    if (selectedCat[catid]) {
                        window.document.getElementById('event_cat' + catid).className = rowClass;
                        delete selectedCat[catid];
                    } else {
                        window.document.getElementById('event_cat' + catid).className = 'selectedrow';
                        selectedCat[catid] = 'event';
                    }
                }

                updateTag();
            }

            function updateTag() {
                var tmp = 0;
                tag = '{autoDPCalendar:';
                for (var icat in selectedCat) {
                    if (selectedCat[icat] == 'event') {
                        tag += icat + '-';
                    }
                }

                for (var i = 0 ; i < document.adminForm.contenttypeauto.length ; i++) {
                    if (document.adminForm.contenttypeauto[i].checked) {
                        if (tmp == 0) {
                            tmp += 1;
                            tag += '| display:';
                            tag += document.adminForm.contenttypeauto[i].value;
                        } else {
                            tag += ', ';
                            tag += document.adminForm.contenttypeauto[i].value;
                        }
                    }
                }

                tag += '| v2';

                for (var i = 0 ; i < document.adminForm.clickableauto.length ; i++) {
                    if (document.adminForm.clickableauto[i].checked && document.adminForm.clickableauto[i].value == '0') {
                        tag += '| nolink';
                    }
                }

                if (document.adminForm.wrapauto.value && document.adminForm.wrapauto.value != 0 && !isNaN(document.adminForm.wrapauto.value)) {
                    tag += '| wrap:' + document.adminForm.wrapauto.value;
                }

                for (var i = 0 ; i < document.adminForm.readmoreauto.length ; i++) {
                    if (document.adminForm.readmoreauto[i].checked && document.adminForm.readmoreauto[i].value == '0') {
                        tag += '| noreadmore';
                    }
                }

                for (var i = 0 ; i < document.adminForm.pictauto.length ; i++) {
                    if (!document.adminForm.pictauto[i].checked) continue;
                    tag += '| pict:' + document.adminForm.pictauto[i].value;

                    if (document.adminForm.pictauto[i].value == 'resized') {
                        document.getElementById('pictsizeauto').style.display = '';
                        if (document.adminForm.pictwidthauto.value) tag += '| maxwidth:' + document.adminForm.pictwidthauto.value;
                        if (document.adminForm.pictheightauto.value) tag += '| maxheight:' + document.adminForm.pictheightauto.value;
                    } else {
                        document.getElementById('pictsizeauto').style.display = 'none';
                    }
                }

                if (window.document.getElementById('jflangauto') && window.document.getElementById('jflangauto').value != '') {
                    tag += '| lang:';
                    tag += window.document.getElementById('jflangauto').value;
                }

                if (document.adminForm.min_article && document.adminForm.min_article.value && document.adminForm.min_article.value != 0) {
                    tag += '| min:' + document.adminForm.min_article.value;
                }
                if (document.adminForm.max_article.value && document.adminForm.max_article.value != 0) {
                    tag += '| max:' + document.adminForm.max_article.value;
                }
                if (document.adminForm.delayevent && document.adminForm.delayevent.value && document.adminForm.delayevent.value > 0) {
                    tag += '| delay:' + document.adminForm.delayevent.value;
                }
                if (document.adminForm.from_date && document.adminForm.from_date.value) {
                    tag += '| from:' + document.adminForm.from_date.value;
                }
                if (document.adminForm.to_date && document.adminForm.to_date.value) {
                    tag += '| to:' + document.adminForm.to_date.value;
                }
                if (document.adminForm.cols.value) {
                    tag += '| cols:' + document.adminForm.cols.value;
                }

                tag += '}';

                setTag(tag);
            }

            //-->
		</script>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
                    <?php
                    $i = 1;
                    foreach ($attributes as $id => $title) {
                        if ($i % 4 == 0) {
                            $i++;
                            echo '</tr><tr><td/>';
                        }

                        if ($i == 3) {
                            $jflanguages = acymailing_get('type.jflanguages');
                            $jflanguages->onclick = 'onchange="updateTag();"';
                            $jflanguages->id = 'jflangauto';
                            $jfDisplay = $jflanguages->display('langauto', $pageInfo->langauto);
                            if (!empty($jfDisplay)) {
                                echo '<td>'.$jfDisplay.'</td></tr><tr><td/>';
                                $i += 2;
                            }
                        }
                        echo '<td><input '.(($id != 'url') ? 'checked="checked"' : '').' value="'.$id.'" name="contenttypeauto" id="autoattr_'.$id.'" type="checkbox" onclick="updateTag();" />';
                        echo ' <label for="autoattr_'.$id.'">'.$title.'</label></td>';
                        $i++;
                    }
                    while ($i % 4 != 0) {
                        $i++;
                        echo '<td/>';
                    }
                    ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'clickableauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmoreauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->readmoreauto); ?>
				</tr>
				<tr>
					<td><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td>
                        <?php echo acymailing_radio($picts, 'pictauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pictauto); ?>
						<span id="pictsizeauto" <?php if ($pageInfo->pictauto != 'resized') echo 'style="display:none;"'; ?> ><br />
							<label for="pictwidthauto"><?php echo acymailing_translation('CAPTCHA_WIDTH') ?></label>
							<input id="pictwidthauto" name="pictwidthauto" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;" />
							x <label for="pictheightauto"><?php echo acymailing_translation('CAPTCHA_HEIGHT') ?></label>
							<input id="pictheightauto" name="pictheightauto" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;" />
						</span>
					</td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrapauto" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
				</tr>
				<tr>
					<td>
                        <?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td>
						<input type="text" name="max_article" style="width:50px" value="20" onchange="updateTag();" />
					</td>
					<td>
                        <?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap">
                        <?php echo acymailing_select($column, 'cols', 'size="1" onchange="updateTag();" style="width:100px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
                <?php if ($type == 'autonews') { ?>
					<tr>
						<td>
                            <?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td>
						<td>
							<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTag();" />
						</td>
						<td>
                            <?php echo acymailing_translation('MAX_STARTING_DATE'); ?>
						</td>
						<td>
                            <?php $delayType = acymailing_get('type.delay');
                            $delayType->onChange = "updateTag();";
                            echo $delayType->display('delayevent', 7776000, 3); ?>
						</td>
					</tr>
                <?php } else { ?>
					<tr>
						<td>
                            <?php echo acymailing_translation('ACY_FROM_DATE'); ?>
						</td>
						<td>
                            <?php echo acymailing_calendar('', 'from_date', 'from_date', '%Y-%m-%d', ['style' => 'width:80px', 'onchange' => 'updateTag();']); ?>
						</td>
						<td>
                            <?php echo acymailing_translation('ACY_TO_DATE'); ?>
						</td>
						<td>
                            <?php echo acymailing_calendar('', 'to_date', 'to_date', '%Y-%m-%d', ['style' => 'width:80px', 'onchange' => 'updateTag();']); ?>
						</td>
					</tr>
                <?php } ?>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table" cellpadding="1" width="100%">
                <?php $k = 0; ?>
				<tr id="event_catall" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td>
                        <?php
                        echo acymailing_translation('ACY_ALL');
                        ?>
					</td>
				</tr>
                <?php

                $categories = acymailing_loadObjectList('SELECT * FROM `#__categories` WHERE extension = "com_dpcalendar" AND published IN (0, 1) ORDER BY `lft` ASC', 'id');

                foreach ($categories as $oneCat) { ?>
					<tr id="event_cat<?php echo $oneCat->id ?>" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent(<?php echo $oneCat->id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
                            <?php
                            if (!empty($oneCat->parent_id) && !empty($categories[$oneCat->parent_id])) {
                                $categories[$oneCat->id]->title = $categories[$oneCat->parent_id]->title.' => '.$categories[$oneCat->id]->title;
                            }
                            echo $oneCat->title;
                            ?>
						</td>
					</tr>
                    <?php
                    $k = 1 - $k;
                }
                ?>
			</table>
		</div>
        <?php
        echo $tabs->endPanel();
        if (in_array(acymailing_getPrefix().'dpcalendar_locations', acymailing_getTableList())) {
            acymailing_loadLanguageFile('plg_dpcalendar_dpcalendar_google', JPATH_SITE.DS.'plugins'.DS.'dpcalendar'.DS.'dpcalendar_google');
            echo $tabs->startPanel(acymailing_translation('PLG_DPCALENDAR_GOOGLE'), 'dpcalendar_ext_auto');
            $type = acymailing_getVar('string', 'type');

            ?>
			<br style="font-size:1px" />
			<script language="javascript" type="text/javascript">
                <!--
                var selectedCatExt = new Array();

                function applyAutoExtEvent(catid, rowClass) {
                    if (catid == 'all') {
                        if (window.document.getElementById('ext_event_cat' + catid).className == 'selectedrow') {
                            window.document.getElementById('ext_event_catall').className = rowClass;
                        } else {
                            window.document.getElementById('ext_event_cat' + catid).className = 'selectedrow';
                            for (key in selectedCatExt) {
                                if (!isNaN(key)) {
                                    window.document.getElementById('ext_event_cat' + key).className = rowClass;
                                    delete selectedCatExt[key];
                                }
                            }
                        }
                    } else {
                        window.document.getElementById('ext_event_catall').className = 'row0';
                        if (selectedCatExt[catid]) {
                            window.document.getElementById('ext_event_cat' + catid).className = rowClass;
                            delete selectedCatExt[catid];
                        } else {
                            window.document.getElementById('ext_event_cat' + catid).className = 'selectedrow';
                            selectedCatExt[catid] = 'event';
                        }
                    }

                    updateExtTag();
                }

                function updateExtTag() {
                    var tmp = 0;
                    tag = '{autoExtDPCalendar:';
                    for (var icat in selectedCatExt) {
                        if (selectedCatExt[icat] == 'event') {
                            tag += icat + '-';
                        }
                    }

                    for (var i = 0 ; i < document.adminForm.contenttypeautoext.length ; i++) {
                        if (document.adminForm.contenttypeautoext[i].checked) {
                            if (tmp == 0) {
                                tmp += 1;
                                tag += '| display:';
                                tag += document.adminForm.contenttypeautoext[i].value;
                            } else {
                                tag += ', ';
                                tag += document.adminForm.contenttypeautoext[i].value;
                            }
                        }
                    }

                    for (var i = 0 ; i < document.adminForm.clickableautoext.length ; i++) {
                        if (document.adminForm.clickableautoext[i].checked && document.adminForm.clickableautoext[i].value == '0') {
                            tag += '| nolink';
                        }
                    }

                    if (document.adminForm.wrapautoext.value && document.adminForm.wrapautoext.value != 0 && !isNaN(document.adminForm.wrapautoext.value)) {
                        tag += '| wrap:' + document.adminForm.wrapautoext.value;
                    }

                    for (var i = 0 ; i < document.adminForm.readmoreautoext.length ; i++) {
                        if (document.adminForm.readmoreautoext[i].checked && document.adminForm.readmoreautoext[i].value == '0') {
                            tag += '| noreadmore';
                        }
                    }

                    if (document.adminForm.min_articleext && document.adminForm.min_articleext.value && document.adminForm.min_articleext.value != 0) {
                        tag += '| min:' + document.adminForm.min_articleext.value;
                    }
                    if (document.adminForm.max_articleext.value && document.adminForm.max_articleext.value != 0) {
                        tag += '| max:' + document.adminForm.max_articleext.value;
                    }
                    if (document.adminForm.delayeventext && document.adminForm.delayeventext.value && document.adminForm.delayeventext.value > 0) {
                        tag += '| delay:' + document.adminForm.delayeventext.value;
                    }
                    if (document.adminForm.from_dateext && document.adminForm.from_dateext.value) {
                        tag += '| from:' + document.adminForm.from_dateext.value;
                    }
                    if (document.adminForm.to_dateext && document.adminForm.to_dateext.value) {
                        tag += '| to:' + document.adminForm.to_dateext.value;
                    }
                    if (document.adminForm.colsext.value) {
                        tag += '| cols:' + document.adminForm.colsext.value;
                    }

                    tag += '}';

                    setTag(tag);
                }

                //-->
			</script>
			<table width="100%" class="adminform">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
                    <?php
                    $i = 1;
                    foreach ($attributes as $id => $title) {
                        if ($i % 4 == 0) {
                            $i++;
                            echo '</tr><tr><td/>';
                        }
                        echo '<td><input '.(($id != 'url') ? 'checked="checked"' : '').' value="'.$id.'" name="contenttypeautoext" id="autoattrext_'.$id.'" type="checkbox" onclick="updateExtTag();" />';
                        echo ' <label for="autoattrext_'.$id.'">'.$title.'</label></td>';
                        $i++;
                    }
                    while ($i % 4 != 0) {
                        $i++;
                        echo '<td/>';
                    }
                    ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'clickableautoext', 'size="1" onclick="updateExtTag();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmoreautoext', 'size="1" onclick="updateExtTag();"', 'value', 'text', $pageInfo->readmoreauto); ?>
				</tr>
				<tr>
					<td nowrap="nowrap" colspan="4"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrapautoext" style="width:50px" value="0" onchange="updateExtTag();"/>'); ?></td>
				</tr>
				<tr>
					<td>
                        <?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td>
						<input type="text" name="max_articleext" style="width:50px" value="20" onchange="updateExtTag();" />
					</td>
					<td>
                        <?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap">
                        <?php echo acymailing_select($column, 'colsext', 'size="1" onchange="updateExtTag();" style="width:100px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
                <?php if ($type == 'autonews') { ?>
					<tr>
						<td>
                            <?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td>
						<td>
							<input type="text" name="min_articleext" style="width:50px" value="1" onchange="updateExtTag();" />
						</td>
						<td>
                            <?php echo acymailing_translation('MAX_STARTING_DATE'); ?>
						</td>
						<td>
                            <?php $delayType = acymailing_get('type.delay');
                            $delayType->onChange = "updateExtTag();";
                            echo $delayType->display('delayeventext', 7776000, 3); ?>
						</td>
					</tr>
                <?php } else { ?>
					<tr>
						<td>
                            <?php echo acymailing_translation('ACY_FROM_DATE'); ?>
						</td>
						<td>
                            <?php echo acymailing_calendar('', 'from_dateext', 'from_dateext', '%Y-%m-%d', ['style' => 'width:80px', 'onchange' => 'updateExtTag();']); ?>
						</td>
						<td>
                            <?php echo acymailing_translation('ACY_TO_DATE'); ?>
						</td>
						<td>
                            <?php echo acymailing_calendar('', 'to_dateext', 'to_dateext', '%Y-%m-%d', ['style' => 'width:80px', 'onchange' => 'updateExtTag();']); ?>
						</td>
					</tr>
                <?php } ?>
			</table>
			<table class="adminlist table table-striped table-hover" cellpadding="1" width="100%">
                <?php $k = 0; ?>
				<tr id="ext_event_catall" class="<?php echo "row$k"; ?>" onclick="applyAutoExtEvent('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td>
                        <?php
                        echo acymailing_translation('ACY_ALL');
                        ?>
					</td>
				</tr>
                <?php

                $extcategories = acymailing_loadObjectList('SELECT id, title FROM `#__dpcalendar_extcalendars` WHERE plugin = "google" AND state = 1 ORDER BY `ordering` ASC', 'id');

                foreach ($extcategories as $oneCat) { ?>
					<tr id="ext_event_cat<?php echo $oneCat->id ?>" class="<?php echo "row$k"; ?>" onclick="applyAutoExtEvent('<?php echo $oneCat->id ?>','<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
                            <?php echo $oneCat->title; ?>
						</td>
					</tr>
                    <?php
                    $k = 1 - $k;
                }
                ?>
			</table>
            <?php
            echo $tabs->endPanel();
        }
        echo $tabs->endPane();
    }

    function acymailing_replacetags(&$email, $send = true)
    {
        $this->_replaceAuto($email);
        $this->_replaceEvents($email);
    }

    function _replaceEvents(&$email)
    {
        $acypluginsHelper = acymailing_get('helper.acyplugins');

        //load the tags
        $tags = $acypluginsHelper->extractTags($email, 'DPCalendarevent');
        if (empty($tags)) return;

        //We will need the mailer class as well
        $this->mailerHelper = acymailing_get('helper.mailer');

        $htmlreplace = [];
        $textreplace = [];
        $subjectreplace = [];
        foreach ($tags as $i => $params) {
            if (isset($htmlreplace[$i])) continue;
            $content = $this->_replaceEvent($tags[$i]);
            $htmlreplace[$i] = $content;
            $textreplace[$i] = $this->mailerHelper->textVersion($content, true);
            $subjectreplace[$i] = strip_tags($content);
        }
        $email->body = str_replace(array_keys($htmlreplace), $htmlreplace, $email->body);
        $email->altbody = str_replace(array_keys($textreplace), $textreplace, $email->altbody);
        $email->subject = str_replace(array_keys($subjectreplace), $subjectreplace, $email->subject);
    }

    private function _replaceEvent(&$tag)
    {
        $acypluginsHelper = acymailing_get('helper.acyplugins');

        // extract the fields selected
        if (!empty($tag->display)) {
            $tag->display = explode(',', $tag->display);

            foreach ($tag->display as $i => $oneDisplay) {
                $tag->display[$i] = trim($oneDisplay);
            }
        }

        if (empty($tag->itemid)) $tag->itemid = $this->params->get('itemid');

        //1 : Load the informations of the product...
        $query = 'SELECT a.description as descriptionEvent, b.title as category_title, b.id as category_id, b.alias as category_alias,a.* FROM `#__dpcalendar_events` as a ';
        $query .= 'JOIN `#__categories` AS b ON a.catid = b.id ';
        $query .= 'WHERE a.id = '.intval($tag->id).' LIMIT 1';
        $event = acymailing_loadObject($query);


        if (empty($event)) {
            if (acymailing_isAdmin()) acymailing_enqueueMessage('The event "'.$tag->id.'" could not be loaded', 'notice');

            return '';
        }


        $link = 'index.php?option=com_dpcalendar&view=event&id='.$tag->id;
        if (!empty($tag->itemid)) $link .= '&Itemid='.$tag->itemid;
        $link = acymailing_frontendLink($link);
        if (!empty($tag->autologin)) $link .= (strpos($link, '?') ? '&' : '?').'user={usertag:username|urlencode}&passw={usertag:password|urlencode}';

        $varFields = [];
        $varFields['{link}'] = $link;

        foreach ($event as $oneField => $value) {
            $varFields['{'.$oneField.'}'] = $value;
        }
        $result = '';
        $addbr = true;

        if (!empty($event->title) && (in_array('title', $tag->display) || empty($tag->v2))) {
            if (empty($tag->nolink)) $result .= '<a style="text-decoration:none;" name="event-'.$event->id.'" target="_blank" href="'.$link.'">';
            $result .= '<h2 class="acymailing_title">'.$event->title.'</h2>';
            $addbr = false;
            if (empty($tag->nolink)) $result .= '</a>';
        }

        $readMoreText = empty($tag->readmore) ? $this->readmore : $tag->readmore;

        if (!empty($tag->display)) {

            //If there is a description and the user wants to display it, we search if there is a wrap param
            if ((!empty($tag->pict) && !empty($event->images)) || (in_array('description', $tag->display) && !empty($event->descriptionEvent))) {
                $result .= '<div class="eventdescription">';
                if (!empty($tag->pict) && !empty($event->images)) {
                    $images = json_decode($event->images);
                    if (!empty($images->image1)) {
                        $varFields['{imagePath}'] = $images->image1;
                        $varFields['{imageHTML}'] = '<img '.(empty($tag->nostyle) ? 'style="float:left;" ' : '').'src="'.$images->image1.'" alt="'.$images->image1.'" />';
                        $result .= $varFields['{imageHTML}'];
                    }
                }

                if (in_array('description', $tag->display) && !empty($event->descriptionEvent)) {
                    //If wordwrap parameter, "cut" the description...
                    if (empty($tag->wrap)) $tag->wrap = $this->params->get('wordwrap', 0);
                    $varFields['{wrappeddesc}'] = $acypluginsHelper->wrapText($event->descriptionEvent, $tag);
                    $result .= $varFields['{wrappeddesc}'];
                    if (!empty($tag->wrap) && empty($tag->v2)) {
                        $readMoreText = empty($tag->readmore) ? $this->readmore : $tag->readmore;
                        $result .= '<a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$readMoreText.'</span></a>';
                    }
                }

                $result .= '</div>';
            }

            foreach ($tag->display as $oneTag => $oneDetails) {
                //We display the Start and the End dates ..
                if ($oneDetails == 'date' && !empty($event->start_date) && !empty($event->end_date)) {
                    $dateFormat = empty($event->all_day) ? $this->params->get('datetimeformat', 'g:i a d.m.Y') : $this->params->get('dateformat', 'd.m.Y');

                    if (ACYMAILING_J16) {
                        $dateObj = JFactory::getDate($event->start_date, null);
                        $timezone = JFactory::getApplication()->getCfg('offset');
                        $dateObj->setTimezone(new DateTimeZone($timezone));
                        if ($event->start_date != $event->end_date && empty($tag->onlystartdate) && date('Y-m-d 00:00:00', strtotime($event->end_date)) == date('Y-m-d 00:00:00', strtotime($event->start_date))) {
                            $start_date = $dateObj->format($this->params->get('timeformat', 'g:i a'), true);
                        } else {
                            $start_date = $dateObj->format($dateFormat, true);
                        }

                        $dateObj = JFactory::getDate($event->end_date, null);
                        $dateObj->setTimezone(new DateTimeZone($timezone));
                        $end_date = $dateObj->format($dateFormat, true);
                    } else {
                        $end_date = acymailing_date($event->end_date, $dateFormat, null);
                        if ($event->start_date != $event->end_date && empty($tag->onlystartdate) && date('Y-m-d 00:00:00', strtotime($event->end_date)) == date('Y-m-d 00:00:00', strtotime($event->start_date))) {
                            $start_date = acymailing_date($event->start_date, $this->params->get('timeformat', 'g:i a'), null);
                        } else {
                            $start_date = acymailing_date($event->start_date, $dateFormat, null);
                        }
                    }

                    if ($addbr) {
                        $result .= '<br />';
                    } else {
                        //for the next one...
                        $addbr = true;
                    }

                    $varFields['{startdate}'] = $start_date;
                    $varFields['{enddate}'] = $end_date;

                    $dateDisplay = '<span style="font-weight: bold;">'.acymailing_translation('FIELD_DATE').'</span> : '.$start_date;
                    if ($event->start_date != $event->end_date) {
                        $dateDisplay = '<span class="eventdate">'.$dateDisplay.(empty($tag->onlystartdate) ? ' - '.$end_date : '').'</span>';
                    }

                    $result .= $dateDisplay;
                }

                //We display the event's location
                if ($oneDetails == 'location') {
                    if ($addbr) {
                        $result .= '<br />';
                    } else {
                        //for the next one...
                        $addbr = true;
                    }
                    if (!empty($event->location)) {
                        $varFields['{eventlocation}'] = $event->location;
                        $result .= '<span style="font-weight: bold;">'.acymailing_translation('COM_DPCALENDAR_LOCATION').'</span> : '.$event->location;
                    } elseif (in_array(acymailing_getPrefix().'dpcalendar_locations', acymailing_getTableList())) {
                        $locations = acymailing_loadObjectList('SELECT l.* FROM #__dpcalendar_locations AS l JOIN #__dpcalendar_events_location AS el ON l.id = el.location_id WHERE el.event_id = '.intval($tag->id));
                        if (empty($locations)) continue;

                        $result .= '<span style="font-weight: bold;">'.acymailing_translation('COM_DPCALENDAR_LOCATION').'</span> : ';
                        $locationListing = [];
                        foreach ($locations as $oneLocation) {
                            $googleMapsSearch = [];
                            if (!empty($oneLocation->number)) $googleMapsSearch[] = $oneLocation->number;
                            if (!empty($oneLocation->street)) $googleMapsSearch[] = $oneLocation->street;
                            if (!empty($oneLocation->zip)) $googleMapsSearch[] = $oneLocation->zip;
                            if (!empty($oneLocation->city)) $googleMapsSearch[] = $oneLocation->city;
                            if (!empty($oneLocation->country)) $googleMapsSearch[] = $oneLocation->country;
                            if (!empty($googleMapsSearch)) {
                                $locationListing[] = '<a href="http://maps.google.com/?q='.urlencode(implode(' ', $googleMapsSearch)).'">'.$oneLocation->title.'</a>';
                            } else $locationListing[] = '<a href="http://maps.google.com/?q='.urlencode($oneLocation->latitude.','.$oneLocation->longitude).'">'.$oneLocation->title.'</a>';
                        }
                        $varFields['{eventlocation}'] = implode('<br/>', $locationListing);
                        $result .= $varFields['{eventlocation}'];
                    }
                }

                if ($oneDetails == 'url' && !empty($event->url)) {
                    if ($addbr) {
                        $result .= '<br/>';
                    } else {
                        //for the next one...
                        $addbr = true;
                    }
                    $varFields['{urllink}'] = '<a href="'.$event->url.'">'.$event->url.'</a>';
                    $result .= '<span style="font-weight: bold;">'.acymailing_translation('URL').'</span> : '.$varFields['{urllink}'];
                }
            }
        }

        if (!empty($tag->v2) && empty($tag->noreadmore)) {
            $result .= '<br/><a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$readMoreText.'</span></a>';
        }

        $result = '<table cellspacing="0" cellpadding="0" border="0" width="100%"><tr><td><div class="acymailing_content" >'.$result.'</div></td></tr></table>';

        //Check if the template exists...
        if (file_exists(ACYMAILING_MEDIA.'plugins'.DS.'dpcalendar.php')) {
            ob_start();
            require(ACYMAILING_MEDIA.'plugins'.DS.'dpcalendar.php');
            $result = ob_get_clean();
            $result = str_replace(array_keys($varFields), $varFields, $result);
        }

        $result = $acypluginsHelper->removeJS($result);
        //We have our content... lets check the pictures options
        $result = $acypluginsHelper->managePicts($tag, $result);

        return $result;
    }

    private function _replaceAuto(&$email)
    {
        $this->tags = [];

        //Set the read more text or image
        $this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';


        acymailing_loadLanguageFile('com_dpcalendar', JPATH_ADMINISTRATOR.'/components/com_dpcalendar');

        $this->acymailing_generateautonews($email);

        if (in_array(acymailing_getPrefix().'dpcalendar_locations', acymailing_getTableList())) $this->acymailing_generateautonewsext($email);

        if (empty($this->tags)) return;

        $email->body = str_replace(array_keys($this->tags), $this->tags, $email->body);
        if (!empty($email->altbody)) $email->altbody = str_replace(array_keys($this->tags), $this->tags, $email->altbody);
        if (!empty($email->subject)) $email->subject = str_replace(array_keys($this->tags), $this->tags, $email->subject);
    }

    function acymailing_generateautonews(&$email)
    {
        $acypluginsHelper = acymailing_get('helper.acyplugins');

        $time = time();

        //load the tags
        $tags = $acypluginsHelper->extractTags($email, 'autoDPCalendar');
        $return = new stdClass();
        $return->status = true;
        $return->message = '';

        if (empty($tags)) return $return;

        foreach ($tags as $oneTag => $parameter) {
            if (isset($this->tags[$oneTag])) continue;
            $allcats = explode('-', $parameter->id);

            if (empty($parameter->order)) {
                $parameter->order = 'a.`start_date` ASC';
            }
            if (empty($parameter->from)) {
                $parameter->from = date('Y-m-d H:i:s', $time);
            }

            // Handle the timezone
            $parameter->from = date('Y-m-d H:i:s', acymailing_getTime($parameter->from) - date('Z'));
            if (!empty($parameter->to)) {
                $parameter->to = date('Y-m-d H:i:s', acymailing_getTime($parameter->to) - date('Z'));
            }


            //Load the articles based on all arguments...
            $selectedArea = [];
            foreach ($allcats as $oneCat) {
                if (empty($oneCat)) continue;
                $selectedArea[] = (int)$oneCat;
            }

            $query = 'SELECT DISTINCT a.`id` FROM `#__dpcalendar_events` as a ';
            $where = [];
            if (!empty($selectedArea)) {
                $where[] = 'a.catid IN ('.implode(',', $selectedArea).')';
            }

            $where[] = 'a.`state` = 1';

            //Only featured or standard events...
            if (!empty($parameter->featured)) $where[] = 'a.featured = 1';
            if (!empty($parameter->nofeatured)) $where[] = 'a.featured = 0';

            //If the event is every day and start before the creation of the newsletter we should select it. So we add the ()
            if (!empty($parameter->mindelay)) {
                $where[] = 'a.`start_date` >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->mindelay - date('Z'))).' OR (a.all_day = 1 AND a.`start_date` >= '.acymailing_escapeDB(date('Y-m-d 00:00:00', $time + $parameter->mindelay - date('Z'))).')';
            } elseif (!empty($parameter->addcurrent)) {
                //not finished and next events
                $where[] = 'a.end_date >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time));
            } else {
                //not started events
                $where[] = 'a.`start_date` >= '.acymailing_escapeDB($parameter->from);
            }


            //As we select all the event which have the function all days enabled we need to delete all the finished event.
            if (!empty($parameter->delay)) $where[] = 'a.`start_date` <= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->delay - date('Z'))).' AND a.end_date >= '.acymailing_escapeDB($parameter->from);
            if (!empty($parameter->to)) $where[] = 'a.`start_date` <= '.acymailing_escapeDB($parameter->to);


            $query .= ' WHERE ('.implode(') AND (', $where).')';
            $query .= ' ORDER BY '.$parameter->order;
            if (!empty($parameter->max)) $query .= ' LIMIT '.(int)$parameter->max;
            $allArticles = acymailing_loadResultArray($query);

            if (!empty($parameter->min) AND count($allArticles) < $parameter->min) {
                //We won't generate the Newsletter
                $return->status = false;
                $return->message = 'Not enough events for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
            }
            $stringTag = '';
            if (!empty($allArticles)) {
                if (file_exists(ACYMAILING_MEDIA.'plugins'.DS.'autodpcalendar.php')) {
                    ob_start();
                    require(ACYMAILING_MEDIA.'plugins'.DS.'autodpcalendar.php');
                    $stringTag = ob_get_clean();
                } else {
                    //we insert the article tag one after the other in a table as they are already sorted
                    $arrayElements = [];
                    $numArticle = 1;
                    foreach ($allArticles as $oneArticleId) {
                        $args = [];
                        $args[] = 'DPCalendarevent:'.$oneArticleId;
                        $args[] = 'num:'.$numArticle++;
                        if (isset($parameter->display)) $args[] = 'display:'.rtrim($parameter->display, ',');
                        if (isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
                        if (!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
                        if (!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
                        if (!empty($parameter->lang)) $args[] = 'lang:'.$parameter->lang;
                        if (!empty($parameter->type)) $args[] = 'type:'.$parameter->type;
                        if (!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
                        if (!empty($parameter->autologin)) $args[] = 'autologin';
                        if (!empty($parameter->nolink)) $args[] = 'nolink';
                        if (!empty($parameter->nostyle)) $args[] = 'nostyle';
                        if (!empty($parameter->noreadmore)) $args[] = 'noreadmore';
                        if (!empty($parameter->onlystartdate)) $args[] = 'onlystartdate';
                        if (!empty($parameter->v2)) $args[] = 'v2';
                        if (!empty($parameter->details)) $args[] = 'details:'.$parameter->details;
                        if (!empty($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
                        $arrayElements[] = '{'.implode('|', $args).'}';
                    }
                    $stringTag = $acypluginsHelper->getFormattedResult($arrayElements, $parameter);
                }
            }
            $this->tags[$oneTag] = $stringTag;
        }

        return $return;
    }

    function acymailing_generateautonewsext(&$email)
    {
        $acypluginsHelper = acymailing_get('helper.acyplugins');

        $time = time();

        //load the tags
        $tags = $acypluginsHelper->extractTags($email, 'autoExtDPCalendar');
        $return = new stdClass();
        $return->status = true;
        $return->message = '';

        if (empty($tags)) return $return;

        require_once(JPATH_SITE.DS.'plugins'.DS.'dpcalendar'.DS.'google'.DS.'google.php');
        $calendarInstance = new PlgDPCalendarGoogle($this->subject);
        $calendarInstance->params = new acyParameter([]);

        $allCalendars = acymailing_loadResultArray('SELECT id FROM #__dpcalendar_extcalendars WHERE state = 1 AND plugin = "google"');
        foreach ($tags as $oneTag => $parameter) {
            if (isset($this->tags[$oneTag])) continue;
            if (empty($parameter->id)) {
                $allcats = $allCalendars;
            } else {
                $allcats = explode('-', $parameter->id);
            }

            if (empty($parameter->from)) {
                $parameter->from = new JDate(date('Y-m-d H:i:s', $time));
            } else $parameter->from = new JDate($parameter->from);
            if (!empty($parameter->mindelay)) {
                $parameter->from = new JDate(date('Y-m-d H:i:s', $time + $parameter->mindelay));
            }

            if (empty($parameter->to)) {
                $parameter->to = null;
            } else $parameter->to = new JDate($parameter->to);
            if (!empty($parameter->delay)) {
                $parameter->to = new JDate(date('Y-m-d H:i:s', $time + $parameter->delay));
            }

            $options = new JRegistry();
            if (!empty($parameter->order)) $options->order = $parameter->order;

            //Load the articles based on all arguments...
            $allArticles = [];
            foreach ($allcats as $oneCat) {
                if (empty($oneCat)) continue;
                $allArticles = array_merge($allArticles, $calendarInstance->fetchEvents((int)$oneCat, $parameter->from, $parameter->to, $options));
            }

            usort($allArticles, [$this, "cmp"]);

            if (!empty($parameter->min) && count($allArticles) < $parameter->min) {
                //We won't generate the Newsletter
                $return->status = false;
                $return->message = 'Not enough events for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
            }
            $stringTag = '';
            if (!empty($allArticles)) {
                //we insert the article tag one after the other in a table as they are already sorted
                $arrayElements = [];
                $numArticle = 0;
                $parameter->max = empty($parameter->max) ? 20 : intval($parameter->max);

                // extract the fields selected
                if (!empty($parameter->display)) {
                    $displays = explode(',', $parameter->display);

                    foreach ($displays as $oneDisplay) {
                        $oneDisplay = trim($oneDisplay);
                        $parameter->$oneDisplay = true;
                    }
                }

                if (empty($parameter->itemid)) $parameter->itemid = $this->params->get('itemid');

                foreach ($allArticles as $event) {
                    if ($numArticle == $parameter->max) break;
                    $numArticle++;

                    $link = 'index.php?option=com_dpcalendar&view=event&id='.$event->id;
                    if (!empty($parameter->itemid)) $link .= '&Itemid='.$parameter->itemid;
                    $link = acymailing_frontendLink($link);
                    if (!empty($parameter->autologin)) $link .= (strpos($link, '?') ? '&' : '?').'user={usertag:username|urlencode}&passw={usertag:password|urlencode}';

                    $varFields = [];
                    $varFields['{link}'] = $link;

                    foreach ($event as $oneField => $value) {
                        $varFields['{'.$oneField.'}'] = $value;
                    }

                    $result = '';

                    if (!empty($event->title) && !empty($parameter->title)) {
                        if (empty($parameter->nolink)) $result .= '<a style="text-decoration:none;" name="event-'.$event->id.'" target="_blank" href="'.$link.'">';
                        $result .= '<h2 class="acymailing_title">'.$event->title.'</h2>';
                        if (empty($parameter->nolink)) $result .= '</a>';
                    }

                    $varFields['{wrapeddescription}'] = '';
                    if (!empty($parameter->description) && !empty($event->description)) {
                        if (empty($parameter->wrap)) $parameter->wrap = $this->params->get('wordwrap', 0);
                        $varFields['{wrapeddescription}'] = $acypluginsHelper->wrapText($event->description, $parameter);
                        $event->descriptionEvent = $varFields['{wrapeddescription}'];
                        $result .= '<div class="eventdescription">'.$varFields['{wrapeddescription}'].'</div>';
                    }
                    $varFields['{descriptionEvent}'] = $varFields['{wrapeddescription}'];

                    $varFields['{dateDisplay}'] = '';
                    $varFields['{startdate}'] = '';
                    $varFields['{enddate}'] = '';
                    if (!empty($parameter->date)) {
                        $dateFormat = empty($event->all_day) ? $this->params->get('datetimeformat', 'g:i a d.m.Y') : $this->params->get('dateformat', 'd.m.Y');

                        if (ACYMAILING_J16) {
                            $dateObj = JFactory::getDate($event->start_date, null);
                            $timezone = JFactory::getApplication()->getCfg('offset');
                            $dateObj->setTimezone(new DateTimeZone($timezone));
                            if ($event->start_date != $event->end_date && empty($parameter->onlystartdate) && date('Y-m-d 00:00:00', strtotime($event->end_date)) == date('Y-m-d 00:00:00', strtotime($event->start_date))) {
                                $start_date = $dateObj->format($this->params->get('timeformat', 'g:i a'), true);
                            } else {
                                $start_date = $dateObj->format($dateFormat, true);
                            }

                            $dateObj = JFactory::getDate($event->end_date, null);
                            $dateObj->setTimezone(new DateTimeZone($timezone));
                            $end_date = $dateObj->format($dateFormat, true);
                        } else {
                            $end_date = acymailing_date($event->end_date, $dateFormat, null);
                            if ($event->start_date != $event->end_date && empty($parameter->onlystartdate) && date('Y-m-d 00:00:00', strtotime($event->end_date)) == date('Y-m-d 00:00:00', strtotime($event->start_date))) {
                                $start_date = acymailing_date($event->start_date, $this->params->get('timeformat', 'g:i a'), null);
                            } else {
                                $start_date = acymailing_date($event->start_date, $dateFormat, null);
                            }
                        }

                        $dateDisplay = '<span style="font-weight: bold;">'.acymailing_translation('FIELD_DATE').'</span> : '.$start_date;
                        if ($event->start_date != $event->end_date) {
                            $dateDisplay = $dateDisplay.(empty($parameter->onlystartdate) ? ' - '.$end_date : '');
                        }

                        $varFields['{dateDisplay}'] = $dateDisplay;
                        $varFields['{startdate}'] = $start_date;
                        $varFields['{enddate}'] = $end_date;
                        $result .= '<div class="eventdate">'.$dateDisplay.'</div>';
                    }

                    $varFields['{urllink}'] = '';
                    if (!empty($parameter->url) && !empty($event->url)) {
                        $varFields['{urllink}'] = '<a href="'.$event->url.'">'.$event->url.'</a>';
                        $result .= '<div class="eventurl"><span style="font-weight: bold;">'.acymailing_translation('URL').'</span> : <a href="'.$event->url.'">'.substr($event->url, 0, 30).'...</a></div>';
                    }

                    $varFields['{locations}'] = '';
                    $varFields['{eventlocation}'] = '';
                    //We display the event's location
                    if (!empty($parameter->location) && count($event->locations) > 0) {
                        $locations = $event->locations;
                        $result .= '<div class="eventlocation"><span style="font-weight: bold;">'.acymailing_translation('COM_DPCALENDAR_FIELD_CONFIG_EVENT_LABEL_LOCATION').'</span> : ';
                        $locationListing = [];
                        foreach ($event->locations as $oneLocation) {
                            $googleMapsSearch = [];
                            if (!empty($oneLocation->number)) $googleMapsSearch[] = $oneLocation->number;
                            if (!empty($oneLocation->street)) $googleMapsSearch[] = $oneLocation->street;
                            if (!empty($oneLocation->zip)) $googleMapsSearch[] = $oneLocation->zip;
                            if (!empty($oneLocation->city)) $googleMapsSearch[] = $oneLocation->city;
                            if (!empty($oneLocation->country)) $googleMapsSearch[] = $oneLocation->country;
                            if (!empty($googleMapsSearch)) {
                                $locationListing[] = '<a href="http://maps.google.com/?q='.urlencode(implode(' ', $googleMapsSearch)).'">'.$oneLocation->title.'</a>';
                            } else $locationListing[] = '<a href="http://maps.google.com/?q='.urlencode($oneLocation->latitude.','.$oneLocation->longitude).'">'.$oneLocation->title.'</a>';
                        }
                        $varFields['{locations}'] = implode('<br/>', $locationListing);
                        $varFields['{eventlocation}'] = implode('<br/>', $locationListing);
                        $result .= $varFields['{locations}'].'</div>';
                    }

                    if (empty($parameter->noreadmore)) {
                        $readMoreText = empty($parameter->readmore) ? $this->readmore : $parameter->readmore;
                        $result .= '<a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$readMoreText.'</span></a>';
                    }

                    $result = '<div class="acymailing_content" >'.$result.'</div>';

                    //Check if the template exists...
                    if (file_exists(ACYMAILING_MEDIA.'plugins'.DS.'dpcalendar.php')) {
                        ob_start();
                        require(ACYMAILING_MEDIA.'plugins'.DS.'dpcalendar.php');
                        $result = ob_get_clean();
                        $result = str_replace(array_keys($varFields), $varFields, $result);
                    }

                    $result = $acypluginsHelper->removeJS($result);

                    $arrayElements[] = $result;
                }
                $stringTag = $acypluginsHelper->getFormattedResult($arrayElements, $parameter);
            }
            $this->tags[$oneTag] = $stringTag;
        }

        return $return;
    }

    function cmp($a, $b)
    {
        return strcmp($a->start_date, $b->start_date);
    }
}
