<?php
/**
 * @copyright    Copyright (C) 2009-2019 ACYBA SAS - All rights reserved.
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingEventbooking extends JPlugin{
	var $searchFields = array('a.title', 'a.id', 'a.event_date', 'a.short_description');
	var $selectedFields = array('a.*');

	public function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', 'eventbooking');
			$this->params = new acyParameter($plugin->params);
		}
		$file = JPATH_SITE.DS.'components'.DS.'com_eventbooking'.DS.'helper'.DS.'helper.php';
		if(file_exists($file) && include_once($file)){
			if(class_exists('EventbookingHelper') && method_exists('EventbookingHelper', 'getInstalledVersion')){
				$this->version = EventbookingHelper::getInstalledVersion();
			}
		}
		$this->component_installed = file_exists(JPATH_SITE.DS.'components'.DS.'com_eventbooking');
	}

	public function acymailing_getPluginType(){
		if(!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;
		$onePlugin = new stdClass();
		$onePlugin->name = 'Event Booking';
		$onePlugin->function = 'acymailingEventbooking_show';
		$onePlugin->help = 'plugin-eventbooking';

		return $onePlugin;
	}

	public function acymailingEventbooking_show(){
		$config = acymailing_config();
		if(version_compare($config->get('version'), '5.9.0', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		// Load language file

		acymailing_loadLanguageFile('com_eventbooking', JPATH_ADMINISTRATOR);
		acymailing_loadLanguageFile('com_eventbooking', JPATH_SITE);

		$pageInfo = new stdClass();
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->limit = new stdClass();
		$pageInfo->elements = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.eventbooking';
		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'a.id', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'desc', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));
		$pageInfo->lang = acymailing_getUserVar($paramBase.".lang", 'lang', '', 'string');
		$pageInfo->contenttype = acymailing_getUserVar($paramBase.".contenttype", 'contenttype', array('title', 'sdesc', 'sdate'), 'array');
		$pageInfo->details = acymailing_getUserVar($paramBase.".details", 'details', '1', 'string');
		$pageInfo->contenttypeauto = acymailing_getUserVar($paramBase.".contenttypeauto", 'contenttypeauto', array('title', 'sdesc', 'sdate'), 'array');

		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');

		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search).'%\'';
			$filters[] = implode(" LIKE $searchVal OR ", $this->searchFields)." LIKE $searchVal";
		}

		//hide past events?
		if($this->params->get('displaypub', 'all') == 'onlypub'){
			$filters[] = 'a.published = 1';
		}

		//we hide past events but we remove one day just to make sure we won't hide something we should not!
		if($this->params->get('hidepastevents', 'yes') == 'yes'){
			$filters[] = 'a.`event_date` >= '.acymailing_escapeDB(date('Y-m-d', time() - 86400));
		}

		$whereQuery = '';
		if(!empty($filters)){
			$whereQuery = ' WHERE ('.implode(') AND (', $filters).')';
		}

		$query = 'SELECT SQL_CALC_FOUND_ROWS '.implode(',', $this->selectedFields).' FROM `#__eb_events` as a';
		if(!empty($whereQuery)) $query .= $whereQuery;
		if(!empty($pageInfo->filter->order->value)){
			$query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;
		}

		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		if(!empty($pageInfo->search)){
			$rows = acymailing_search($pageInfo->search, $rows);
		}

		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$categories = acymailing_loadObjectList('SELECT name, id, parent FROM #__eb_categories', 'id');

		$this->cats = array();
		foreach($categories as $oneCat){
			$this->cats[$oneCat->parent][] = $oneCat;
		}
		$this->_handleChildrens();

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		$picts = array();
		$picts[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$pictureHelper = acymailing_get('helper.acypict');
		if($pictureHelper->available()){
			$picts[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
			$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', 'resized', 'string');
			$pageInfo->pictauto = acymailing_getUserVar($paramBase.".pictauto", 'pictauto', 'resized', 'string');
		}else{
			$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
			$pageInfo->pictauto = acymailing_getUserVar($paramBase.".pictauto", 'pictauto', '1', 'string');
		}
		$picts[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$attributes = array();
		$attributes["title"] = acymailing_translation('EB_TITLE');
		$attributes["sdesc"] = acymailing_translation('EB_SHORT_DESCRIPTION');
		$attributes["ldesc"] = acymailing_translation('EB_DESCRIPTION');
		$attributes["sdate"] = acymailing_translation('EB_EVENT_START_DATE');
		$attributes["edate"] = acymailing_translation('EB_EVENT_END_DATE');
		$attributes["location"] = acymailing_translation('EB_LOCATION');
		$attributes["cutoff"] = acymailing_translation('EB_CUT_OFF_DATE');
		$attributes["capacity"] = acymailing_translation('EB_CAPACITY');
		$attributes["price"] = acymailing_translation('EB_PRICE');
		$attributes["ireg"] = acymailing_translation('EB_REGISTER_INDIVIDUAL');
		$attributes["greg"] = acymailing_translation('EB_REGISTER_GROUP');

		if(file_exists(JPATH_ROOT.DS.'components'.DS.'com_eventbooking'.DS.'fields.xml')){
			$xml = JFactory::getXML(JPATH_ROOT.'/components/com_eventbooking/fields.xml');
			if(!empty($xml->fields)){
				$fields = $xml->fields->fieldset->children();
				$customFields = array();
				foreach($fields as $oneCustomField){
					$name = $oneCustomField->attributes()->name;
					$label = acymailing_translation($oneCustomField->attributes()->label);
					$customFields["$name"] = $label;
				}
			}
		}

		$ordering = array();
		$ordering[] = acymailing_selectOption("id", acymailing_translation('ACY_ID'));
		$ordering[] = acymailing_selectOption("event_date", acymailing_translation('EB_EVENT_START_DATE'));
		$ordering[] = acymailing_selectOption("event_end_date", acymailing_translation('EB_EVENT_END_DATE'));
		$ordering[] = acymailing_selectOption("cut_off_date", acymailing_translation('EB_CUT_OFF_DATE'));
		$ordering[] = acymailing_selectOption("category_id", acymailing_translation('EB_CATEGORY'));
		$ordering[] = acymailing_selectOption("rand", acymailing_translation('ACY_RANDOM'));

		$showDetails = array();
		$showDetails[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$showDetails[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$tabs = acymailing_get('helper.acytabs');
		echo $tabs->startPane('eventbooking_tab');
		echo $tabs->startPanel(acymailing_translation('JOOMEXT_EVENT'), 'eventbooking_event');

		?>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyEvent(eventid, rowClass){
				var tmp = selectedContents.indexOf(eventid)
				if(tmp != -1){
					window.document.getElementById('content' + eventid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + eventid).className = 'selectedrow';
					selectedContents.push(eventid);
				}
				updateEventTag();
			}

			function updateEventTag(){
				var tag = '';
				var otherinfo = '';
				var already = 0;

				contenttype = document.adminForm.elements['contenttype'];
				for(var i = 0; i < contenttype.length; i++){
					if(contenttype[i].checked){
						if(already == 0){
							otherinfo += '| display:' + contenttype[i].value;
							already++;
						}else{
							otherinfo += ',' + contenttype[i].value;
						}
					}
				}
				already = 0;
				if(document.adminForm.customfields){
					for(var i = 0; i < document.adminForm.customfields.length; i++){
						if(document.adminForm.customfields[i].checked){
							if(already == 0){
								otherinfo += '| custom:' + document.adminForm.customfields[i].value;
								already++;
							}else{
								otherinfo += ',' + document.adminForm.customfields[i].value;
							}
						}
					}
				}

				for(var i = 0; i < document.adminForm.pict.length; i++){
					if(document.adminForm.pict[i].checked){
						otherinfo += '| thumb:' + document.adminForm.pict[i].value;
						if(document.adminForm.pict[i].value == 'resized'){
							document.getElementById('thumbsize').style.display = '';
							if(document.adminForm.thumbwidth.value) otherinfo += '| maxwidth:' + document.adminForm.thumbwidth.value;
							if(document.adminForm.thumbheight.value) otherinfo += '| maxheight:' + document.adminForm.thumbheight.value;
						}else{
							document.getElementById('thumbsize').style.display = 'none';
						}
					}
				}

				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{eventbooking:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}
			//-->
		</script>
		<br style="font-size:1px"/>
		<table width="100%" class="adminform">
			<tr>
				<td width="25%">
					<?php echo acymailing_translation('DISPLAY'); ?>
				</td>
				<?php
				$cpt = 1;
				foreach($attributes as $id => $title){
					if($cpt == 4){
						$cpt = 1;
						echo '</tr><tr><td/>';
					}
					echo '<td><input '.(in_array($id, (array)$pageInfo->contenttype) ? 'checked="checked"' : '').' value="'.$id.'" name="contenttype" id="attr_'.$id.'" type="checkbox" onclick="updateEventTag();" /> ';
					echo '<label for="attr_'.$id.'">'.$title.'</label></td>';
					$cpt++;
				}

				while($cpt != 4){
					$cpt++;
					echo '<td/>';
				}
				?>
			</tr>
			<?php
			if(!empty($customFields)){
				echo '<tr><td>'.acymailing_translation('EXTRA_FIELDS').'</td>';
				$cpt = 1;
				foreach($customFields as $name => $label){
					if($cpt == 4){
						$cpt = 1;
						echo '</tr><tr><td/>';
					}
					echo '<td><input value="'.$name.'" name="customfields" id="cf_'.$name.'" type="checkbox" onclick="updateEventTag();" /> ';
					echo '<label for="cf_'.$name.'">'.$label.'</label></td>';
					$cpt++;
				}

				while($cpt != 4){
					$cpt++;
					echo '<td/>';
				}
				echo '</tr>';
			}
			?>
			<tr>
				<td valign="top"><?php echo acymailing_translation('EB_THUMB_IMAGE'); ?></td>
				<td colspan="3"><?php echo acymailing_radio($picts, 'pict', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->pict); ?>
					<span id="thumbsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?> ><br/>
						<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
						<input name="thumbwidth" type="text" onchange="updateEventTag();" value="160" style="width:30px;"/>
						x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
						<input name="thumbheight" type="text" onchange="updateEventTag();" value="160" style="width:30px;"/>
					</span>
				</td>
			</tr>
		</table>
		<table>
			<tr>
				<td width="100%">
					<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
					<button class="btn" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
					<button class="btn" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
				</td>
				<td nowrap="nowrap">

				</td>
			</tr>
		</table>

		<table class="adminlist table table-striped table-hover" cellpadding="1" width="100%">
			<thead>
			<tr>
				<th class="title"></th>
				<th class="title">
					<?php echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'a.title', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
				</th>
				<th class="title">
					<?php echo acymailing_gridSort(acymailing_translation('ACY_DESCRIPTION'), 'a.short_description', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
				</th>
				<th class="title titledate">
					<?php
					echo acymailing_gridSort(acymailing_translation('FIELD_DATE'), 'a.event_date', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
					?>
				</th>
				<th class="title titleid">
					<?php echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'a.id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
				</th>
			</tr>
			</thead>
			<tfoot>
			<tr>
				<td colspan="5">
					<?php echo $pagination->getListFooter(); ?>
					<?php echo $pagination->getResultsCounter(); ?>
				</td>
			</tr>
			</tfoot>
			<tbody>
			<?php
			$k = 0;

			for($i = 0, $a = count($rows); $i < $a; $i++){
				$row =& $rows[$i];
				$description = substr(strip_tags($row->short_description), 0, 100);
				if(strlen($description) == 100) $description .= '...';
				?>
				<tr id="content<?php echo $row->id; ?>" class="<?php echo "row$k"; ?>" onclick="applyEvent(<?php echo $row->id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td>
						<?php echo $row->title; ?>
					</td>
					<td>
						<?php echo acymailing_absoluteURL($description); ?>
					</td>
					<td align="center" style="text-align:center">
						<?php echo acymailing_getDate(acymailing_getTime($row->event_date), acymailing_translation('DATE_FORMAT_LC')); ?>
					</td>
					<td align="center" style="text-align:center">
						<?php echo $row->id; ?>
					</td>
				</tr>
				<?php
				$k = 1 - $k;
			}
			?>
			</tbody>
		</table>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>
		<?php
		echo $tabs->endPanel();
		echo $tabs->startPanel(acymailing_translation('UPCOMING_EVENTS'), 'eventbooking_auto');
		$type = acymailing_getVar('string', 'type');

		?>
		<br style="font-size:1px"/>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedCat = new Array();
			function applyAutoEvent(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('event_cat' + catid).className == 'selectedrow'){
						window.document.getElementById('event_catall').className = rowClass;
					}else{
						window.document.getElementById('event_cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('event_cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('event_catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('event_cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('event_cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'event';
					}
				}
				updateTag();
			}

			function updateTag(){
				var already = 0;
				var tag = '{autoeventbooking:';

				for(var icat in selectedCat){
					if(selectedCat[icat] == 'event'){
						tag += icat + '-';
					}
				}

				contenttypeauto = document.adminForm.elements['contenttypeauto'];
				for(var i = 0; i < contenttypeauto.length; i++){
					if(contenttypeauto[i].checked){
						if(already == 0){
							tag += '| display:' + contenttypeauto[i].value;
							already++;
						}else{
							tag += ',' + contenttypeauto[i].value;
						}
					}
				}
				already = 0;
				if(document.adminForm.customfieldsauto){
					for(var i = 0; i < document.adminForm.customfieldsauto.length; i++){
						if(document.adminForm.customfieldsauto[i].checked){
							if(already == 0){
								tag += '| custom:' + document.adminForm.customfieldsauto[i].value;
								already++;
							}else{
								tag += ',' + document.adminForm.customfieldsauto[i].value;
							}
						}
					}
				}

				for(var i = 0; i < document.adminForm.pictauto.length; i++){
					if(document.adminForm.pictauto[i].checked){
						tag += '| thumb:' + document.adminForm.pictauto[i].value;
						if(document.adminForm.pictauto[i].value == 'resized'){
							document.getElementById('thumbsizeauto').style.display = '';
							if(document.adminForm.thumbwidthauto.value) tag += '| maxwidth:' + document.adminForm.thumbwidthauto.value;
							if(document.adminForm.thumbheightauto.value) tag += '| maxheight:' + document.adminForm.thumbheightauto.value;
						}else{
							document.getElementById('thumbsizeauto').style.display = 'none';
						}
					}
				}

				if(window.document.getElementById('jlang') && window.document.getElementById('jlang').value != ''){
					tag += '| language:' + window.document.getElementById('jlang').value;
				}

				if(document.adminForm.min_article && document.adminForm.min_article.value && document.adminForm.min_article.value != 0){
					tag += '| min:' + document.adminForm.min_article.value;
				}
				if(document.adminForm.max_article.value && document.adminForm.max_article.value != 0){
					tag += '| max:' + document.adminForm.max_article.value;
				}
				if(document.adminForm.delayevent && document.adminForm.delayevent.value && document.adminForm.delayevent.value > 0){
					tag += '| delay:' + document.adminForm.delayevent.value;
				}
				if(document.adminForm.from_date && document.adminForm.from_date.value){
					tag += '| from:' + document.adminForm.from_date.value;
				}
				if(document.adminForm.to_date && document.adminForm.to_date.value){
					tag += '| to:' + document.adminForm.to_date.value;
				}
				if(document.adminForm.order && document.adminForm.order.value){
					tag += '| order:' + document.adminForm.order.value;
					if(document.adminForm.order.value != 'rand') tag += ',ASC';
				}

				tag += '}';

				setTag(tag);
			}
			//-->
		</script>
		<table width="100%" class="adminform">
			<tr>
				<td width="25%">
					<?php echo acymailing_translation('DISPLAY'); ?>
				</td>
				<?php
				$i = 1;
				foreach($attributes as $id => $title){
					if($i % 4 == 0){
						echo '</tr><tr><td/>';
						$i++;
					}

					if($i == 3){
						$jflanguages = acymailing_get('type.jflanguages');
						$jflanguages->onclick = 'onchange="updateTag();"';
						echo '<td>'.$jflanguages->displayJLanguages('lang', $pageInfo->lang).'</td></tr><tr><td/>';
						$i += 2;
					}
					echo '<td><input '.(in_array($id, (array)$pageInfo->contenttypeauto) ? 'checked="checked"' : '').' value="'.$id.'" name="contenttypeauto" id="autoattr_'.$id.'" type="checkbox" onclick="updateTag();" /> ';
					echo '<label for="autoattr_'.$id.'">'.$title.'</label></td>';
					$i++;
				}
				while($i % 4 != 0){
					echo '<td/>';
					$i++;
				}
				?>
			</tr>
			<?php
			if(!empty($customFields)){
				echo '<tr><td>'.acymailing_translation('EXTRA_FIELDS').'</td>';
				$cpt = 1;
				foreach($customFields as $name => $label){
					if($cpt == 4){
						$cpt = 1;
						echo '</tr><tr><td/>';
					}
					echo '<td><input value="'.$name.'" name="customfieldsauto" id="autocf_'.$name.'" type="checkbox" onclick="updateTag();" /> ';
					echo '<label for="autocf_'.$name.'">'.$label.'</label></td>';
					$cpt++;
				}

				while($cpt != 4){
					$cpt++;
					echo '<td/>';
				}
				echo '</tr>';
			}
			?>
			<tr>
				<td valign="top"><?php echo acymailing_translation('EB_THUMB_IMAGE'); ?></td>
				<td colspan="3">
					<?php echo acymailing_radio($picts, 'pictauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pictauto); ?>
					<span id="thumbsizeauto" <?php if($pageInfo->pictauto != 'resized') echo 'style="display:none;"'; ?> ><br/>
						<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
						<input name="thumbwidthauto" type="text" onchange="updateTag();" value="160" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
						<input name="thumbheightauto" type="text" onchange="updateTag();" value="160" style="width:30px;"/>
				</span>
				</td>
			</tr>
			<tr>
				<td>
					<?php echo acymailing_translation('MAX_ARTICLE'); ?>
				</td>
				<td>
					<input type="text" name="max_article" style="width:50px" value="20" onchange="updateTag();"/>
				</td>
				<td>
					<?php echo acymailing_translation('ACY_ORDER'); ?>
				</td>
				<td>
					<?php echo acymailing_select($ordering, 'order', 'class="inputbox" size="1" onchange="updateTag();" style="width:100px;"', 'value', 'text'); ?>
				</td>
			</tr>
			<?php if($type == 'autonews'){ ?>
				<tr>
					<td>
						<?php echo acymailing_translation('MIN_ARTICLE'); ?>
					</td>
					<td>
						<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTag();"/>
					</td>
					<td>
						<?php echo acymailing_translation('MAX_STARTING_DATE'); ?>
					</td>
					<td>
						<?php $delayType = acymailing_get('type.delay');
						$delayType->onChange = "updateTag();";
						echo $delayType->display('delayevent', 7776000, 3); ?>
					</td>
				</tr>
			<?php }else{ ?>
				<tr>
					<td>
						<?php echo acymailing_translation('ACY_FROM_DATE'); ?>
					</td>
					<td>
						<?php echo acymailing_calendar('', 'from_date', 'from_date', '%Y-%m-%d', 'style="width:80px" onchange="updateTag();"'); ?>
					</td>
					<td>
						<?php echo acymailing_translation('ACY_TO_DATE'); ?>
					</td>
					<td>
						<?php echo acymailing_calendar('', 'to_date', 'to_date', '%Y-%m-%d', 'style="width:80px" onchange="updateTag();"'); ?>
					</td>
				</tr>
			<?php } ?>
		</table>
		<table class="adminlist table table-striped table-hover" cellpadding="1" width="100%">
			<?php $k = 0; ?>
			<tr id="event_catall" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
				<td class="acytdcheckbox"></td>
				<td>
					<?php
					echo acymailing_translation('ACY_ALL');
					?>
				</td>
			</tr>
			<?php
			if(!empty($this->catvalues)){
				foreach($this->catvalues as $oneCat){ ?>
					<tr id="event_cat<?php echo $oneCat->id ?>" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent(<?php echo $oneCat->id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
							<?php
							echo $oneCat->name;
							?>
						</td>
					</tr>
					<?php $k = 1 - $k;
				}
			} ?>
		</table>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
		//End of the function
	}

	private function _handleChildrens($parentId = 0, $level = 0){
		if(!empty($this->cats[$parentId])){
			foreach($this->cats[$parentId] as $cat){
				//$cat->name = str_repeat($this->separator,$level).$cat->cat_name;
				$cat->name = str_repeat(" - - ", $level).$cat->name;
				$this->catvalues[] = $cat;
				$this->_handleChildrens($cat->id, $level + 1);
			}
		}
	}

	public function acymailing_replacetags(&$email, $send = true){
		$this->_replaceAuto($email);
		$this->_replaceEvents($email);
	}

	private function _replaceEvents(&$email){
		$acypluginsHelper = acymailing_get('helper.acyplugins');
		//load the tags
		$tags = $acypluginsHelper->extractTags($email, 'eventbooking');
		if(empty($tags)) return;

		//We will need the mailer class as well
		$this->mailerHelper = acymailing_get('helper.mailer');


		acymailing_loadLanguageFile('com_eventbooking', JPATH_SITE);

		if(!include_once JPATH_ROOT.'/components/com_eventbooking/helper/helper.php'){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('Could not load the eventBooking helper', 'notice');
			return;
		}

		$this->eventbookingconfig = EventBookingHelper::getConfig();

		//Set the read more link:
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		$htmlreplace = array();
		$textreplace = array();
		foreach($tags as $i => $params){
			if(isset($htmlreplace[$i])) continue;
			$content = $this->_replaceEvent($tags[$i]);
			$htmlreplace[$i] = $content;
			$textreplace[$i] = $this->mailerHelper->textVersion($content, true);
		}
		$email->body = str_replace(array_keys($htmlreplace), $htmlreplace, $email->body);
		$email->altbody = str_replace(array_keys($textreplace), $textreplace, $email->altbody);
	}

	private function _replaceEvent(&$tag){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		if(empty($tag->itemid)) $tag->itemid = $this->params->get('itemid');
		if(empty($tag->thumbfloat)) $tag->thumbfloat = 'left';

		//1 : Load the informations of the product...
		$query = 'SELECT b.name as location_name, a.* FROM `#__eb_events` as a ';
		$query .= 'LEFT JOIN `#__eb_locations` AS b ON a.location_id  = b.id ';
		$query .= 'WHERE a.id = '.intval($tag->id).' LIMIT 1';
		$event = acymailing_loadObject($query);

		if(empty($event)){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('The event "'.$tag->id.'" could not be loaded', 'notice');
			return '';
		}

		$varFields = array();
		foreach($event as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}

		if(!empty($this->version)){
			if(version_compare($this->version, '1.6.1', '>=')){
				$link = 'index.php?option=com_eventbooking&view=event&id='.intval($tag->id);
			}else{
				$link = 'index.php?option=com_eventbooking&task=view_event&event_id='.intval($tag->id);
			}
		}else{
			$link = 'index.php?option=com_eventbooking&task=view_event&event_id='.intval($tag->id);
		}

		if(!empty($tag->itemid)) $link .= '&Itemid='.$tag->itemid;
		$link = acymailing_frontendLink($link);
		$varFields['{link}'] = $link;

		$result = '';
		//Trim the space as well!
		$displayargs = explode(',', trim($tag->display, ', '));

		if(in_array('title', $displayargs)){
			if(count($displayargs) == 1){
				//Only title
				$styleTitle = '';
				$styleTitleEnd = '';
			}else{
				$styleTitle = '<h2 class="acymailing_title">';
				$styleTitleEnd = '</h2>';
			}

			$result .= '<a href="'.$link.'" style="text-decoration:none" name="event-'.$event->id.'" target="_blank" >'.$styleTitle.$event->title.$styleTitleEnd.'</a>';
		}

		//Display picture with description
		$description = '';
		if(in_array('sdesc', $displayargs)) $description .= $event->short_description;
		if(in_array('ldesc', $displayargs)){
			if(!empty($description)) $description .= '<br />';
			$description .= $event->description;
		}

		$description = $acypluginsHelper->wrapText($description, $tag);
		$varFields['{wrapeddescription}'] = $description;

		if(!empty($tag->thumb)){
			if(!empty($event->image)){
				$pictPath = ACYMAILING_LIVE.$event->image;
			}else if(!empty($event->thumb)){
				if(file_exists(JPATH_ROOT.'/media/com_eventbooking/images/'.$event->thumb)){
					$pictPath = ACYMAILING_LIVE.'media/com_eventbooking/images/'.$event->thumb;
				}else{
					$pictPath = ACYMAILING_LIVE.'media/com_eventbooking/images/thumbs/'.$event->thumb;
				}
			}
			//take the picture from the desc if there is no thumb and the user asked for one with the parameter wrap.
			if(empty($pictPath) && !empty($tag->wrap)){
				//Load the picture from the content as it has been removed anyway...
				if(preg_match('#<img[^>]*src="([^"]*)"[^>]*>#Uis', $event->description.$event->short_description, $pregresult)){
					$pictPath = $pregresult[1];
				}
			}

			if(!empty($pictPath)){
				$varFields['{imagehtml}'] = '<img src="'.$pictPath.'" style="float:'.$tag->thumbfloat.';padding-'.($tag->thumbfloat = 'left' ? 'right' : 'left').':10px;padding-bottom:10px;" alt="'.$event->title.'" />';
				$picture = '<a href="'.$link.'" style="text-decoration:none" >'.$varFields['{imagehtml}'].'</a>';
				$description = $picture.$description;
			}
		}

		$result .= $description;

		$information = array();
		foreach($displayargs as $onevar){
			$onevar = trim($onevar);
			if($onevar == 'sdate' && $event->event_date > '0001-00-00'){
				$information[] = '<span class="event_parameter eb_date">'.acymailing_translation('EB_EVENT_DATE').':</span> '.acymailing_date($event->event_date, $this->eventbookingconfig->event_date_format, null);
			}elseif($onevar == 'edate' && $event->event_end_date > '0001-00-00'){
				$information[] = '<span class="event_parameter eb_enddate">'.acymailing_translation('EB_EVENT_END_DATE').':</span> '.acymailing_date($event->event_end_date, $this->eventbookingconfig->event_date_format, null);
			}elseif($onevar == 'location' && !empty($event->location_name)){
				$varFields['{location_link}'] = 'index.php?option=com_eventbooking&view=map&tmpl=component&format=html&location_id='.$event->location_id;
				$information[] = '<span class="event_parameter eb_location">'.acymailing_translation('EB_LOCATION').':</span> <a href="'.$varFields['{location_link}'].'">'.$event->location_name.'</a>';
			}elseif($onevar == 'cutoff' && $event->cut_off_date > '0001-00-00'){
				$information[] = '<span class="event_parameter eb_cutoff">'.acymailing_translation('EB_CUT_OFF_DATE').':</span> '.acymailing_date($event->cut_off_date, $this->eventbookingconfig->date_format, null);
			}elseif($onevar == 'capacity'){
				$tmp = '<span class="event_parameter eb_capacity">'.acymailing_translation('EB_CAPACITY').':</span> ';
				$tmp .= $event->event_capacity ? $event->event_capacity : acymailing_translation('EB_UNLIMITED');
				$information[] = $tmp;
			}elseif($onevar == 'price'){
				$tmp = '<span class="event_parameter eb_price">'.acymailing_translation('EB_PRICE').':</span> ';
				$tmp .= $event->individual_price > 0 ? @EventBookingHelper::formatCurrency($event->individual_price, $this->eventbookingconfig, $event->currency_symbol) : acymailing_translation('EB_FREE');
				$information[] = $tmp;
			}
		}
		if(!empty($information)) $result .= implode('<br/>', $information);

		//Display custom fields...
		//First see if there are values
		if(!empty($event->custom_fields) && !empty($tag->custom)){
			$customFields = explode(',', $tag->custom);
			//Then load the fields and their values
			if(file_exists(JPATH_ROOT.DS.'components'.DS.'com_eventbooking'.DS.'fields.xml')){
				$xml = JFactory::getXML(JPATH_ROOT.'/components/com_eventbooking/fields.xml');
				$fields = $xml->fields->fieldset->children();
				$params = new JRegistry();
				$params->loadString($event->custom_fields, 'INI');
				$decodedFields = json_decode($event->custom_fields);

				foreach($fields as $oneCustomField){
					$name = $oneCustomField->attributes()->name;
					$label = acymailing_translation($oneCustomField->attributes()->label);
					$value = $params->get($name);
					$name = (string) $name;
					if($value === NULL && !empty($decodedFields) && !empty($decodedFields->$name)){
						$value = $decodedFields->$name;
					}

					if(!empty($value) && in_array($name, $customFields)){
						$varFields['{cf|'.$name.'}'] = $value;
						$varFields['{cf|'.$label.'}'] = $value;
						$result .= '<br /><span class="event_custom">'.$label.':</span> ';
						$result .= $value;
					}
				}
			}
		}

		//Display reg buttons...
		if(in_array('ireg', $displayargs) || in_array('greg', $displayargs)){
			$result .= '<p class="reg_buttons">';
			if(in_array('ireg', $displayargs)){
				$label = empty($tag->itext) ? acymailing_translation('EB_REGISTER_INDIVIDUAL') : $tag->itext;
				$reglink = 'index.php?option=com_eventbooking&task='.(version_compare(EventbookingHelper::getInstalledVersion(), '2.0.0', '>=') ? 'register.' : '').'individual_registration&event_id='.$tag->id;
				if(!empty($tag->itemid)) $reglink .= '&Itemid='.$tag->itemid;
				$reglink = acymailing_frontendLink($reglink);
				$varFields['{individualregbutton}'] = ' <a class="event_registration eb_indivreg" href="'.$reglink.'" target="_blank" >'.$label.'</a> ';
				$result .= $varFields['{individualregbutton}'];
			}
			if(in_array('greg', $displayargs)){
				$label = empty($tag->gtext) ? acymailing_translation('EB_REGISTER_GROUP') : $tag->gtext;
				$reglink = 'index.php?option=com_eventbooking&task='.(version_compare(EventbookingHelper::getInstalledVersion(), '2.0.0', '>=') ? 'register.' : '').'group_registration&event_id='.$tag->id;
				if(!empty($tag->itemid)) $reglink .= '&Itemid='.$tag->itemid;
				$reglink = acymailing_frontendLink($reglink);
				$varFields['{groupregbutton}'] = ' <a class="event_registration eb_groupreg" href="'.$reglink.'" target="_blank" >'.$label.'</a> ';
				$result .= $varFields['{groupregbutton}'];
			}
			$result .= '</p>';
		}

		$result = '<table cellspacing="0" cellpadding="0" border="0" width="100%"><tr><td class="cat_'.@$event->category_id.'" ><div class="acymailing_content" >'.$result.'</div></td></tr></table>';


		//Check if the template exists...
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'eventbooking.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.'eventbooking.php');
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		if(!empty($tag->thumb) && $tag->thumb == 'resized' && (!empty($tag->maxheight) || !empty($tag->maxwidth))){
			$pictureHelper = acymailing_get('helper.acypict');
			$pictureHelper->maxHeight = empty($tag->maxheight) ? 9999 : (int)$tag->maxheight;
			$pictureHelper->maxWidth = empty($tag->maxwidth) ? 9999 : (int)$tag->maxwidth;
			if($pictureHelper->available()){
				$result = $pictureHelper->resizePictures($result);
			}elseif(acymailing_isAdmin()){
				acymailing_enqueueMessage($pictureHelper->error, 'notice');
			}
		}

		return $result;
	}

	private function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);

		if(!empty($this->tags)){
			$email->body = str_replace(array_keys($this->tags), $this->tags, $email->body);
			if(!empty($email->altbody)) $email->altbody = str_replace(array_keys($this->tags), $this->tags, $email->altbody);
		}
	}

	public function acymailing_generateautonews(&$email){
		$acypluginsHelper = acymailing_get('helper.acyplugins');
		$time = time();

		//load the tags
		$tags = $acypluginsHelper->extractTags($email, 'autoeventbooking');
		$return = new stdClass();
		$return->status = true;
		$return->message = '';
		$this->tags = array();

		if(empty($tags)) return $return;

		foreach($tags as $oneTag => $parameter){
			if(isset($this->tags[$oneTag])) continue;

			$allcats = explode('-', $parameter->id);
			if(empty($parameter->order)) $parameter->order = 'event_date,ASC';
			if(empty($parameter->from)) $parameter->from = date('Y-m-d H:i:s', $time);
			//Load the articles based on all arguments...
			$selectedArea = array();
			foreach($allcats as $oneCat){
				if(empty($oneCat)) continue;
				$selectedArea[] = (int)$oneCat;
			}

			$query = 'SELECT DISTINCT a.`id` FROM `#__eb_events` as a ';
			$where = array();
			if(!empty($selectedArea)){
				$query .= ' JOIN #__eb_event_categories as b ON a.id = b.event_id ';
				$where[] = 'b.category_id IN ('.implode(',', $selectedArea).')';
			}

			$where[] = 'a.`published` = 1';

			if(!empty($parameter->language)) $where[] = 'a.language = '.acymailing_escapeDB($parameter->language);

			if(!empty($parameter->mindelay)){
				$where[] = 'a.`event_date` >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->mindelay));
			}else $where[] = 'a.`event_date` >= '.acymailing_escapeDB($parameter->from);

			if(!empty($parameter->delay)) $where[] = 'a.`event_date` <= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->delay));
			if(!empty($parameter->to)) $where[] = 'a.`event_date` <= '.acymailing_escapeDB($parameter->to);
			if(!empty($parameter->open)) $where[] = 'a.`cut_off_date` > '.acymailing_escapeDB(date('Y-m-d H:i:s', $time)).' OR a.`cut_off_date` < "0001-01-01"';

			$query .= ' WHERE ('.implode(') AND (', $where).')';
			if($parameter->order == 'rand'){
				$query .= ' ORDER BY rand()';
			}else{
				$ordering = explode(',', $parameter->order);
				$query .= ' ORDER BY `'.acymailing_secureField($ordering[0]).'` '.acymailing_secureField($ordering[1]);
			}

			if(!empty($parameter->max)) $query .= ' LIMIT '.(int)$parameter->max;
			$allArticles = acymailing_loadResultArray($query);

			if(!empty($parameter->min) AND count($allArticles) < $parameter->min){
				//We won't generate the Newsletter
				$return->status = false;
				$return->message = 'Not enough events for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
			}
			$stringTag = '';
			if(!empty($allArticles)){
				if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'autoeventbooking.php')){
					ob_start();
					require(ACYMAILING_MEDIA.'plugins'.DS.'autoeventbooking.php');
					$stringTag = ob_get_clean();
				}else{
					//we insert the article tag one after the other in a table as they are already sorted
					$arrayElements = array();
					$numArticle = 1;
					foreach($allArticles as $oneArticleId){
						$args = array();
						$args[] = 'eventbooking:'.$oneArticleId;
						$args[] = 'num:'.$numArticle++;
						if(!empty($parameter->display)) $args[] = 'display:'.$parameter->display;
						if(!empty($parameter->custom)) $args[] = 'custom:'.$parameter->custom;
						if(!empty($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
						if(isset($parameter->thumb)) $args[] = 'thumb:'.$parameter->thumb;
						if(!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
						if(!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
						if(!empty($parameter->thumbfloat)) $args[] = 'thumbfloat:'.$parameter->thumbfloat;
						if(!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
						if(!empty($parameter->itext)) $args[] = 'itext:'.$parameter->itext;
						if(!empty($parameter->gtext)) $args[] = 'gtext:'.$parameter->gtext;
						$arrayElements[] = '{'.implode('|', $args).'}';
					}
					$stringTag = $acypluginsHelper->getFormattedResult($arrayElements, $parameter);
				}
			}
			$this->tags[$oneTag] = $stringTag;
		}
		return $return;
	}

	function onAcyDisplayFilters(&$type){

		if(!$this->component_installed) return '';
		$config = acymailing_config();


		acymailing_loadLanguageFile('com_eventbooking', JPATH_SITE);
		acymailing_loadLanguageFile('com_eventbooking', JPATH_ADMINISTRATOR);

		$allEvents = acymailing_loadObjectList('SELECT id AS value, title AS text FROM #__eb_events WHERE published = 1 ORDER BY title ASC');
		array_unshift($allEvents, acymailing_selectOption('-1', acymailing_translation('ACY_ALL')));

		$status = array();
		$status[] = acymailing_selectOption('-1', acymailing_translation('EB_REGISTRATION_STATUS'));
		$status[] = acymailing_selectOption('0', acymailing_translation('EB_PENDING'));
		$status[] = acymailing_selectOption('1', acymailing_translation('EB_PAID'));
		$status[] = acymailing_selectOption('2', acymailing_translation('EB_CANCELLED'));

		$return = '<div id="filter__num__ebregistration">';
		$return .= acymailing_translation('EB_REGISTRANTS').' '.acymailing_select($allEvents, 'filter[__num__][ebregistration][event]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= ' '.acymailing_select($status, 'filter[__num__][ebregistration][status]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= '<br /><input type="text" name="filter[__num__][ebregistration][dateinf]" onclick="displayDatePicker(this,event)" onchange="countresults(__num__)" style="width:70px;" /> < '.acymailing_translation('EB_REGISTRATION_DATE').' < <input type="text" name="filter[__num__][ebregistration][datesup]" onclick="displayDatePicker(this,event)" onchange="countresults(__num__)" style="width:70px;"/>';
		$return .= '</div>';
		$type['ebregistration'] = 'Event Booking';
		if(version_compare($config->get('version'), '4.8.0', '<')){
			echo 'Please update AcyMailing, the Event Booking plugin may not work properly with this version';
		}

		return $return;
	}

	function onAcyProcessFilterCount_ebregistration(&$query, $filter, $num){
		$this->onAcyProcessFilter_ebregistration($query, $filter, $num);
		return acymailing_translation_sprintf('SELECTED_USERS', $query->count());
	}

	function onAcyProcessFilter_ebregistration(&$query, $filter, $num){
		if(!$this->component_installed) return;

		$query->join['eventbooking'.$num] = "`#__eb_registrants` as eventbooking$num ON (eventbooking$num.email = sub.email OR (eventbooking$num.user_id != 0 AND eventbooking$num.user_id = sub.userid))";

		$filter['event'] = intval($filter['event']);
		$filter['status'] = intval($filter['status']);

		if($filter['event'] != -1){
			$query->where[] = "eventbooking$num.event_id = ".$filter['event'];
		}

		if($filter['status'] != -1){
			$query->where[] = "eventbooking$num.published = ".$filter['status'];
		}

		if(!empty($filter['dateinf'])){
			$filter['dateinf'] = acymailing_replaceDate($filter['dateinf']);
			if(!is_numeric($filter['dateinf'])) $filter['dateinf'] = strtotime($filter['dateinf']);
			if(!empty($filter['dateinf'])) $query->where[] = "eventbooking$num.register_date > '".date('Y-m-d H:i:s', $filter['dateinf'])."'";
		}

		if(!empty($filter['datesup'])){
			$filter['datesup'] = acymailing_replaceDate($filter['datesup']);
			if(!is_numeric($filter['datesup'])) $filter['datesup'] = strtotime($filter['datesup']);
			if(!empty($filter['datesup'])) $query->where[] = "eventbooking$num.register_date < '".date('Y-m-d H:i:s', $filter['datesup'])."'";
		}
	}
}//endclass