<?php
/**
 * @copyright    Copyright (C) 2009-2018 ACYBA SAS - All rights reserved..
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingOhanah extends JPlugin{

	var $searchFields = array('a.ohanah_event_id', 'a.ohanah_category_id', 'a.title', 'a.date');
	var $selectedFields = array('a.*');

	function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', 'ohanah');
			$this->params = new acyParameter($plugin->params);
		}

		$this->component_installed = file_exists(rtrim(JPATH_ADMINISTRATOR, DS).DS.'components'.DS.'com_ohanah');
		$this->newVersion = false;
		if(file_exists(rtrim(JPATH_ADMINISTRATOR, DS).DS.'components'.DS.'com_ohanah'.DS.'ohanah.xml')){
			$xml = simplexml_load_file(rtrim(JPATH_ADMINISTRATOR, DS).DS.'components'.DS.'com_ohanah'.DS.'ohanah.xml');
			$this->newVersion = version_compare((string)$xml->version, '3.0.0', '>=');
		}
		//If is the new version we set the search fields
		if($this->newVersion){
			$this->searchFields = array('a.ohanah_event_id', 'a.ohanah_category_id', 'a.title', 'b.start');
		}else{
			$this->searchFields = array('a.ohanah_event_id', 'a.ohanah_category_id', 'a.title', 'a.date');
		}
	}

	function acymailing_getPluginType(){
		if(!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;
		$onePlugin = new stdClass();
		$onePlugin->name = 'Ohanah';
		$onePlugin->function = 'acymailingOhanah_show';
		$onePlugin->help = 'plugin-ohanah';
		return $onePlugin;
	}

	function acymailingOhanah_show(){
		$config = acymailing_config();
		if(version_compare($config->get('version'), '5.0.0', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		$pageInfo = new stdClass();
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->limit = new stdClass();
		$pageInfo->elements = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.ohanah';
		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'a.ohanah_event_id', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'desc', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));
		$pageInfo->contenttype = acymailing_getUserVar($paramBase.".contenttype", 'contenttype', 'full', 'string');
		$pageInfo->details = acymailing_getUserVar($paramBase.".details", 'details', 'yes', 'string');
		$pageInfo->contenttypeauto = acymailing_getUserVar($paramBase.".contenttypeauto", 'contenttypeauto', 'full', 'string');
		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');
		$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
		$pageInfo->autopict = acymailing_getUserVar($paramBase.".autopict", 'autopict', '1', 'string');
		$pageInfo->contentorder = acymailing_getUserVar($paramBase.".contentorder", 'contentorder', 'id,DESC', 'string');
		$pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', $this->params->get('maxheight', 150), 'string');
		$pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', $this->params->get('maxwidth', 150), 'string');
		$pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
		$pageInfo->autoreadmore = acymailing_getUserVar($paramBase.".autoreadmore", 'autoreadmore', '1', 'string');
		$pageInfo->wrap = acymailing_getUserVar($paramBase.".wrap", 'wrap', '0', 'string');
		$pageInfo->clickable = acymailing_getUserVar($paramBase.".clickable", 'clickable', '1', 'string');
		$pageInfo->clickableauto = acymailing_getUserVar($paramBase.".clickableauto", 'clickableauto', '1', 'string');
		$pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');

		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search).'%\'';
			$filters[] = implode(" LIKE $searchVal OR ", $this->searchFields)." LIKE $searchVal";
		}

		//we hide past events but we remove one day just to make sure we won't hide something we should not!
		if($this->params->get('hidepastevents', 'yes') == 'yes'){
			if($this->newVersion){
				$filters[] = 'b.`end` >= '.acymailing_escapeDB(date('Y-m-d', time() - 86400));
			}else{
				$filters[] = 'a.`end_date` >= '.acymailing_escapeDB(date('Y-m-d', time() - 86400));
			}
		}

		if($this->newVersion) $this->selectedFields[] = 'b.start AS date';
		$query = 'SELECT SQL_CALC_FOUND_ROWS '.implode(',', $this->selectedFields).' FROM `#__ohanah_events` as a';
		if($this->newVersion) $query .= ' JOIN #__ohanah_dates AS b ON a.ohanah_event_id = b.ohanah_event_id ';

		if(!empty($filters)) $query .= ' WHERE ('.implode(') AND (', $filters).')';
		if(!empty($pageInfo->filter->order->value)) $query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;


		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		if(!empty($pageInfo->search)) $rows = acymailing_search($pageInfo->search, $rows);

		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		$picts = array();
		$picts[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$picts[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
		$picts[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$contenttype = array();
		$contenttype[] = acymailing_selectOption("title", acymailing_translation('INTRO_ONLY'));
		$contenttype[] = acymailing_selectOption("full", acymailing_translation('FULL_TEXT'));

		$showDetails = array();
		$showDetails[] = acymailing_selectOption("yes", acymailing_translation('JOOMEXT_YES'));
		$showDetails[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$clickable = array();
		$clickable[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$clickable[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$readmore = array();
		$readmore[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$readmore[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$column = array();
		for($i = 1; $i < 11; $i++){
			$column[] = acymailing_selectOption("$i", $i);
		}

		$tabs = acymailing_get('helper.acytabs');
		echo $tabs->startPane('jevents_tab');
		echo $tabs->startPanel(acymailing_translation('JOOMEXT_EVENT'), 'jevents_event');

		?>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyEvent(eventid, rowClass){
				var tmp = selectedContents.indexOf(eventid)
				if(tmp != -1){
					window.document.getElementById('content' + eventid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + eventid).className = 'selectedrow';
					selectedContents.push(eventid);
				}
				updateEventTag();
			}

			function updateEventTag(){
				var tag = '';
				var otherinfo = '';

				for(var i = 0; i < document.adminForm.contenttype.length; i++){
					if(document.adminForm.contenttype[i].checked){
						selectedtype = document.adminForm.contenttype[i].value;
						otherinfo += "| type:" + document.adminForm.contenttype[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.clickable.length; i++){
					if(document.adminForm.clickable[i].checked){
						otherinfo += "| clickable:" + document.adminForm.clickable[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked){
						otherinfo += "| readmore:" + document.adminForm.readmore[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.pict.length; i++){
					if(document.adminForm.pict[i].checked){
						otherinfo += '|pict:' + document.adminForm.pict[i].value;
						if(document.adminForm.pict[i].value == 'resized'){
							document.getElementById('pictsize').style.display = '';
							if(document.adminForm.pictwidth.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidth.value;
							if(document.adminForm.pictheight.value) otherinfo += '| maxheight:' + document.adminForm.pictheight.value;
						}else{
							document.getElementById('pictsize').style.display = 'none';
						}
					}
				}

				for(var i = 0; i < document.adminForm.details.length; i++){
					if(document.adminForm.details[i].checked){
						otherinfo += "| details:" + document.adminForm.details[i].value;
					}
				}

				if(document.adminForm.wrap.value && document.adminForm.wrap.value != 0){
					otherinfo += "| wrap:" + document.adminForm.wrap.value;
				}

				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{ohanahevent:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}
			//-->
		</script>
		<br style="font-size:1px"/>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td>
						<?php echo acymailing_translation('DISPLAY'); ?>
					</td>
					<td colspan="3">
						<?php echo acymailing_radio($contenttype, 'contenttype', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->contenttype); ?>
					</td>
				</tr>
				<tr>
					<td><?php echo acymailing_translation('EXTRA_INFORMATION'); ?></td>
					<td>
						<?php echo acymailing_radio($showDetails, 'details', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->details); ?>
					</td>
					<td colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateEventTag();"/>'); ?></td>
				</tr>
				<tr>
					<td><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td><?php echo acymailing_radio($clickable, 'clickable', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->clickable); ?></td>
					<td valign="top"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td><?php echo acymailing_radio($readmore, 'readmore', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->readmore); ?>
				</tr>
				<tr>
					<td valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td valign="top"><?php echo acymailing_radio($picts, 'pict', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->pict); ?>
						<span id="pictsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidth" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheight" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
				</span>
					</td>
					<td></td>
					<td></td>
				</tr>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table_options">
				<tr>
					<td width="100%">
						<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
						<button class="acymailing_button_grey" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
						<button class="acymailing_button_grey" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
					</td>
					<td nowrap="nowrap">

					</td>
				</tr>
			</table>

			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
				<tr>
					<th class="title"></th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'a.title', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('ACY_DESCRIPTION'), 'a.description', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php
						echo acymailing_gridSort(acymailing_translation('FIELD_DATE'), $this->newVersion ? 'b.start' : 'a.date', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
						?>
					</th>
					<th class="title titleid">
						<?php echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'a.ohanah_event_id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="5">
						<?php echo $pagination->getListFooter(); ?>
						<?php echo $pagination->getResultsCounter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php
				$k = 0;

				for($i = 0, $a = count($rows); $i < $a; $i++){
					$row =& $rows[$i];
					$descriptionPresent = strpos($row->description, '<hr');
					if(!empty($descriptionPresent)){
						$description = substr(strip_tags($row->description), 0, strpos($row->description, '<hr'));
					}else $description = substr(strip_tags($row->description), 0, 100);
					$description .= '...';
					?>
					<tr id="content<?php echo $row->ohanah_event_id; ?>" class="<?php echo "row$k"; ?>" onclick="applyEvent(<?php echo $row->ohanah_event_id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
							<?php echo $row->title; ?>
						</td>
						<td>
							<?php echo acymailing_absoluteURL($description); ?>
						</td>
						<td align="center" style="text-align:center">
							<?php echo acymailing_getDate(acymailing_getTime(preg_replace('#<([^>]+)>#Uis', '', $row->date)), acymailing_translation('DATE_FORMAT_LC')); ?>
						</td>
						<td align="center" style="text-align:center">
							<?php echo $row->ohanah_event_id; ?>
						</td>
					</tr>
					<?php
					$k = 1 - $k;
				}
				?>
				</tbody>
			</table>
		</div>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>
		<?php
		echo $tabs->endPanel();
		echo $tabs->startPanel(acymailing_translation('UPCOMING_EVENTS'), 'ohanah_auto');
		$type = acymailing_getVar('string', 'type');

		$categories = acymailing_loadObjectList('SELECT a.* FROM `#__ohanah_categories` as a ORDER BY a.`ohanah_category_id` ASC', 'ohanah_category_id');

		$ordering = array();
		$ordering[] = acymailing_selectOption("ohanah_event_id,DESC", acymailing_translation('ACY_ID'));
		$ordering[] = acymailing_selectOption("date,ASC", acymailing_translation('OHANAH_START'));
		$ordering[] = acymailing_selectOption("title,ASC", acymailing_translation('FIELD_TITLE'));
		$ordering[] = acymailing_selectOption("rand", acymailing_translation('ACY_RANDOM'));

		?>
		<br style="font-size:1px"/>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedCat = new Array();
			function applyAutoEvent(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('event_cat' + catid).className == 'selectedrow'){
						window.document.getElementById('event_catall').className = rowClass;
					}else{
						window.document.getElementById('event_cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('event_cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('event_catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('event_cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('event_cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'event';
					}
				}
				updateTag();
			}

			function updateTag(){
				tag = '{autoOhanah:';

				for(var icat in selectedCat){
					if(selectedCat[icat] == 'event'){
						tag += icat + '-';
					}
				}

				for(var i = 0; i < document.adminForm.clickableauto.length; i++){
					if(document.adminForm.clickableauto[i].checked){
						tag += "| clickable:" + document.adminForm.clickableauto[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.autoreadmore.length; i++){
					if(document.adminForm.autoreadmore[i].checked){
						tag += "| readmore:" + document.adminForm.autoreadmore[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.contenttypeauto.length; i++){
					if(document.adminForm.contenttypeauto[i].checked){
						selectedtype = document.adminForm.contenttypeauto[i].value;
						tag += "| type:" + document.adminForm.contenttypeauto[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.autopict.length; i++){
					if(document.adminForm.autopict[i].checked){
						tag += '|pict:' + document.adminForm.autopict[i].value;
						if(document.adminForm.autopict[i].value == 'resized'){
							document.getElementById('pictsizeauto').style.display = '';
							if(document.adminForm.pictwidthauto.value){
								tag += '| maxwidth:' + document.adminForm.pictwidthauto.value;
							}
							if(document.adminForm.pictheightauto.value){
								tag += '| maxheight:' + document.adminForm.pictheightauto.value;
							}
						}else{
							document.getElementById('pictsizeauto').style.display = 'none';
						}
					}
				}

				for(var i = 0; i < document.adminForm.detailsauto.length; i++){
					if(document.adminForm.detailsauto[i].checked){
						tag += "| details:" + document.adminForm.detailsauto[i].value;
					}
				}

				if(document.adminForm.cols.value){
					tag += "| cols:" + document.adminForm.cols.value;
				}
				if(document.adminForm.autowrap.value && document.adminForm.autowrap.value != 0){
					tag += "| wrap:" + document.adminForm.autowrap.value;
				}
				if(document.adminForm.min_article && document.adminForm.min_article.value && document.adminForm.min_article.value != 0){
					tag += '| min:' + document.adminForm.min_article.value;
				}
				if(document.adminForm.max_article.value && document.adminForm.max_article.value != 0){
					tag += '| max:' + document.adminForm.max_article.value;
				}
				if(document.adminForm.delayevent && document.adminForm.delayevent.value && document.adminForm.delayevent.value > 0){
					tag += '| delay:' + document.adminForm.delayevent.value;
				}
				if(document.adminForm.from_date && document.adminForm.from_date.value){
					tag += '| from:' + document.adminForm.from_date.value;
				}
				if(document.adminForm.to_date && document.adminForm.to_date.value){
					tag += '| to:' + document.adminForm.to_date.value;
				}

				tag += '}';

				setTag(tag);
			}
			//-->
		</script>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('DISPLAY'); ?>
					</td>
					<td colspan="3">
						<?php echo acymailing_radio($contenttype, 'contenttypeauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->contenttypeauto); ?>
					</td>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('EXTRA_INFORMATION'); ?></td>
					<td>
						<?php echo acymailing_radio($showDetails, 'detailsauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->details); ?>
					</td>
					<td colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="autowrap" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td><?php echo acymailing_radio($clickable, 'clickableauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td><?php echo acymailing_radio($readmore, 'autoreadmore', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->autoreadmore); ?></td>
				</tr>
				<tr>
					<td nowrap="nowrap" valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td nowrap="nowrap" valign="top"><?php echo acymailing_radio($picts, 'autopict', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->autopict); ?>
						<span id="pictsizeauto" <?php if($pageInfo->autopict != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidthauto" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheightauto" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
				</span>
					</td>
					<td nowrap="nowrap" valign="top">
						<?php echo acymailing_translation('ACY_ORDER'); ?>
					</td>
					<td nowrap="nowrap" valign="top">
						<?php echo acymailing_select($ordering, 'contentorder', 'size="1" onchange="updateTag();" style="width:100px;"', 'value', 'text', $pageInfo->contentorder); ?>
					</td>
				</tr>
				<tr>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td>
						<input type="text" name="max_article" style="width:50px" value="20" onchange="updateTag();"/>
					</td>
					<td><?php echo acymailing_translation('FIELD_COLUMNS'); ?></td>
					<td>
						<?php echo acymailing_select($column, 'cols', 'size="1" onchange="updateTag();" style="width:60px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
				<?php if($type == 'autonews'){ ?>
					<tr>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td>
						<td>
							<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTag();"/>
						</td>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('MAX_STARTING_DATE'); ?>
						</td>
						<td nowrap="nowrap">
							<?php $delayType = acymailing_get('type.delay');
							$delayType->onChange = "updateTag();";
							echo $delayType->display('delayevent', 7776000, 3); ?>
						</td>
					</tr>
				<?php }else{ ?>
					<tr>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('ACY_FROM_DATE'); ?>
						</td>
						<td>
							<?php echo acymailing_calendar('', 'from_date', 'from_date', '%Y-%m-%d', array('style' => 'width:80px', 'onchange' => 'updateTag();')); ?>
						</td>
						<td>
							<?php echo acymailing_translation('ACY_TO_DATE'); ?>
						</td>
						<td>
							<?php echo acymailing_calendar('', 'to_date', 'to_date', '%Y-%m-%d', array('style' => 'width:80px', 'onchange' => 'updateTag();')); ?>
						</td>
					</tr>
				<?php } ?>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table" cellpadding="1" width="100%">
				<?php $k = 0; ?>
				<tr id="event_catall" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"/>
					<td>
						<?php
						echo acymailing_translation('ACY_ALL');
						?>
					</td>
				</tr>
				<?php
				foreach($categories as $oneCat){ ?>
					<tr id="event_cat<?php echo $oneCat->ohanah_category_id ?>" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent(<?php echo $oneCat->ohanah_category_id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
							<?php
							if(!empty($oneCat->parent_id) && !empty($categories[$oneCat->parent_id])) echo $categories[$oneCat->parent_id]->title.' => ';
							echo $oneCat->title;
							?>
						</td>
					</tr>
					<?php $k = 1 - $k;
				} ?>
			</table>
		</div>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
	}

	function acymailing_replacetags(&$email, $send = true){
		$this->_replaceAuto($email);
		$this->_replaceEvents($email);
	}

	function _replaceEvents(&$email){

		acymailing_loadLanguageFile('com_ohanah', JPATH_SITE);

		$match = '#{ohanahevent:(.*)}#Ui';
		$variables = array('body', 'altbody');
		$found = false;
		foreach($variables as $var){
			if(empty($email->$var)) continue;
			$found = preg_match_all($match, $email->$var, $results[$var]) || $found;
			//we unset the results so that we won't handle it later... it will save some memory and processing
			if(empty($results[$var][0])) unset($results[$var]);
		}

		//If we didn't find anything...
		if(!$found) return;
		$mailerHelper = acymailing_get('helper.mailer');

		$this->currentcatid = -1;
		//Set the read more link:
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		$resultshtml = array();
		$resultstext = array();
		foreach($results as $var => $allresults){
			foreach($allresults[0] as $i => $oneTag){
				//Don't need to process twice a tag we already have!
				if(isset($resultshtml[$oneTag])) continue;

				$resultshtml[$oneTag] = $this->_replaceEvent($allresults, $i);
				$resultstext[$oneTag] = $mailerHelper->textVersion($resultshtml[$oneTag]);
			}
		}

		$email->body = str_replace(array_keys($resultshtml), $resultshtml, $email->body);
		$email->altbody = str_replace(array_keys($resultstext), $resultstext, $email->altbody);
	}

	function _replaceEvent(&$results, $i){
		$acypluginsHelper = acymailing_get('helper.acyplugins');
		$arguments = explode('|', strip_tags($results[1][$i]));
		$tag = new stdClass();
		$tag->id = intval($arguments[0]);
		$tag->pict = 1;
		$tag->type = 'full';
		for($i = 1, $a = count($arguments); $i < $a; $i++){
			$args = explode(':', $arguments[$i]);
			$arg0 = trim($args[0]);
			if(isset($args[1])){
				$tag->$arg0 = str_replace(" ", "", $args[1]);
			}else{
				$tag->$arg0 = true;
			}
		}

		//1 : Load the informations of the product...
		if($this->newVersion){
			$query = 'SELECT a.*, a.title AS eventTitle, a.image_path as eventPicture,  a.description as eventDescription, b.*, b.title AS categoryTitle, c.start AS date, c.end AS end_date  FROM `#__ohanah_events` as a ';
			$query .= 'LEFT JOIN `#__ohanah_categories` AS b ON a.ohanah_category_id = b.ohanah_category_id ';
			$query .= ' JOIN #__ohanah_dates AS c ON a.ohanah_event_id = c.ohanah_event_id ';
		}else{
			$query = 'SELECT a.*, a.title AS eventTitle, a.picture as eventPicture,  a.description as eventDescription, b.*, b.title AS categoryTitle  FROM `#__ohanah_events` as a ';
			$query .= 'LEFT JOIN `#__ohanah_categories` AS b ON a.ohanah_category_id = b.ohanah_category_id ';
		}

		$query .= 'WHERE a.ohanah_event_id = '.intval($tag->id).' LIMIT 1';
		$event = acymailing_loadObject($query);

		if(empty($event)){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('The event "'.$tag->id.'" could not be loaded', 'notice');
			return '';
		}

		$varFields = array();
		foreach($event as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}

		$startdate = acymailing_getDate(strtotime($event->date), acymailing_translation('DATE_FORMAT_LC'));
		$varFields['{startdate}'] = $startdate;
		$timeVar = 'start_time';
		if($this->newVersion) $timeVar = 'date';
		$starttime = substr($event->$timeVar, 11, 5);
		$varFields['{starttime}'] = $starttime;
		$enddate = acymailing_getDate(acymailing_getTime($event->end_date), acymailing_translation('DATE_FORMAT_LC'));
		$varFields['{enddate}'] = $enddate;

		$link = 'index.php?option=com_ohanah&view=event&id='.intval($tag->id);
		if(!empty($tag->itemid)) $link .= '&Itemid='.$tag->itemid;
		if(!empty($tag->addtourl)){
			$link .= $tag->addtourl;
		}elseif($this->params->get('addtourl', 'none') != 'none'){
			$link .= $this->params->get('addtourl', 'none');
		}
		$link = acymailing_frontendLink($link);
		$varFields['{link}'] = $link;

		$result = '<table cellspacing="0" cellpadding="0" border="0" width="100%">';
		$trimValues = array('<p>', '</p>');

		if(!empty($event->eventTitle)){
			if(!empty($tag->clickable)){
				$result .= '<tr><td><a target="_blank" href="'.$link.'"><h2 class="acymailing_title">'.$event->eventTitle.'</h2></a></td></tr>';
			}else{
				$result .= '<tr><td><h2 class="acymailing_title">'.$event->eventTitle.'</h2></td></tr>';
			}
		}

		if(!empty($event->eventPicture) && !empty($tag->pict)){
			if($this->newVersion){
				$imageFile = $event->eventPicture;
			}else{
				$imageFile = file_exists(ACYMAILING_ROOT.'media'.DS.'com_ohanah'.DS.'attachments'.DS.$event->eventPicture) ? ACYMAILING_LIVE.'/media/com_ohanah/attachments/'.$event->eventPicture : ACYMAILING_LIVE.'/media/com_ohanah/attachments_thumbs/'.$event->eventPicture;
			}
			$varFields['{imagehtml}'] = '<img style="float:left;margin:5px" src="'.$imageFile.'" />';
			$result .= '<tr><td><span class="eventcontact" style="text-decoration:none;border:0" target="_blank" href="'.$link.'" >'.$varFields['{imagehtml}'].'</span></td></tr>';
		}

		if(!empty($tag->details) && $tag->details == 'yes'){
			if(!empty($startdate) && !empty($enddate)){
				if($startdate != $enddate){
					$result .= '<tr><td><span class="eventdate">'.ucfirst($startdate).'  -  '.ucfirst($enddate).'</span></td></tr>';
				}else{
					$result .= '<tr><td><span class="eventdate">'.ucfirst($enddate).'</span></td></tr>';
				}
			}

			if(!empty($event->ohanah_venue_id)){
				$query = 'SELECT * FROM `#__ohanah_venues` WHERE enabled = 1 AND ohanah_venue_id = '.intval($event->ohanah_venue_id);
				$venue = acymailing_loadObject($query);
			}

			$cityVar = 'geolocated_city';
			$countryVar = 'geolocated_country';
			$addressVar = 'address';
			$titleVar = 'title';
			if($this->newVersion){
				$cityVar = 'city';
				$countryVar = 'country';
				$addressVar = 'address_1';
				$titleVar = 'name';
			}

			if(!empty($venue) || !empty($event->$cityVar) || !empty($event->$countryVar)){
				$result .= '<tr><td><span class="eventlocation">';
				$geolocated_city = '';
				$geolocated_country = '';
				if(!empty($event->$cityVar)) $geolocated_city = $event->$cityVar;
				if(!empty($event->$countryVar)) $geolocated_country = $event->$countryVar;

				if(!empty($venue)){
					if(!empty($venue->$cityVar)) $geolocated_city = $venue->$cityVar;
					if(!empty($venue->$countryVar)) $geolocated_country = $venue->$countryVar;
				}

				$geoloc = array();
				if(!empty($geolocated_city)) $geoloc[] = $geolocated_city;
				if(!empty($geolocated_country)) $geoloc[] = $geolocated_country;
				if(!empty($geoloc)) $result .= implode(', ', $geoloc);

				if(!empty($venue)){
					$varFields['{address}'] = $venue->$addressVar;
					$varFields['{geolocated_city}'] = $venue->$cityVar;
					$varFields['{geolocated_country}'] = $venue->$countryVar;
					if(!empty($geoloc)) $result .= '<br />';
					$result .= $venue->$titleVar.' : '.$venue->$addressVar;
				}
				$result .= '</span></td></tr>';
			}

			if($this->newVersion){
				$tickets = acymailing_loadObjectList('SELECT * FROM #__ohanah_ticket_types WHERE ohanah_event_id = '.intval($tag->id).(empty($tag->oneprice) ? '' : ' LIMIT 1'));
				if(!empty($tickets)){
					$prices = array();
					foreach($tickets as $oneTicket){
						$prices[] = $oneTicket->price.' ('.$oneTicket->currency_code.')';
					}
					$result .= '<tr><td><span class="eventcontact">'.acymailing_translation('COM_OHANAH_PRICE').' : '.implode(' - ', $prices).'</span></td></tr>';
				}
			}elseif(!empty($event->ticket_cost) && !empty($event->payment_currency)){
				$result .= '<tr><td><span class="eventcontact">'.acymailing_translation('OHANAH_TICKET_COST').' : '.$event->ticket_cost.' '.$event->payment_currency.'</span></td></tr>';
			}
			if(!empty($event->attendees_limit)) $result .= '<tr><td><span class="eventcontact">'.acymailing_translation('OHANAH_PLACES_LEFT').' : '.$event->attendees_limit.'</span></td></tr>';
		}

		if($tag->type == 'full'){
			$event->eventDescription = str_replace('<hr id="system-readmore" />', '', $event->eventDescription);
		}

		if($tag->type == 'title' && !empty($event->eventDescription) && preg_match('<hr id="system-readmore" />', $event->eventDescription)){
			$event->eventDescription = str_replace($trimValues, '', substr($event->eventDescription, 0, strpos($event->eventDescription, '<hr')));
		}

		if(!empty($event->eventDescription)) $result .= '<tr><td>'.$acypluginsHelper->wrapText($event->eventDescription, $tag).'</td></tr>';

		if(!empty($tag->readmore)){
			$readMoreText = empty($this->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : $this->readmore;
			$result .= '<tr><td><a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$readMoreText.'</span></a></td></tr>';
		}

		$result = '<div class="acymailing_content" >'.$result.'</table></div>';

		//Add the cat title...
		if(!empty($tag->cattitle) && $this->currentcatid != $event->ohanah_category_id){
			$this->currentcatid = $event->ohanah_category_id;
			$result = '<h3 class="cattitle">'.$event->categoryTitle.'</h3>'.$result;
		}


		//Check if the template exists...
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'ohanah.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.'ohanah.php');
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		$acypluginsHelper = acymailing_get('helper.acyplugins');
		$result = $acypluginsHelper->removeJS($result);
		$result = $acypluginsHelper->managePicts($tag, $result);

		return $result;
	}

	function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);

		if(!empty($this->tags)){
			$email->body = str_replace(array_keys($this->tags), $this->tags, $email->body);
			if(!empty($email->altbody)) $email->altbody = str_replace(array_keys($this->tags), $this->tags, $email->altbody);
		}
	}

	function acymailing_generateautonews(&$email){
		$return = new stdClass();
		$return->status = true;
		$return->message = '';

		$time = time();
		//Check if we should generate the autoNewsletter or not...
		$match = '#{autoOhanah:(.*)}#Ui';
		$variables = array('body', 'altbody');
		$found = false;
		foreach($variables as $var){
			if(empty($email->$var)) continue;
			$found = preg_match_all($match, $email->$var, $results[$var]) || $found;
			//we unset the results so that we won't handle it later... it will save some memory and processing
			if(empty($results[$var][0])) unset($results[$var]);
		}

		//If we didn't find anything... so we won't try to stop the generation
		if(!$found) return $return;

		$this->tags = array();

		$acypluginsHelper = acymailing_get('helper.acyplugins');

		foreach($results as $var => $allresults){
			foreach($allresults[0] as $i => $oneTag){
				if(isset($this->tags[$oneTag])) continue;

				$arguments = explode('|', $allresults[1][$i]);
				//The first argument is a list of sections and cats...
				$allcats = explode('-', $arguments[0]);
				$parameter = new stdClass();
				$parameter->order = 'date,ASC';
				$parameter->from = date('Y-m-d', $time);
				for($i = 1; $i < count($arguments); $i++){
					$args = explode(':', $arguments[$i]);
					$arg0 = trim($args[0], " ");
					if(isset($args[1])){
						$parameter->$arg0 = trim($args[1], " ");
					}else{
						$parameter->$arg0 = true;
					}
				}
				//Load the articles based on all arguments...
				$selectedArea = array();
				foreach($allcats as $oneCat){
					if(empty($oneCat)) continue;
					$selectedArea[] = 'a.`ohanah_category_id` = '.intval($oneCat);
				}

				$query = 'SELECT DISTINCT a.`ohanah_event_id` FROM `#__ohanah_events` as a ';
				$query .= 'LEFT JOIN #__ohanah_categories as b on a.ohanah_category_id = b.ohanah_category_id ';
				if($this->newVersion) $query .= ' JOIN #__ohanah_dates AS c ON a.ohanah_event_id = c.ohanah_event_id ';

				$where = array();
				if(!empty($selectedArea)) $where[] = implode(' OR ', $selectedArea);

				if($this->newVersion){
					$where[] = 'c.`enabled` = 1';

					//Only featured or standard events...
					if(!empty($parameter->featured)) $where[] = 'c.featured = 1';
					if(!empty($parameter->nofeatured)) $where[] = 'c.featured = 0';

					if(!empty($parameter->mindelay)){
						$where[] = 'c.`start` >= '.acymailing_escapeDB(date('Y-m-d', $time + $parameter->mindelay));
					}else $where[] = 'c.`start` >= '.acymailing_escapeDB($parameter->from);

					if(!empty($parameter->todaysevent)){
						$where[] = 'c.`start` <= '.acymailing_escapeDB(date('Y-m-d 23:59:59', $time));
					}

					if(!empty($parameter->delay)) $where[] = 'c.`start` <= '.acymailing_escapeDB(date('Y-m-d', $time + $parameter->delay));
					if(!empty($parameter->to)) $where[] = 'c.`end` <= '.acymailing_escapeDB($parameter->to);
					$query .= ' WHERE ('.implode(') AND (', $where).')';
					if($parameter->order == 'rand'){
						$query .= ' ORDER BY rand()';
					}else{
						$ordering = explode(',', $parameter->order);
						if($ordering[0] == 'date'){
							$query .= ' ORDER BY c.start ASC';
						}else{
							$query .= ' ORDER BY a.'.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
						}
					}
				}else{
					$where[] = 'a.`enabled` = 1';

					//Only featured or standard events...
					if(!empty($parameter->featured)) $where[] = 'a.featured = 1';
					if(!empty($parameter->nofeatured)) $where[] = 'a.featured = 0';

					if(!empty($parameter->mindelay)){
						$where[] = 'a.`date` >= '.acymailing_escapeDB(date('Y-m-d', $time + $parameter->mindelay));
					}else $where[] = 'a.`date` >= '.acymailing_escapeDB($parameter->from);

					if(!empty($parameter->todaysevent)){
						$where[] = 'a.`date` <= '.acymailing_escapeDB(date('Y-m-d 23:59:59', $time));
					}

					if(!empty($parameter->delay)) $where[] = 'a.`date` <= '.acymailing_escapeDB(date('Y-m-d', $time + $parameter->delay));
					if(!empty($parameter->to)) $where[] = 'a.`end_date` <= '.acymailing_escapeDB($parameter->to);
					$query .= ' WHERE ('.implode(') AND (', $where).')';
					if($parameter->order == 'rand'){
						$query .= ' ORDER BY rand()';
					}else{
						$ordering = explode(',', $parameter->order);
						$query .= ' ORDER BY a.'.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
					}
				}

				if(!empty($parameter->max)) $query .= ' LIMIT '.intval($parameter->max);
				$allArticles = acymailing_loadResultArray($query);

				if(!empty($parameter->min) && count($allArticles) < $parameter->min){
					//We won't generate the Newsletter
					$return->status = false;
					$return->message = 'Not enough events for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
				}
				$stringTag = '';
				if(!empty($allArticles)){
					if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'autoohanah.php')){
						ob_start();
						require(ACYMAILING_MEDIA.'plugins'.DS.'autoohanah.php');
						$stringTag = ob_get_clean();
					}else{
						//we insert the article tag one after the other in a table as they are already sorted
						$arrayElements = array();
						$numArticle = 1;
						foreach($allArticles as $oneArticleId){
							$args = array();
							$args[] = 'ohanahevent:'.$oneArticleId;
							$args[] = 'num:'.$numArticle++;
							if(isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
							if(!empty($parameter->type)) $args[] = 'type:'.$parameter->type;
							if(!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
							if(!empty($parameter->clickable)) $args[] = 'clickable:'.$parameter->clickable;
							if(isset($parameter->readmore)) $args[] = 'readmore:'.$parameter->readmore;
							if(isset($parameter->details)) $args[] = 'details:'.$parameter->details;
							if(!empty($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
							if(!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
							if(!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
							if(!empty($parameter->addtourl)) $args[] = 'addtourl:'.$parameter->addtourl;
							if(!empty($parameter->cattitle)) $args[] = 'cattitle';
							$arrayElements[] = '{'.implode('|', $args).'}';
						}
						$stringTag = $acypluginsHelper->getFormattedResult($arrayElements, $parameter);
					}
				}
				$this->tags[$oneTag] = $stringTag;
			}
		}
		return $return;
	}

	function onAcyDisplayFilters(&$type){
		$acyconfig = acymailing_config();
		$type['ohanah'] = 'Ohanah registered';
		if(version_compare($acyconfig->get('version'), '4.9.4', '<')) return '<div id="filter__num__ohanah">Please update AcyMailing, the Ohanah plugin may not work properly with this version</div>';
		if(!$this->component_installed) return '<div id="filter__num__ohanah">You must install Ohanah to use this filter</div>';


		acymailing_loadLanguageFile('com_ohanah', JPATH_SITE);
		acymailing_loadLanguageFile('com_ohanah', JPATH_ADMINISTRATOR);

		$allEvents = acymailing_loadObjectList('SELECT ohanah_event_id, title FROM #__ohanah_events ORDER BY title ASC');
		$eventList = array();
		if(!empty($allEvents)){
			foreach($allEvents as $oneEvent){
				$eventList[] = acymailing_selectOption($oneEvent->ohanah_event_id, $oneEvent->title);
			}
		}else{
			$eventList[] = acymailing_selectOption('<OPTGROUP>', "No event");
			$eventList[] = acymailing_selectOption('</OPTGROUP>');
		}

		$paid = array();
		$paid[] = acymailing_selectOption('0', '- - -');
		$paid[] = acymailing_selectOption('1', acymailing_translation('OHANAH_PAID'));
		$paid[] = acymailing_selectOption('2', acymailing_translation('OHANAH_NOT_PAID'));

		$return = '<div id="filter__num__ohanah">';
		$return .= acymailing_translation('OHANAH_REGISTRATION').' '.acymailing_select($eventList, 'filter[__num__][ohanah][ohanah_event_id]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= '<br />'.acymailing_translation('OHANAH_PAID').' '.acymailing_select($paid, 'filter[__num__][ohanah][paid]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= '</div>';
		return $return;
	}

	function onAcyProcessFilterCount_ohanah(&$query, $filter, $num){
		$this->onAcyProcessFilter_ohanah($query, $filter, $num);
		return acymailing_translation_sprintf('SELECTED_USERS', $query->count());
	}

	function onAcyProcessFilter_ohanah(&$query, $filter, $num){
		if(!$this->component_installed) return;

		if($this->newVersion){
			$myquery = '#__ohanah_orders AS ohanahevent'.$num.' ON ohanahevent'.$num.'.email = sub.email';
			if(!empty($filter['paid'])){
				if($filter['paid'] == '1'){
					$myquery .= ' AND ohanahevent'.$num.'.status = 1';
				}else{
					$myquery .= ' AND ohanahevent'.$num.'.status = 0';
				}
			}
		}else{
			$myquery = '#__ohanah_registrations AS ohanahevent'.$num.' ON ohanahevent'.$num.'.email = sub.email';
			if(!empty($filter['paid'])){
				if($filter['paid'] == '1'){
					$myquery .= ' AND ohanahevent'.$num.'.paid = 1';
				}else{
					$myquery .= ' AND ohanahevent'.$num.'.paid = 0';
				}
			}
		}
		$query->join[] = $myquery;
		$query->where[] = 'ohanahevent'.$num.'.ohanah_event_id = '.intval($filter['ohanah_event_id']);
	}
}//endclass