<?php
/**
 * @copyright    Copyright (C) 2009-2019 ACYBA SAS - All rights reserved.
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingRseventspro extends JPlugin{

	var $searchFields = array('e.description', 'e.name');

	function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		if(!isset($this->params)){
			$plugin =& JPluginHelper::getPlugin('acymailing', 'rseventspro');
			$this->params = new acyParameter($plugin->params);
		}

		//check if the component is installed
		$this->component_installed = file_exists(JPATH_SITE.DS.'components'.DS.'com_rseventspro');
	}

	function acymailing_getPluginType(){
		if(!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;
		$onePlugin = new stdClass();
		$onePlugin->name = acymailing_translation('JOOMEXT_EVENT').' <small>(RsEvents!Pro)</small>';
		$onePlugin->function = 'acymailingrseventspro_show';
		$onePlugin->help = 'plugin-rseventspro';

		return $onePlugin;
	}

	function acymailingrseventspro_show(){
		$config = acymailing_config();

		if(version_compare($config->get('version'), '5.6.1', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		$pageInfo = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.rseventspro';
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'e.id ', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'DESC', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';

		$pageInfo->author = acymailing_getUserVar($paramBase.".author", 'author', '', 'string');
		$pageInfo->link = acymailing_getUserVar($paramBase.".link", 'link', '1', 'string');
		$pageInfo->place = acymailing_getUserVar($paramBase.".place", 'place', '|place', 'string');
		$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
		$pageInfo->filter_cat = acymailing_getUserVar($paramBase.".filter_cat", 'filter_cat', '', 'int');
		$pageInfo->autolink = acymailing_getUserVar($paramBase.".autolink", 'autolink', '1', 'string');
		$pageInfo->autopict = acymailing_getUserVar($paramBase.".autopict", 'autopict', '1', 'string');
		$pageInfo->max_article = acymailing_getUserVar($paramBase.".max_article", 'max_article', '20', 'int');
		$pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', $this->params->get('maxheight', 150), 'string');
		$pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', $this->params->get('maxwidth', 150), 'string');
		$pageInfo->wrap = acymailing_getUserVar($paramBase.".wrap", 'wrap', '0', 'string');
		$pageInfo->wrapauto = acymailing_getUserVar($paramBase.".wrapauto", 'wrapauto', '0', 'string');
		$pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
		$pageInfo->readmoreauto = acymailing_getUserVar($paramBase.".readmoreauto", 'readmoreauto', '1', 'string');
		$pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');
		$pageInfo->contentorder = acymailing_getUserVar($paramBase.".contentorder", 'contentorder', 'id,DESC', 'string');


		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));

		$pageInfo->limit = new stdClass();
		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');

		if(!empty($pageInfo->filter_cat)){
			$filters[] = "c.id = ".$pageInfo->filter_cat;
		}

		// Loads RSEvents!Pro language files
		
		acymailing_loadLanguageFile('com_rseventspro', JPATH_SITE);

		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search).'%\'';
			$filters[] = implode(" LIKE $searchVal OR ", $this->searchFields)." LIKE $searchVal";
		}

		// We hide past events but we remove one day just to make sure we will not hide something we should not!
		if($this->params->get('hidepastevents', 'yes') == 'yes'){
			$filters[] = 'e.start >= '.acymailing_escapeDB(time() - 86400);
		}

		$whereQuery = ' WHERE ce.type = \'category\'';
		if(!empty($filters)){
			$whereQuery .= ' AND ('.implode(') AND (', $filters).')';
		}

		$query = '
			SELECT SQL_CALC_FOUND_ROWS e.*
			FROM `#__rseventspro_events` AS e
			JOIN `#__users` AS u ON e.owner = u.id
			LEFT JOIN `#__rseventspro_locations` AS location ON e.location = location.id
			JOIN `#__rseventspro_taxonomy` AS ce ON ce.ide = e.id';
		if($this->params->get('categorytable', 'joomla') == 'joomla'){
			$query .= ' JOIN `#__categories` AS c ON c.id = ce.id';
		}else{
			$query .= ' JOIN `#__rseventspro_categories` AS c ON c.id = ce.id';
		}

		$query .= $whereQuery.' GROUP BY e.id ';

		if(!empty($pageInfo->filter->order->value)){
			$query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;
		}

		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		if(!empty($pageInfo->search)){
			$rows = acymailing_search($pageInfo->search, $rows);
		}

		$pageInfo->elements = new stdClass();
		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		$tabs = acymailing_get('helper.acytabs');
		echo $tabs->startPane('rseventspro_tab');
		echo $tabs->startPanel(acymailing_translation('JOOMEXT_EVENT'), 'rseventspro_event');

		$valImages = array();
		$valImages[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$valImages[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
		$valImages[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		// yes/no for the options
		$choice = array();
		$choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		// options for the Nb. columns dropdown (1 to 10)
		$column = array();
		for($i = 1; $i < 11; $i++){
			$column[] = acymailing_selectOption("$i", $i);
		}

		?>
		<br style="font-size:1px"/>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td valign="top" width="25%"><?php echo acymailing_translation('DISP_FIELDS'); ?></td>
					<?php echo $this->_getFields('updateTag()') ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($choice, 'link', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->link); ?></td>

					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->readmore); ?>
				</tr>
				<tr>
					<td nowrap="nowrap" valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($valImages, 'pict', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pict); ?>
						<span id="pictsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?>><br/><?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidth" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
							x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheight" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
						</span>
					</td>
					<td nowrap="nowrap" colspan="2" valign="top"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
				</tr>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table_options">
				<tr>
					<td width="100%">
						<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
						<button class="acymailing_button" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
						<button class="acymailing_button" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
					</td>
					<td class="nowrap">
						<?php echo $this->_categories($pageInfo->filter_cat); ?>
					</td>
				</tr>
			</table>

			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
				<tr>
					<th class="title"></th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'e.name', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('ACY_DESCRIPTION'), 'e.description ', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('FIELD_DATE'), 'e.start', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title titleid">
						<?php echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'e.id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="5">
						<?php echo $pagination->getListFooter(); ?>
						<?php echo $pagination->getResultsCounter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php
				$k = 0;
				for($i = 0, $a = count($rows); $i < $a; $i++){
					$row =& $rows[$i];
					?>
					<tr id="content<?php echo $row->id; ?>" class="<?php echo "row$k"; ?>" onclick="applyContent(<?php echo $row->id.",'row$k'" ?>);" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td width="150px"><?php echo $row->name; ?></td>
						<td width="300px"><?php echo substr(strip_tags($row->description), 0, 120).'...'; ?></td>
						<td align="center" style="text-align:center"><?php echo acymailing_date($row->start, acymailing_translation('DATE_FORMAT_LC')); ?></td>
						<td align="center" style="text-align:center"><?php echo $row->id; ?></td>
					</tr>
					<?php
					$k = 1 - $k;
				}
				?>
				</tbody>
			</table>
		</div>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>
		<?php
		echo $tabs->endPanel();
		echo $tabs->startPanel(acymailing_translation('UPCOMING_EVENTS'), 'rseventspro_auto');
		$type = acymailing_getVar('string', 'type');

		if($this->params->get('categorytable', 'joomla') == 'joomla'){
			$categories = acymailing_loadObjectList('SELECT a.*, a.title as name FROM `#__categories` AS a '.(ACYMAILING_J16 ? 'WHERE `extension`= "com_rseventspro"' : '').' ORDER BY lft ASC');
		}else{
			$categories = acymailing_loadObjectList('SELECT a.* FROM `#__rseventspro_categories` AS a ORDER BY ordering ASC');
		}

		?>
		<br style="font-size:1px"/>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyContent(contentid, rowClass){
				var tmp = selectedContents.indexOf(contentid)
				if(tmp != -1){
					window.document.getElementById('content' + contentid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + contentid).className = 'selectedrow';
					selectedContents.push(contentid);
				}

				updateTag();
			}

			function updateTag(){
				var tag = '', otherinfo = '', selectedfields = [];

				for(var i = 0, len = document.adminForm.fields.length; i < len; i++){
					if(document.adminForm.fields[i].checked){
						selectedfields.push(document.adminForm.fields[i].value);
					}
				}

				if(selectedfields.length){
					otherinfo += '|fields:' + selectedfields.join();
				}else{
					otherinfo += '|fields:name';
				}

				<?php
				//is the title clickable ?
				?>
				for(var i = 0; i < document.adminForm.link.length; i++){
					if(document.adminForm.link[i].checked && document.adminForm.link[i].value == '0'){
						otherinfo += '| nolink';
					}
				}

				<?php
				//do we have to wrap the text ? (description for example...)
				?>
				if(document.adminForm.wrap.value && document.adminForm.wrap.value != 0 && !isNaN(document.adminForm.wrap.value)){
					otherinfo += "| wrap:" + document.adminForm.wrap.value;
				}

				<?php
				//do we have to add a "read more" button ?
				?>
				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked && document.adminForm.readmore[i].value == '1'){
						otherinfo += '| readmore';
					}
				}

				if(selectedfields.length && !( selectedfields.length === 1 && selectedfields[0] == 'name' )){
					for(var i = 0, len = document.adminForm.pict.length; i < len; i++){
						if(document.adminForm.pict[i].checked){
							otherinfo += '|pict:' + document.adminForm.pict[i].value;
							if(document.adminForm.pict[i].value == 'resized'){
								document.getElementById('pictsize').style.display = '';
								if(document.adminForm.pictwidth.value) otherinfo += '|maxwidth:' + document.adminForm.pictwidth.value;
								if(document.adminForm.pictheight.value) otherinfo += '|maxheight:' + document.adminForm.pictheight.value;
							}else{
								document.getElementById('pictsize').style.display = 'none';
							}
						}
					}
				}

				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{rseventspro:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}

			var selectedCat = new Array();
			function applyAuto(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('cat' + catid).className == 'selectedrow'){
						window.document.getElementById('catall').className = rowClass;
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'selectedone';
					}
				}
				updateTagAuto();
			}

			function updateTagAuto(){
				var tag = '{autorseventspro:', selectedfields = [];

				for(var icat in selectedCat){
					if(selectedCat[icat] == 'selectedone'){
						tag += icat + '-';
					}
				}

				for(var i = 0, len = document.adminForm.autofields.length; i < len; i++){
					if(document.adminForm.autofields[i].checked){
						selectedfields.push(document.adminForm.autofields[i].value);
					}
				}
				if(selectedfields.length){
					tag += '| fields:' + selectedfields.join();
				}else{
					tag += '| fields:name';
				}

				for(var i = 0; i < document.adminForm.autolink.length; i++){
					if(document.adminForm.autolink[i].checked && document.adminForm.autolink[i].value == '0'){
						tag += '| nolink';
					}
				}

				if(document.adminForm.wrapauto.value && document.adminForm.wrapauto.value != 0 && !isNaN(document.adminForm.wrapauto.value)){
					tag += "| wrap:" + document.adminForm.wrapauto.value;
				}

				for(var i = 0; i < document.adminForm.readmoreauto.length; i++){
					if(document.adminForm.readmoreauto[i].checked && document.adminForm.readmoreauto[i].value == '1'){
						tag += '| readmore';
					}
				}

				if(selectedfields.length && !( selectedfields.length === 1 && selectedfields[0] == 'name' )){
					for(var i = 0, len = document.adminForm.autopict.length; i < len; i++){
						if(document.adminForm.autopict[i].checked){
							tag += '| pict:' + document.adminForm.autopict[i].value;
							if(document.adminForm.autopict[i].value == 'resized'){
								document.getElementById('pictsizeauto').style.display = '';
								if(document.adminForm.pictwidthauto.value) tag += '| maxwidth:' + document.adminForm.pictwidthauto.value;
								if(document.adminForm.pictheightauto.value) tag += '| maxheight:' + document.adminForm.pictheightauto.value;
							}else{
								document.getElementById('pictsizeauto').style.display = 'none';
							}
						}
					}
				}

				<?php
				//on how many columns do we have to display the contents ?
				?>
				if(document.adminForm.cols.value){
					tag += "| cols:" + document.adminForm.cols.value;
				}

				if(document.adminForm.contentorder.value){
					tag += "| order:" + document.adminForm.contentorder.value;
				}

				if(document.adminForm.min_article && document.adminForm.min_article.value && document.adminForm.min_article.value != 0){
					tag += '| min:' + document.adminForm.min_article.value;
				}
				if(document.adminForm.max_article.value && document.adminForm.max_article.value != 0){
					tag += '| max:' + document.adminForm.max_article.value;
				}
				if(document.adminForm.mindelayevent && document.adminForm.mindelayevent.value > 0){
					tag += '| mindelay:' + document.adminForm.mindelayevent.value;
				}
				if(document.adminForm.delayevent && document.adminForm.delayevent.value > 0){
					tag += '| delay:' + document.adminForm.delayevent.value;
				}
				if(document.adminForm.from_date && document.adminForm.from_date.value){
					tag += '| from:' + document.adminForm.from_date.value;
				}
				if(document.adminForm.to_date && document.adminForm.to_date.value){
					tag += '| to:' + document.adminForm.to_date.value;
				}

				tag += '}';

				setTag(tag);
			}
			//-->
		</script>
		<?php
		// here are the possible orderings
		$ordering = array();
		$ordering[] = acymailing_selectOption("id,DESC", acymailing_translation('ACY_ID'));
		$ordering[] = acymailing_selectOption("created,DESC", acymailing_translation('CREATED_DATE'));
		$ordering[] = acymailing_selectOption("start,ASC", acymailing_translation('FIELD_DATE'));
		$ordering[] = acymailing_selectOption("name,ASC", acymailing_translation('FIELD_TITLE'));
		$ordering[] = acymailing_selectOption("rand", acymailing_translation('ACY_RANDOM'));
		?>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td><?php echo acymailing_translation('DISP_FIELDS'); ?></td>
					<?php echo $this->_getFields('updateTagAuto()', 'autofields') ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($choice, 'autolink', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->autolink); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmoreauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->readmoreauto); ?>
				</tr>
				<tr>
					<td valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td colspan="2"><?php echo acymailing_radio($valImages, 'autopict', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->autopict); ?>
						<span id="pictsizeauto" <?php if($pageInfo->autopict != 'resized') echo 'style="display:none;"'; ?> ><br/><?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidthauto" type="text" onchange="updateTagAuto();" value="<?php echo $this->params->get('maxwidth', '150'); ?>" style="width:30px;"/>
						x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheightauto" type="text" onchange="updateTagAuto();" value="<?php echo $this->params->get('maxheight', '150'); ?>" style="width:30px;"/>
					</span>
					</td>
					<td nowrap="nowrap" colspan="2" valign="top"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrapauto" style="width:50px" value="0" onchange="updateTagAuto();"/>'); ?></td>
				</tr>
				<tr>
					<td><?php echo acymailing_translation('MAX_ARTICLE'); ?></td>
					<td colspan="2"><input type="text" name="max_article" style="width:50px" value="<?php echo (int)$pageInfo->max_article; ?>" onchange="updateTagAuto();"/></td>
					<td>
						<?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap">
						<?php echo acymailing_select($column, 'cols', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>

				<?php if($type == 'autonews'){ ?>
					<tr>
						<td><?php echo acymailing_translation('MIN_ARTICLE'); ?></td>
						<td colspan="2"><input type="text" name="min_article" style="width:50px" value="1" onchange="updateTagAuto();"/></td>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('ACY_ORDER'); ?>
						</td>
						<td nowrap="nowrap">
							<?php echo acymailing_select($ordering, 'contentorder', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'value', 'text', $pageInfo->contentorder); ?>
						</td>
					</tr>
					<tr>
						<td><?php echo acymailing_translation('ACY_FROM_DATE'); ?></td>
						<td colspan="2"><?php $delayType = acymailing_get('type.delay');
							$delayType->onChange = "updateTagAuto();";
							echo $delayType->display('mindelayevent', 7776000, 3); ?></td>
						<td><?php echo acymailing_translation('ACY_TO_DATE'); ?></td>
						<td><?php $delayType = acymailing_get('type.delay');
							$delayType->onChange = "updateTagAuto();";
							echo $delayType->display('delayevent', 7776000, 3); ?></td>
					</tr>
				<?php }else{ ?>
					<tr>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('ACY_ORDER'); ?>
						</td>
						<td nowrap="nowrap" colspan="4">
							<?php echo acymailing_select($ordering, 'contentorder', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'value', 'text', $pageInfo->contentorder); ?>
						</td>
					</tr>
					<tr>
						<td><?php echo acymailing_translation('ACY_FROM_DATE'); ?></td>
						<td colspan="2"><?php echo acymailing_calendar('', 'from_date', 'from_date', '%Y-%m-%d', array('style' => 'width:80px', 'onchange' => 'updateTagAuto();')); ?></td>
						<td><?php echo acymailing_translation('ACY_TO_DATE'); ?></td>
						<td><?php echo acymailing_calendar('', 'to_date', 'to_date', '%Y-%m-%d', array('style' => 'width:80px', 'onchange' => 'updateTagAuto();')); ?></td>
					</tr>
				<?php } ?>

			</table>
		</div>

		<div class="onelineblockoptions">
			<table class="acymailing_table" cellpadding="1" width="100%">
				<?php
				$k = 0;
				?>
				<tr id="catall" class="<?php echo "row$k"; ?>" onclick="applyAuto('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td>
						<?php
						echo acymailing_translation('ACY_ALL');
						?>
					</td>
				</tr>
				<?php
				if(!empty($categories)){
					foreach($categories as $oneCat){ ?>
						<tr id="cat<?php echo $oneCat->id ?>" class="<?php echo "row$k"; ?>" onclick="applyAuto(<?php echo $oneCat->id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
							<td class="acytdcheckbox"></td>
							<td><?php echo $oneCat->name; ?></td>
						</tr>
						<?php $k = 1 - $k;
					}
				} ?>
			</table>
		</div>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
		//End of the function
	}

	function _categories($filter_cat){

		$selectedCat = !empty($filter_cat) ? $filter_cat : 0;

		// Select all categories
		if($this->params->get('categorytable', 'joomla') == 'joomla'){
			$categories = acymailing_loadObjectList('SELECT id,title as name FROM `#__categories` '.(ACYMAILING_J16 ? 'WHERE `extension`= "com_rseventspro"' : '').' ORDER BY lft ASC');
		}else{
			$categories = acymailing_loadObjectList('SELECT id,name FROM `#__rseventspro_categories` ORDER BY ordering ASC');
		}
		if($categories === null){
			acymailing_display('Please check the RSEventsPro plugins, you should switch the parameter "Category table" to the other value', 'error');
			acymailing_display(acymailing_getDBError(), 'error');
		}

		$ret = '<select onchange="document.adminForm.submit();" size="1" class="inputbox" name="filter_cat" id="filter_cat">';

		$selected = (0 == $selectedCat) ? ' selected="selected"' : '';
		$ret .= '<option value="0"'.$selected.'>'.acymailing_translation('ACY_ALL').'</option>';

		foreach($categories as $cat){
			$selected = ($cat->id == $selectedCat) ? ' selected="selected"' : '';
			$ret .= '<option value="'.$cat->id.'"'.$selected.'>'.acymailing_translation($cat->name).'</option>';
		}

		return $ret;
	}

	function acymailing_replacetags(&$email){
		$this->_replaceAuto($email);
		$this->_replaceEvents($email);
	}

	function _replaceEvents(&$email){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		//load the tags
		$tags = $acypluginsHelper->extractTags($email, 'rseventspro');
		if(empty($tags)){
			return;
		}

		// Loads RSEvents!Pro helper
		$mailerHelper = acymailing_get('helper.mailer');
		include_once ACYMAILING_ROOT.'components'.DS.'com_rseventspro'.DS.'helpers'.DS.'rseventspro.php';

		// Loads RSEvents!Pro language files
		
		acymailing_loadLanguageFile('com_rseventspro', JPATH_SITE);

		$this->rsconfig = rseventsproHelper::getConfig();

		//We will need the mailer class as well
		$this->mailerHelper = acymailing_get('helper.mailer');

		//Set the read more text or image
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		$htmlreplace = array();
		$textreplace = array();
		$subjectreplace = array();
		foreach($tags as $i => $params){
			if(isset($htmlreplace[$i])) continue;
			$content = $this->_replaceEvent($tags[$i]);
			$htmlreplace[$i] = $content;
			$textreplace[$i] = $this->mailerHelper->textVersion($content, true);
			$subjectreplace[$i] = strip_tags($content);
		}
		$email->body = str_replace(array_keys($htmlreplace), $htmlreplace, $email->body);
		$email->altbody = str_replace(array_keys($textreplace), $textreplace, $email->altbody);
		$email->subject = str_replace(array_keys($subjectreplace), $subjectreplace, $email->subject);
	}

	function _replaceEvent(&$tag){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		if(empty($tag->itemid)) $tag->itemid = $this->params->get('itemid');

		$query = 'SELECT e.*, l.id AS locationid, l.name AS location, l.url AS locationlink, l.address, l.description AS ldescription, l.coordinates, l.published AS lpublished '.'FROM #__rseventspro_events AS e '.'LEFT JOIN #__rseventspro_locations AS l ON e.location = l.id '.'WHERE e.id = '.intval($tag->id);

		$event = acymailing_loadObject($query);

		// Non-existing event?
		if(empty($event)){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('The RsEvents!Pro content "'.$tag->id.'" could not be loaded', 'notice');
			return '';
		}

		$varFields = array();
		foreach($event as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}

		// Loads the event details
		//$details = rseventsproHelper::details( $tag->id );
		//$event =& $details[ 'event' ];
		$details = array();

		$query = 'SELECT tx.ide, c.* ';
		if($this->params->get('categorytable', 'joomla') == 'joomla'){
			$query .= ' FROM `#__categories` AS c ';
		}else{
			$query .= ' FROM `#__rseventspro_categories` AS c ';
		}
		$query .= ' JOIN #__rseventspro_taxonomy AS tx ON tx.id = c.id '.'WHERE tx.type = "category" '.'AND c.published = 1 ';
		if(ACYMAILING_J16 && $this->params->get('categorytable', 'joomla') == 'joomla') $query .= 'AND c.extension = "com_rseventspro"';

		$allcategories = acymailing_loadObjectList($query);

		$categories = array();
		if(!empty($allcategories)){
			foreach($allcategories as $cat){
				if($cat->ide != $tag->id) continue;
				if(rseventsproHelper::getConfig('color', 'int')){
					$color = '';
					if($cat->params){
						$registry = new JRegistry;
						$registry->loadString($cat->params);
						$color = $registry->get('color');
					}

					$style = $color ? 'style="color: '.$color.'"' : '';
				}else $style = '';
				if(empty($cat->title) && !empty($cat->name)) $cat->title = $cat->name;
				$cURL = rseventsproHelper::route('index.php?option=com_rseventspro&category='.rseventsproHelper::sef($cat->id, $cat->title));
				$cURL = str_replace('administrator/', '', $cURL);

				$categories[] = '<a href="'.$cURL.'" class="rs_cat_link" '.$style.'>'.$cat->title.'</a>';
			}
		}

		// Add categories
		$details['categories'] = !empty($categories) ? implode(' , ', $categories) : '';

		$alltags = acymailing_loadObjectList('SELECT tx.ide, t.id, t.name '.'FROM #__rseventspro_tags AS t '.'JOIN #__rseventspro_taxonomy AS tx ON tx.id = t.id '.'WHERE tx.type = "tag" AND t.published = 1 ');

		$tags = array();
		if(!empty($alltags)){
			foreach($alltags as $oneTag){
				if($oneTag->ide != $oneTag->id) continue;
				$tURL = rseventsproHelper::route('index.php?option=com_rseventspro&tag='.rseventsproHelper::sef($oneTag->id, $oneTag->name));
				$tURL = str_replace('administrator/', '', $tURL);

				$tags[] = '<a href="'.$tURL.'" class="rs_tag_link">'.$oneTag->name.'</a>';
			}
		}

		// Add tags
		$details['tags'] = !empty($tags) ? implode(' , ', $tags) : '';
		//;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
		// ACL
		// if ( !rseventsproHelper::canview( $event->id ) && $event->owner != $this->user ) return '';
		$item = empty($tag->itemid) ? '' : '&Itemid='.$tag->itemid;
		$eventUrl = rseventsproHelper::route('index.php?option=com_rseventspro&layout=show&id='.rseventsproHelper::sef($event->id, $event->name).$item);
		$eventUrl = str_replace('/administrator/', '/', $eventUrl);
		$varFields['{link}'] = $eventUrl;
		$full = @rseventsproHelper::eventisfull($event->id);
		$eventClass = 'rs_event_link'.($full ? ' rs_event_full' : '');

		// Name only ?
		if(empty($tag->fields) || $tag->fields == 'name'){
			$result = '<a class="rs_event" href="'.$eventUrl.'" class="'.$eventClass.'">'.$event->name.'</a>';
		}else{

			// Formats the content to display
			$tag->fields = explode(',', $tag->fields);
			$fields = array();

			$result = '<table class="rs_event"><tr>';

			// Name
			if(in_array('name', $tag->fields)){
				$result .= '<td colspan="2"><h2 class="name">';
				if(empty($tag->nolink)) $result .= '<a style="text-decoration:none" href="'.$eventUrl.'" class="'.$eventClass.'">';
				$result .= $event->name;
				if(empty($tag->nolink)) $result .= '</a>';
				$result .= '</h2></td></tr><tr>';
			}

			// Icon
			if(in_array('icon', $tag->fields)){
				$iconUrl = '';
				if(!empty($event->icon)){
					$iconUrl = acymailing_rootURI().'components/com_rseventspro/assets/images/events/'.$event->icon;
				}else{
					$iconUrl = acymailing_rootURI().'components/com_rseventspro/assets/images/blank.png';
				}
				$iconTitle = addslashes($event->name);
				$result .= '<td class="rs_event_icon" valign="top">';
				if(empty($tag->nolink)) $result .= '<a href="'.$eventUrl.'" title="'.$iconTitle.'" class="image">';
				$varFields['{picthtml}'] = '<img src="'.$iconUrl.'" alt="'.$iconTitle.'" />';
				$result .= '<img src="'.$iconUrl.'" alt="'.$iconTitle.'" />';
				if(empty($tag->nolink)) $result .= '</a>';
				$result .= '</td>';
			}
			// Date
			if(in_array('date', $tag->fields)){
				if(!empty($event->allday)){
					$start = $this->getTrans(array('RSEPRO_ON', 'COM_RSEVENTSPRO_GLOBAL_ON', 'COM_RSEVENTSPRO_EVENT_STARTING_ON')).' <b>'.rseventsproHelper::date($event->start, $this->rsconfig->global_date, true).'</b>';
					$fields['date'] = '<span class="date">'.$start.'</span>';
				}else{
					$start = $this->getTrans(array('RSEPRO_FROM', 'COM_RSEVENTSPRO_GLOBAL_FROM', 'COM_RSEVENTSPRO_FROM')).' <b>'.rseventsproHelper::date($event->start, null, true).'</b>';
					$end = (empty($tag->noenddate)) ? $this->getTrans(array('RSEPRO_TO_LOWERCASE', 'COM_RSEVENTSPRO_TO_LOWERCASE', 'COM_RSEVENTSPRO_TO')).' <b>'.rseventsproHelper::date($event->end, null, true).'</b>' : '';
					$fields['date'] = '<span class="date">'.$start.' '.$end.'</span>';
				}
			}
			// Location
			if(in_array('location', $tag->fields) && $event->locationid && $event->lpublished){
				$locationUrl = rseventsproHelper::route('index.php?option=com_rseventspro&layout=location&id='.rseventsproHelper::sef($event->locationid, $event->location).$item);
				$locationUrl = str_replace('/administrator/', '/', $locationUrl);
				$fields['location'] = '<span class="location">'.$this->getTrans(array('RSEPRO_AT', 'COM_RSEVENTSPRO_GLOBAL_AT', 'COM_RSEVENTSPRO_AT')).' <a href="'.$locationUrl.'">'.$event->location.'</a></span>';
			}
			// Categories
			if(in_array('categories', $tag->fields) && !empty($details['categories'])){
				$fields['categories'] = '<span class="categories">'.$this->getTrans(array('RSEPRO_CATEGORIES', 'COM_RSEVENTSPRO_CATEGORIES')).' '.str_replace('/administrator/', '/', $details['categories']).'</span>';
			}
			// Tags
			if(in_array('tags', $tag->fields) && !empty($details['tags'])){
				$fields['tags'] = '<span class="tags">'.$this->getTrans(array('RSEPRO_TAGS', 'COM_RSEVENTSPRO_TAGS')).' '.str_replace('/administrator/', '/', $details['tags']).'</span>';
			}
			if(in_array('smalldesc', $tag->fields) && !empty($event->small_description)){
				$fields['small_description'] = '<div class="smalldesc">'.$event->small_description.'</div>';
			}
			if(!empty($event->description)){
				$rmlink = strpos($event->description, '<hr id="system-readmore" />');
				// Intro text
				if(in_array('introtext', $tag->fields)){
					//No read more? we load everything
					if($rmlink === false){
						$tag->fields[] = 'description';
					}else{
						$fields['introtext'] = '<div class="introtext">'.$acypluginsHelper->wrapText(substr($event->description, 0, $rmlink), $tag).'</div>';
					}
				}
				// Description
				if(in_array('description', $tag->fields)){
					if($rmlink === false){
						$fields['description'] = '<div class="description">' . $acypluginsHelper->wrapText($event->description, $tag) . '</div>';
					}else {
						$fields['description'] = '<div class="description">' . $acypluginsHelper->wrapText(substr($event->description, $rmlink), $tag) . '</div>';
					}
				}
			}

			if(!empty($tag->readmore)){
				$fields['readmore'] = '<a style="text-decoration:none;" target="_blank" href="'.$eventUrl.'"><span class="acymailing_readmore">'.$this->readmore.'</span></a>';
			}

			if(!empty($fields)){
				$result .= '<td class="rs_event_details" valign="top">'.implode('<br />', $fields).'</td>';
			}

			$result .= '</tr></table>';
		}

		// Is there a template plugin to load?
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'rseventspro.php')){
			ob_start();
			require ACYMAILING_MEDIA.'plugins'.DS.'rseventspro.php';
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		// Do we have to display pictures ?
		if(isset($tag->pict)){
			$pictureHelper = acymailing_get('helper.acypict');
			if($tag->pict == '0'){
				$result = $pictureHelper->removePictures($result);
			}elseif($tag->pict == 'resized'){
				$pictureHelper->maxHeight = empty($tag->maxheight) ? $this->params->get('maxheight', 150) : $tag->maxheight;
				$pictureHelper->maxWidth = empty($tag->maxwidth) ? $this->params->get('maxwidth', 150) : $tag->maxwidth;
				if($pictureHelper->available()){
					$result = $pictureHelper->resizePictures($result);
				}elseif(acymailing_isAdmin()){
					acymailing_enqueueMessage($pictureHelper->error, 'notice');
				}
			}
		}

		return $result;
	}

	function getTrans($possibilities){
		foreach($possibilities as $onePoss){
			if(acymailing_translation($onePoss) != $onePoss){
				return acymailing_translation($onePoss);
			}
		}
	}


	function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);

		if(!empty($this->tags)){
			$email->body = str_replace(array_keys($this->tags), $this->tags, $email->body);
			if(!empty($email->altbody)){
				$email->altbody = str_replace(array_keys($this->tags), $this->tags, $email->altbody);
			}
			foreach($this->tags as $tag => $result){
				$email->subject = str_replace($tag, strip_tags(str_replace('</tr><tr>', ' | ', $result)), $email->subject);
			}
		}
	}

	function acymailing_generateautonews(&$email){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		$tags = $acypluginsHelper->extractTags($email, 'autorseventspro');
		$return = new stdClass();
		$return->status = true;
		$return->message = '';

		$time = time();
		$this->tags = array();

		if(empty($tags)) return $return;

		foreach($tags as $oneTag => $parameter){
			if(isset($this->tags[$oneTag])) continue;

			$allcats = explode('-', $parameter->id);
			$selectedArea = array();
			foreach($allcats as $oneCat){
				if(empty($oneCat)) continue;
				$selectedArea[] = intval($oneCat);
			}

			$query = 'SELECT DISTINCT e.id ';
			$query .= 'FROM #__rseventspro_events AS e ';
			$query .= 'JOIN #__rseventspro_taxonomy AS ec ';
			$query .= 'ON ec.ide = e.id ';

			$where = array();

			// load only needed content
			if(!empty($selectedArea)){
				$where[] = 'ec.id IN ('.implode(',', $selectedArea).')';
			}

			if(!empty($parameter->featured)){
				$where[] = 'e.featured = 1';
			}

			if(!empty($parameter->nofeatured)){
				$where[] = 'e.featured = 0';
			}

			if(!empty($parameter->recurring)){
				$where[] = 'e.recurring = 1 OR e.parent <> 0';
			}

			if(!empty($parameter->norecurring)){
				$where[] = 'e.recurring = 0 AND e.parent = 0';
			}

			$where[] = 'ec.type = "category"';

			if(!empty($selectedArea)){
				$where[] = implode(' OR ', $selectedArea);
			}

			$where[] = 'e.`published` = 1';

			// Date
			if(!empty($parameter->from)){
				$where[] = 'e.`start` >= '.acymailing_escapeDB($parameter->from);
			}else{
				if(!empty($parameter->addcurrent)){
					$where[] = 'e.`end` >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time));
				}else{
					$where[] = 'e.`start` >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time));
				}
			}

			if(!empty($parameter->todaysevent)){
				$where[] = 'e.`start` <= '.acymailing_escapeDB(date('Y-m-d 23:59:59', $time));
			}

			if(!empty($parameter->to)) $where[] = 'e.`start` <= '.acymailing_escapeDB($parameter->to);
			if(!empty($parameter->mindelay)) $where[] = 'e.`start` >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->mindelay));
			if(!empty($parameter->delay)) $where[] = 'e.`start` <= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->delay));

			if(!empty($parameter->filter) AND !empty($email->params['lastgenerateddate'])){
				$where[] = 'e.`created` >\''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\'';
			}

			$query .= ' WHERE ('.implode(') AND (', $where).')';

			//$query .= ' GROUP BY e.name ';

			if(empty($parameter->order)) $parameter->order = 'start,ASC';
			if($parameter->order == 'rand'){
				$query .= ' ORDER BY rand()';
			}else{
				$ordering = explode(',', $parameter->order);
				$query .= ' ORDER BY e.'.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
			}

			if(!empty($parameter->max)) $query .= ' LIMIT '.(int)$parameter->max;

			$allArticles = acymailing_loadResultArray($query);

			// Is there enough events to generate the newsletter?
			if(!empty($parameter->min) && count($allArticles) < intval($parameter->min)){
				$return->status = false;
				$return->message = 'Not enough events for the tag '.$oneTag.': '.count($allArticles).' / '.$parameter->min;
			}

			$stringTag = '';
			if(!empty($allArticles)){
				if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'autorseventspro.php')){
					ob_start();
					require(ACYMAILING_MEDIA.'plugins'.DS.'autorseventspro.php');
					$stringTag = ob_get_clean();
				}else{
					// We insert the article tag one after the other in a table as they are already sorted
					$arrayElements = array();
					foreach($allArticles as $oneArticleId){
						$stringTag .= '<tr><td>';
						$args = array();
						$args[] = 'rseventspro:'.$oneArticleId;
						if(!empty($parameter->nolink)) $args[] = 'nolink';
						if(!empty($parameter->readmore)) $args[] = 'readmore';
						if(!empty($parameter->noenddate)) $args[] = 'noenddate';
						if(isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
						if(isset($parameter->fields)) $args[] = 'fields:'.$parameter->fields;
						if(isset($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
						if(isset($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
						if(isset($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
						if(isset($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
						$arrayElements[] = '{'.implode('|', $args).'}';
					}
					$stringTag = $acypluginsHelper->getFormattedResult($arrayElements, $parameter);
				}
			}
			$this->tags[$oneTag] = $stringTag;
		}

		return $return;
	}

	function _getFields($onchange = 'void(0)', $name = 'fields', $cols = 5){
		$fields = '';
		$existingFields = array('icon' => 'ACY_IMAGE', 'name' => 'RSEPRO_EVENT_NAME', 'date' => 'RSEPRO_FEED_DATE', 'location' => 'RSEPRO_EVENT_LOCATION', 'categories' => 'RSEPRO_EVENT_CATEGORIES', 'tags' => 'RSEPRO_EVENT_TAGS', 'smalldesc' => 'COM_RSEVENTSPRO_EVENT_SMALL_DESCRIPTION', 'description' => 'ACY_DESCRIPTION', 'introtext' => 'INTRO_TEXT');
		$selectedfields = array('icon', 'name', 'date', 'description');

		$i = 0;
		$j = 1;
		foreach($existingFields as $value => $label){
			if($j == $cols){
				$j = 1;
				$fields .= '</tr><tr><td/>';
			}

			$labelname = acymailing_translation($label);

			if($labelname == $label) $labelname = acymailing_translation(str_replace('RSEPRO_', 'COM_RSEVENTSPRO_', $label));
			$fields .= '<td>
				<input type="checkbox" name="'.$name.'" id="rseventspro-'.$name.'-'.$i.'" value="'.$value.'" '.(in_array($value, $selectedfields) ? 'checked="checked"' : '').' onchange="'.$onchange.'" />
				<label for="rseventspro-'.$name.'-'.$i.'">'.$labelname.'</label></td>';

			$i++;
			$j++;
		}

		while($j != $cols){
			$fields .= '<td/>';
			$j++;
		}
		return $fields;
	}


	function onAcyDisplayFilters(&$type){
		
		acymailing_loadLanguageFile('com_rseventspro', JPATH_SITE);

		$allEvents = acymailing_loadObjectList('SELECT id, name FROM #__rseventspro_events');
		$eventList = array();
		$eventList[] = acymailing_selectOption(0, '- - -');
		foreach($allEvents as $oneEvent){
			$eventList[] = acymailing_selectOption($oneEvent->id, $oneEvent->name);
		}

		//a ticket can be complete/incomplete or denied
		$status = array();
		$status[] = acymailing_selectOption(0, acymailing_translation('ALL_STATUS'));
		$status[] = acymailing_selectOption(1, acymailing_translation('COM_RSEVENTSPRO_RULE_STATUS_INCOMPLETE'));
		$status[] = acymailing_selectOption(2, acymailing_translation('COM_RSEVENTSPRO_RULE_STATUS_COMPLETE'));
		$status[] = acymailing_selectOption(3, acymailing_translation('COM_RSEVENTSPRO_RULE_STATUS_DENIED'));

		// Action to do when choosing a geolocation field (on some types propose values, count results)
		$jsOnChange = "var eventId = document.getElementById('filter__num__rseventsid').value; ";
		$jsOnChange .= "displayCondFilter('displayTickets', 'toChange__num__',__num__,'eventId='+eventId); ";
		// countResults done on success of ajax call

		$return = '<div id="filter__num__rsevents">';
		$return .= acymailing_translation('COM_RSEVENTSPRO_MY_SUBSCRIPTION_EVENT').' '.acymailing_select($eventList, 'filter[__num__][rsevents][id]', 'class="inputbox" onchange="'.$jsOnChange.'countresults(__num__)" size="1"', 'value', 'text').'<span id="toChange__num__">Ticket Id : <input onchange="countresults(__num__)" class="inputbox" type="text" name="filter[__num__][rsevents][ticket]" id="filter__num__rseventsticket" style="width:200px" value=""></span>';
		$return .= '<br />'.acymailing_translation('COM_RSEVENTSPRO_GLOBAL_STATUS').' '.acymailing_select($status, 'filter[__num__][rsevents][status]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= '</div>';
		$type['rsevents'] = 'RSEvents registered';
		$acyconfig = acymailing_config();
		if(version_compare($acyconfig->get('version'), '4.0.0', '<')){
			echo 'Please update AcyMailing, the RSEvents plugin may not work properly with this version';
		}
		return $return;
	}

	// Load tickets of the selected event
	function onAcyTriggerFct_displayTickets(){
		$num = acymailing_getVar('int', 'num');
		$eventId = acymailing_getVar('none', 'eventId');

		// Display first 100 tickets
		$query = 'SELECT id, name FROM #__rseventspro_tickets WHERE ide = '.intval($eventId).' LIMIT 100';
		$tickets = acymailing_loadObjectList($query);

		// No values -> default return
		if(empty($tickets)) return '';
		$valueProp = array();
		$valueProp[] = acymailing_selectOption(0, '- - -');
		foreach($tickets as $oneTicket){
			$valueProp[] = acymailing_selectOption($oneTicket->id, $oneTicket->name);
		}
		return acymailing_select($valueProp, "filter[$num][rsevents][ticket]", 'onchange="countresults('.$num.')" class="inputbox" size="1" style="width:200px"', 'value', 'text', null, 'filter'.$num.'rseventsticket');
	}

	function onAcyProcessFilterCount_rsevents(&$query, $filter, $num){
		$this->onAcyProcessFilter_rsevents($query, $filter, $num);
		return acymailing_translation_sprintf('SELECTED_USERS', $query->count());
	}

	function onAcyProcessFilter_rsevents(&$query, $filter, $num){
		$myquery = 'SELECT DISTINCT a.email FROM #__rseventspro_users AS a '.'LEFT JOIN #__rseventspro_user_tickets AS b '.'ON a.id = b.ids ';
		//if we didn't select an event, this will take users registered to at least one event
		$where = array();
		if(!empty($filter['id'])) $where[] = 'a.ide = '.intval($filter['id']);

		//if we didn't select a status, this will not take the status into account
		if(!empty($filter['status'])){
			if($filter['status'] == 1){
				$where[] = 'a.state = 0';
			}elseif($filter['status'] == 2){
				$where[] = 'a.state = 1';
			}else{
				$where[] = 'a.state = 2';
			}
		}
		if(!empty($filter['ticket'])) $where[] = 'b.idt = '.$filter['ticket'];
		if(!empty($where)) $myquery .= 'WHERE ('.implode(') AND (', $where).')';
		$allEmails = acymailing_loadResultArray($myquery);
		if(empty($allEmails)) $allEmails[] = 'none';
		$query->where[] = "sub.email IN ('".implode("','", $allEmails)."')";
	}
}//endclass
