<?php
/**
 * @copyright    Copyright (C) 2009-2018 ACYBA SAS - All rights reserved..
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingTagjevents extends JPlugin{
	var $searchFields = array('rpt.rp_id', 'detail.evdet_id', 'detail.description', 'detail.summary', 'detail.contact', 'detail.location');
	var $selectedFields = array('rpt.*', 'detail.*');

	function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', 'tagjevents');
			$this->params = new acyParameter($plugin->params);
		}

		//check if the component is installed
		$this->acypluginsHelper = acymailing_get('helper.acyplugins');
		$this->component_installed = file_exists(JPATH_SITE.DS.'components'.DS.'com_jevents');
	}

	function acymailing_getPluginType(){
		if(!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;
		$onePlugin = new stdClass();
		$onePlugin->name = acymailing_translation('JOOMEXT_EVENT').' <small>(jEvents)</small>';
		$onePlugin->function = 'acymailingtagjevents_show';
		$onePlugin->help = 'plugin-tagjevents';
		return $onePlugin;
	}

	function acymailingtagjevents_show(){
		$config = acymailing_config();
		if(version_compare($config->get('version'), '5.9.6', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}


		acymailing_loadLanguageFile('com_jevents', JPATH_SITE);
		if(file_exists(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_jevlocations')) acymailing_loadLanguageFile('com_jevents', JPATH_ADMINISTRATOR);

		$pageInfo = new stdClass();
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->limit = new stdClass();
		$pageInfo->elements = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.tagjevents';
		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'rpt.startrepeat', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'desc', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));
		$pageInfo->contenttype = acymailing_getUserVar($paramBase.".contenttype", 'contenttype', 'full', 'string');
		$pageInfo->lang = acymailing_getUserVar($paramBase.".lang", 'lang', '', 'string');
		$pageInfo->contenttypeauto = acymailing_getUserVar($paramBase.".contenttypeauto", 'contenttypeauto', 'full', 'string');
		$pageInfo->langauto = acymailing_getUserVar($paramBase.".langauto", 'langauto', '', 'string');
		$pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', $this->params->get('maxheight', 150), 'string');
		$pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', $this->params->get('maxwidth', 150), 'string');
		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');
		$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
		$pageInfo->autopict = acymailing_getUserVar($paramBase.".autopict", 'autopict', '1', 'string');
		$pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
		$pageInfo->autoreadmore = acymailing_getUserVar($paramBase.".autoreadmore", 'autoreadmore', '1', 'string');
		$pageInfo->wrap = acymailing_getUserVar($paramBase.".wrap", 'wrap', '0', 'string');
		$pageInfo->clickable = acymailing_getUserVar($paramBase.".clickable", 'clickable', '1', 'string');
		$pageInfo->clickableauto = acymailing_getUserVar($paramBase.".clickableauto", 'clickableauto', '1', 'string');
		$pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');
		$pageInfo->pluginFields = acymailing_getUserVar($paramBase.".pluginFields", 'pluginFields', '1', 'string');
		$pageInfo->pluginFieldsauto = acymailing_getUserVar($paramBase.".pluginFieldsauto", 'pluginFieldsauto', '1', 'string');
		$pageInfo->location = acymailing_getUserVar($paramBase.".location", 'location', '0', 'string');
		$pageInfo->city = acymailing_getUserVar($paramBase."city", 'city', '0', 'string');
		$pageInfo->state = acymailing_getUserVar($paramBase."state", 'state', '0', 'string');
		$pageInfo->country = acymailing_getUserVar($paramBase."country", 'country', '0', 'string');
		$pageInfo->exactlocation = acymailing_getUserVar($paramBase.".exactlocation", 'exactlocation', '0', 'string');
		$pageInfo->contentorder = acymailing_getUserVar($paramBase.".contentorder", 'contentorder', 'id', 'string');
		$pageInfo->contentorderdir = acymailing_getUserVar($paramBase.".contentorderdir", 'contentorderdir', 'DESC', 'string');

		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search).'%\'';
			$filters[] = implode(" LIKE $searchVal OR ", $this->searchFields)." LIKE $searchVal";
		}

		//we hide past events but we remove one day just to make sure we won't hide something we should not!
		if($this->params->get('hidepastevents', 'yes') == 'yes'){
			$filters[] = 'rpt.`endrepeat` >= '.acymailing_escapeDB(date('Y-m-d', time() - 86400));
		}

		$whereQuery = '';
		if(!empty($filters)){
			$whereQuery = ' WHERE ('.implode(') AND (', $filters).')';
		}

		$query = 'SELECT SQL_CALC_FOUND_ROWS '.implode(',', $this->selectedFields).' FROM `#__jevents_repetition` as rpt ';
		$query .= 'JOIN `#__jevents_vevent` as ev ON rpt.eventid = ev.ev_id ';
		$query .= 'JOIN `#__jevents_vevdetail` AS detail ON ev.detail_id=detail.evdet_id ';

		if(!empty($whereQuery)) $query .= $whereQuery;
		if(!empty($pageInfo->filter->order->value)){
			$query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;
		}

		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		if(!empty($pageInfo->search)){
			$rows = acymailing_search($pageInfo->search, $rows);
		}

		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		$picts = array();
		$picts[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$picts[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
		$picts[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$contenttype = array();
		$contenttype[] = acymailing_selectOption("title", acymailing_translation('TITLE_ONLY'));
		$contenttype[] = acymailing_selectOption("full", acymailing_translation('FULL_TEXT'));

		$choice = array();
		$choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$column = array();
		for($i = 1; $i < 11; $i++){
			$column[] = acymailing_selectOption("$i", $i);
		}

		//handle custom fields
		if(ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevcustomfields')){
			$jevCFParams = acymailing_loadObject('SELECT params FROM #__extensions WHERE element = "jevcustomfields"');
			if(!empty($jevCFParams->params)){
				$template = json_decode($jevCFParams->params)->template;
			}
			if(!empty($template)){
				$xmlfile = JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevcustomfields'.DS.'customfields'.DS.'templates'.DS.$template;
				if(file_exists($xmlfile)){
					$xml = simplexml_load_file($xmlfile);
					$jevCf = $xml->xpath('//fields/fieldset/field');
				}
			}
		}

		$tabs = acymailing_get('helper.acytabs');
		echo $tabs->startPane('jevents_tab');
		echo $tabs->startPanel(acymailing_translation('JOOMEXT_EVENT'), 'jevents_event');

		?>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyEvent(eventid, rowClass){
				var tmp = selectedContents.indexOf(eventid)
				if(tmp != -1){
					window.document.getElementById('content' + eventid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + eventid).className = 'selectedrow';
					selectedContents.push(eventid);
				}
				updateEventTag();
			}

			function updateEventTag(){
				var tag = '';
				var otherinfo = '';
				var already = 0;

				for(var i = 0; i < document.adminForm.contenttype.length; i++){
					if(document.adminForm.contenttype[i].checked){
						selectedtype = document.adminForm.contenttype[i].value;
						otherinfo += '|type:' + document.adminForm.contenttype[i].value;
					}
				}

				if(document.adminForm.customfields){
					for(var i = 0; i < document.adminForm.customfields.length; i++){
						if(document.adminForm.customfields[i].checked){
							if(already == 0){
								otherinfo += '| custom:' + document.adminForm.customfields[i].value;
								already++;
							}else{
								otherinfo += ', ' + document.adminForm.customfields[i].value;
							}
						}
					}
				}

				for(var i = 0; i < document.adminForm.clickable.length; i++){
					if(document.adminForm.clickable[i].checked && document.adminForm.clickable[i].value != 0){
						otherinfo += '| clickable';
					}
				}

				if(document.adminForm.pluginFields){
					for(var i = 0; i < document.adminForm.pluginFields.length; i++){
						if(document.adminForm.pluginFields[i].checked){
							otherinfo += '| pluginFields:' + document.adminForm.pluginFields[i].value;
						}
					}
				}

				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked && document.adminForm.readmore[i].value != 0){
						otherinfo += '| readmore';
					}
				}

				for(var i = 0; i < document.adminForm.pict.length; i++){
					if(document.adminForm.pict[i].checked){
						otherinfo += '| pict:' + document.adminForm.pict[i].value;
						if(document.adminForm.pict[i].value == 'resized'){
							document.getElementById('pictsize').style.display = '';
							if(document.adminForm.pictwidth.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidth.value;
							if(document.adminForm.pictheight.value) otherinfo += '| maxheight:' + document.adminForm.pictheight.value;
						}else{
							document.getElementById('pictsize').style.display = 'none';
						}
					}
				}

				if(window.document.getElementById('jflang') && window.document.getElementById('jflang').value != ''){
					otherinfo += '| lang:';
					otherinfo += window.document.getElementById('jflang').value;
				}

				if(document.adminForm.wrap.value && document.adminForm.wrap.value != 0 && !isNaN(document.adminForm.wrap.value)){
					otherinfo += "| wrap:" + document.adminForm.wrap.value;
				}

				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{jevents:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}
			//-->
		</script>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td>
						<?php echo acymailing_translation('DISPLAY'); ?>
					</td>
					<td colspan="2">
						<?php echo acymailing_radio($contenttype, 'contenttype', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->contenttype); ?>
					</td>
					<td>
						<?php $jflanguages = acymailing_get('type.jflanguages');
						$jflanguages->onclick = 'onchange="updateEventTag();"';
						echo $jflanguages->display('lang', $pageInfo->lang); ?>
					</td>
				</tr>
				<?php
				//handle custom fields
				if(!empty($jevCf)){
					echo '<tr><td>'.acymailing_translation('EXTRA_FIELDS').'</td>';
					$cpt = 1;
					foreach($jevCf as $oneParam){
						if(!empty($oneParam->attributes()->name) && !empty($oneParam->attributes()->label)){
							if($cpt == 4){
								$cpt = 1;
								echo '</tr><tr><td/>';
							}
							echo '<td><input value="'.$oneParam->attributes()->name.'" name="customfields" id="cf_'.$oneParam->attributes()->name.'" type="checkbox" onclick="updateEventTag();" /> ';
							echo '<label for="cf_'.$oneParam->attributes()->name.'">'.$oneParam->attributes()->label.'</label></td>';
							$cpt++;
						}
					}
					while($cpt != 4){
						$cpt++;
						echo '<td/>';
					}
					echo '</tr>';
				}
				?>
				<tr>
					<td><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->readmore); ?>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateEventTag();"/>'); ?></td>
				</tr>

				<tr>
					<td valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td valign="top"><?php echo acymailing_radio($picts, 'pict', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->pict); ?>
						<span id="pictsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?>><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidth" type="text" onchange="updateEventTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
						x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheight" type="text" onchange="updateEventTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
					</span>
					</td>
					<td valign="top"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td valign="top"><?php echo acymailing_radio($choice, 'clickable', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->clickable); ?></td>
				</tr>
				<?php if((ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles'.DS.'jevfiles.php')) || (!ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles.php'))){ ?>
					<tr>
						<td><?php echo acymailing_translation('ACY_FILES'); ?></td>
						<td colspan="3"><?php echo acymailing_radio($choice, 'pluginFields', 'size="1" onclick="updateEventTag();"', 'value', 'text', $pageInfo->pluginFields); ?>
					</tr>
				<?php } ?>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table_options">
				<tr>
					<td width="100%">
						<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
						<button class="acymailing_button_grey" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
						<button class="acymailing_button_grey" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
					</td>
				</tr>
			</table>

			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
				<tr>
					<th/>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'detail.summary', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('ACY_DESCRIPTION'), 'detail.description', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('FIELD_DATE'), 'rpt.startrepeat', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title titleid">
						<?php echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'rpt.rp_id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="5">
						<?php echo $pagination->getListFooter(); ?>
						<?php echo $pagination->getResultsCounter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php
				$k = 0;
				for($i = 0, $a = count($rows); $i < $a; $i++){
					$row =& $rows[$i];
					?>
					<tr id="content<?php echo $row->rp_id; ?>" class="<?php echo "row$k"; ?>" onclick="applyEvent(<?php echo $row->rp_id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
							<?php echo $row->summary; ?>
						</td>
						<td>
							<?php
							$tag = new stdClass();
							$tag->wrap = 200;
							echo acymailing_absoluteURL($this->acypluginsHelper->wrapText($row->description, $tag));
							if(!empty($row->location)) echo '<br /><b>'.$row->location.'</b>';
							?>
						</td>
						<td align="center">
							<?php echo acymailing_getDate(acymailing_getTime($row->startrepeat), acymailing_translation('DATE_FORMAT_LC')); ?>
						</td>
						<td align="center">
							<?php echo $row->rp_id; ?>
						</td>
					</tr>
					<?php
					$k = 1 - $k;
				}
				?>
				</tbody>
			</table>
		</div>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>
		<?php
		echo $tabs->endPanel();
		echo $tabs->startPanel(acymailing_translation('UPCOMING_EVENTS'), 'jevents_auto');
		$type = acymailing_getVar('string', 'type');

		if(!ACYMAILING_J16){
			$categories = acymailing_loadObjectList('SELECT a.*,b.* FROM `#__jevents_categories` as a LEFT JOIN `#__categories` as b ON a.id = b.id', 'id');
		}else{
			$categories = acymailing_loadObjectList("SELECT b.* FROM `#__categories` as b WHERE b.extension = 'com_jevents' AND b.published >= 0", 'id');
		}

		?>
		<br style="font-size:1px"/>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedCat = new Array();
			function applyAutoEvent(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('event_cat' + catid).className == 'selectedrow'){
						window.document.getElementById('event_catall').className = rowClass;
					}else{
						window.document.getElementById('event_cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('event_cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('event_catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('event_cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('event_cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'event';
					}
				}
				updateTag();
			}

			function updateTag(){
				var already = 0;
				var tag = '{autojevents:';
				for(var icat in selectedCat){
					if(selectedCat[icat] == 'event'){
						tag += icat + '-';
					}
				}

				if(document.adminForm.customfieldsauto){
					for(var i = 0; i < document.adminForm.customfieldsauto.length; i++){
						if(document.adminForm.customfieldsauto[i].checked){
							if(already == 0){
								tag += '| custom:' + document.adminForm.customfieldsauto[i].value;
								already++;
							}else{
								tag += ', ' + document.adminForm.customfieldsauto[i].value;
							}
						}
					}
				}

				for(var i = 0; i < document.adminForm.clickableauto.length; i++){
					if(document.adminForm.clickableauto[i].checked && document.adminForm.clickableauto[i].value != 0){
						tag += '| clickable';
					}
				}

				if(document.adminForm.pluginFieldsauto){
					for(var i = 0; i < document.adminForm.pluginFieldsauto.length; i++){
						if(document.adminForm.pluginFieldsauto[i].checked){
							tag += '| pluginFields:' + document.adminForm.pluginFieldsauto[i].value;
						}
					}
				}

				for(var i = 0; i < document.adminForm.autoreadmore.length; i++){
					if(document.adminForm.autoreadmore[i].checked && document.adminForm.autoreadmore[i].value != 0){
						tag += '| readmore';
					}
				}

				for(var i = 0; i < document.adminForm.contenttypeauto.length; i++){
					if(document.adminForm.contenttypeauto[i].checked){
						selectedtype = document.adminForm.contenttypeauto[i].value;
						tag += '| type:' + document.adminForm.contenttypeauto[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.pictauto.length; i++){
					if(document.adminForm.pictauto[i].checked){
						tag += '| pict:' + document.adminForm.pictauto[i].value;
						if(document.adminForm.pictauto[i].value == 'resized'){
							document.getElementById('pictsizeauto').style.display = '';
							if(document.adminForm.pictwidthauto.value) tag += '| maxwidth:' + document.adminForm.pictwidthauto.value;
							if(document.adminForm.pictheightauto.value) tag += '| maxheight:' + document.adminForm.pictheightauto.value;
						}else{
							document.getElementById('pictsizeauto').style.display = 'none';
						}
					}
				}


				if(window.document.getElementById('jflangauto') && window.document.getElementById('jflangauto').value != ''){
					tag += '| lang:' + window.document.getElementById('jflangauto').value;
				}

				if(document.adminForm.contentorder.value){
					tag += "| order:" + document.adminForm.contentorder.value + "," + document.adminForm.contentorderdir.value;
				}

				if(document.adminForm.cols.value){
					tag += '| cols:' + document.adminForm.cols.value;
				}
				if(document.adminForm.autowrap.value && document.adminForm.autowrap.value != 0){
					tag += "| wrap:" + document.adminForm.autowrap.value;
				}
				if(document.adminForm.min_article && document.adminForm.min_article.value && document.adminForm.min_article.value != 0){
					tag += '| min:' + document.adminForm.min_article.value;
				}
				if(document.adminForm.max_article.value && document.adminForm.max_article.value != 0){
					tag += '| max:' + document.adminForm.max_article.value;
				}
				if(document.adminForm.mindelayevent && document.adminForm.mindelayevent.value && document.adminForm.mindelayevent.value != 0){
					tag += '| mindelay:' + document.adminForm.mindelayevent.value;
				}
				if(document.adminForm.delayevent && document.adminForm.delayevent.value && document.adminForm.delayevent.value != 0){
					tag += '| delay:' + document.adminForm.delayevent.value;
				}
				if(document.adminForm.from_date && document.adminForm.from_date.value){
					tag += '| from:' + document.adminForm.from_date.value;
				}
				if(document.adminForm.to_date && document.adminForm.to_date.value){
					tag += '| to:' + document.adminForm.to_date.value;
				}
				<?php if(file_exists(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_jevlocations')){ ?>
				if(document.adminForm.location && document.adminForm.location.value && document.adminForm.location.value != 0){
					tag += '| location:' + document.adminForm.location.value;
				}
				if(document.adminForm.city && document.adminForm.city.value && document.adminForm.city.value != 0){
					tag += '| city:' + document.adminForm.city.value;
				}
				if(document.adminForm.state && document.adminForm.state.value && document.adminForm.state.value != 0){
					tag += '| state:' + document.adminForm.state.value;
				}
				if(document.adminForm.country && document.adminForm.country.value && document.adminForm.country.value != 0){
					tag += '| country:' + document.adminForm.country.value;
				}
				<?php } ?>
				tag += '}';

				setTag(tag);
			}
			//-->
		</script>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td>
						<?php echo acymailing_translation('DISPLAY'); ?>
					</td>
					<td colspan="2">
						<?php echo acymailing_radio($contenttype, 'contenttypeauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->contenttypeauto); ?>
					</td>
					<td>
						<?php $jflanguages = acymailing_get('type.jflanguages');
						$jflanguages->onclick = 'onchange="updateTag();"';
						$jflanguages->id = 'jflangauto';
						echo $jflanguages->display('langauto', $pageInfo->langauto); ?>
					</td>
				</tr>
				<?php
				//handle custom fields
				if(!empty($jevCf)){
					echo '<tr><td>'.acymailing_translation('EXTRA_FIELDS').'</td>';
					$cpt = 1;
					foreach($jevCf as $oneParam){
						if(!empty($oneParam->attributes()->name) && !empty($oneParam->attributes()->label)){
							if($cpt == 4){
								$cpt = 1;
								echo '</tr><tr><td/>';
							}
							echo '<td><input value="'.$oneParam->attributes()->name.'" name="customfieldsauto" id="cfauto_'.$oneParam->attributes()->name.'" type="checkbox" onclick="updateTag();" /> ';
							echo '<label for="cfauto_'.$oneParam->attributes()->name.'">'.$oneParam->attributes()->label.'</label></td>';
							$cpt++;
						}
					}
					while($cpt != 4){
						$cpt++;
						echo '<td/>';
					}
					echo '</tr>';
				}
				?>
				<tr>
					<td><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td><?php echo acymailing_radio($choice, 'autoreadmore', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->autoreadmore); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="autowrap" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
				</tr>
				<tr>
					<td valign="top" nowrap="nowrap"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td valign="top" nowrap="nowrap"><?php echo acymailing_radio($picts, 'pictauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->autopict); ?>
						<span id="pictsizeauto" <?php if($pageInfo->autopict != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidthauto" type="text" onchange="updateTag();" value="<?php echo $this->params->get('maxwidth', '150'); ?>" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheightauto" type="text" onchange="updateTag();" value="<?php echo $this->params->get('maxheight', '150'); ?>" style="width:30px;"/>
				</span>
					</td>
					<td valign="top"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td valign="top"><?php echo acymailing_radio($choice, 'clickableauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
				</tr>
				<?php if((ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles'.DS.'jevfiles.php')) || (!ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles.php'))){ ?>
					<tr>
						<td><?php echo acymailing_translation('ACY_FILES'); ?></td>
						<td colspan="3"><?php echo acymailing_radio($choice, 'pluginFieldsauto', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pluginFieldsauto); ?>
					</tr>
				<?php } ?>
				<tr>
					<td>
						<?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td>
						<input type="text" name="max_article" style="width:50px" value="20" onchange="updateTag();"/>
					</td>
					<td>
						<?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td>
						<?php echo acymailing_select($column, 'cols', 'size="1" style="width:50px" onchange="updateTag();"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
				<tr>
					<?php if($type == 'autonews'){ ?>
						<td>
							<?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td>
						<td>
							<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTag();"/>
						</td>
					<?php } ?>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('ACY_ORDER'); ?>
					</td>
					<td nowrap="nowrap"<?php if($type != 'autonews'){
						echo ' colspan="3"';
					} ?>>
						<?php
						$values = array('rp_id' => 'ACY_ID', 'startrepeat' => 'JEV_EVENT_STARTDATE', 'endrepeat' => 'JEV_EVENT_ENDDATE', 'summary' => 'FIELD_TITLE');
						echo $this->acypluginsHelper->getOrderingField($values, $pageInfo->contentorder, $pageInfo->contentorderdir, 'updateTag');
						?>
					</td>
				</tr>
				<?php if($type == 'autonews'){ ?>
					<tr>
						<td>
							<?php echo acymailing_translation('ACY_FROM_DATE'); ?>
						</td>
						<td>
							<?php $delayType = acymailing_get('type.delay');
							$delayType->onChange = "updateTag();";
							echo $delayType->display('mindelayevent', 0, 3); ?>
						</td>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('ACY_TO_DATE'); ?>
						</td>
						<td nowrap="nowrap">
							<?php $delayType = acymailing_get('type.delay');
							$delayType->onChange = "updateTag();";
							echo $delayType->display('delayevent', 7776000, 3); ?>
						</td>
					</tr>
				<?php }else{ ?>
					<tr>
						<td>
							<?php echo acymailing_translation('ACY_FROM_DATE'); ?>
						</td>
						<td>
							<?php echo acymailing_calendar('', 'from_date', 'from_date', '%Y-%m-%d', array('style' => 'width:80px', 'onchange' => 'updateTag();')); ?>
						</td>
						<td>
							<?php echo acymailing_translation('ACY_TO_DATE'); ?>
						</td>
						<td>
							<?php echo acymailing_calendar('', 'to_date', 'to_date', '%Y-%m-%d', array('style' => 'width:80px', 'onchange' => 'updateTag();')); ?>
						</td>
					</tr>
				<?php } ?>
			</table>
		</div>
		<?php
		if(file_exists(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_jevlocations')){
			//handle locations
			//We get all locations
			$location = array();
			$locs = acymailing_loadObjectList('SELECT loc_id, title, city, state, country FROM #__jev_locations');
			$location[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
			foreach($locs as $oneLoc){
				$location[] = acymailing_selectOption($oneLoc->loc_id, $oneLoc->title);
			}

			if(!empty($locs)){
				foreach($locs as $oneResult){
					if(!empty($oneResult->city)) $allCities[] = $oneResult->city;
					if(!empty($oneResult->state)) $allStates[] = $oneResult->state;
					if(!empty($oneResult->country)) $allCountries[] = $oneResult->country;
				}
				$cities = array_unique($allCities);
				$states = array_unique($allStates);
				$countries = array_unique($allCountries);
				$citiesToDisplay[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
				$statesToDisplay[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
				$countriesToDisplay[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
				foreach($cities as $oneCity){
					$citiesToDisplay[] = acymailing_selectOption($oneCity, $oneCity);
				}
				foreach($states as $oneState){
					$statesToDisplay[] = acymailing_selectOption($oneState, $oneState);
				}
				foreach($countries as $oneCountry){
					$countriesToDisplay[] = acymailing_selectOption($oneCountry, $oneCountry);
				}
			?>
			<div class="onelineblockoptions">
				<table class="acymailing_table" cellpadding="1" width="100%">
					<tr>
						<th style="text-align: left" colspan="6"><?php echo acymailing_translation('ACY_LOCATION') ?></th>
					</tr>
					<tr>
						<td width="16%">
							<?php echo acymailing_translation('COUNTRYCAPTION'); ?>
						</td>
						<td>
							<?php echo acymailing_select($countriesToDisplay, 'country', 'size="1" style="width:150px" onchange="updateTag();"', 'value', 'text', $pageInfo->country); ?>
						</td>
						<td>
							<?php echo acymailing_translation('STATECAPTION'); ?>
						</td>
						<td>
							<?php echo acymailing_select($statesToDisplay, 'state', 'size="1" style="width:150px" onchange="updateTag();"', 'value', 'text', $pageInfo->state); ?>
						</td>
						<td>
							<?php echo acymailing_translation('CITYCAPTION'); ?>
						</td>
						<td>
							<?php echo acymailing_select($citiesToDisplay, 'city', 'size="1" style="width:150px" onchange="updateTag();"', 'value', 'text', $pageInfo->city); ?>
						</td>
					</tr>
					<tr>
						<td colspan="3" align="right">
							<span style="float: left"><?php echo ucfirst(acymailing_translation('ACY_OR')) ?></span>
							<span style="margin-right: 30px;">
							<?php echo acymailing_translation('ACY_LOCATION'); ?>
							</span>
						</td>
						<td colspan="3">
							<?php echo acymailing_select($location, 'location', 'size="1" style="width:150px" onchange="updateTag();"', 'value', 'text', $pageInfo->location); ?>
						</td>
					</tr>
				</table>
			</div>
		<?php
			}
		} ?>
		<div class="onelineblockoptions">
			<table class="acymailing_table" cellpadding="1" width="100%">
				<?php $k = 0; ?>
				<tr id="event_catall" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"/>
					<td>
						<?php
						echo acymailing_translation('ACY_ALL');
						?>
					</td>
				</tr>
				<?php
				foreach($categories as $oneCat){ ?>
					<tr id="event_cat<?php echo $oneCat->id ?>" class="<?php echo "row$k"; ?>" onclick="applyAutoEvent(<?php echo $oneCat->id ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"/>
						<td>
							<?php
							if(!empty($oneCat->parent_id) && !empty($categories[$oneCat->parent_id])) echo $categories[$oneCat->parent_id]->title.' => ';
							echo $oneCat->title;
							?>
						</td>
					</tr>
					<?php $k = 1 - $k;
				} ?>
			</table>
		</div>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
		//End of the function
	}

	function acymailing_replacetags(&$email, $send = true){
		$this->_replaceAuto($email);
		$this->_replaceEvents($email);
	}

	function _replaceEvents(&$email){
		//load the tags
		$tags = $this->acypluginsHelper->extractTags($email, 'jevents');

		if(empty($tags)) return;

		acymailing_loadLanguageFile('com_jevents', JPATH_SITE);

		$this->newslanguage = new stdClass();
		if(!empty($email->language)){
			$this->newslanguage = acymailing_loadObject('SELECT lang_id, lang_code FROM #__languages WHERE sef = '.acymailing_escapeDB($email->language).' LIMIT 1');
		}

		//We will need the mailer class as well
		$this->mailerHelper = acymailing_get('helper.mailer');
		if(!ACYMAILING_J16){
			$config = JFactory::getConfig();
			$this->timeoffset = $config->getValue('config.offset');
		}

		//Set the read more link:
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		if((ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles'.DS.'jevfiles.php')) || (!ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles.php'))){
			$JEVplugin = JPluginHelper::getPlugin('jevents', 'jevfiles');
			$JEVparams = new acyParameter($JEVplugin->params);
			$imagesFolder = JComponentHelper::getParams('com_media')->get('image_path', 'images');
			$this->imgFolder = ACYMAILING_LIVE.$imagesFolder.'/'.trim($JEVparams->get('folder', 'jevents'), '/').'/';
		}

		$tagsReplaced = array();
		foreach($tags as $i => $params){
			if(isset($tagsReplaced[$i])) continue;
			$tagsReplaced[$i] = $this->_replaceEvent($tags[$i]);
		}

		$this->acypluginsHelper->replaceTags($email, $tagsReplaced, true);
	}

	function _replaceEvent(&$tag){
		if(empty($tag->itemid)){
			$tag->itemid = $this->params->get('itemid', 0);
		}
		//1 : Load the informations of the product...
		$query = 'SELECT rpt.*,detail.*,cat.title as category, ev.catid, ev.uid FROM `#__jevents_repetition` as rpt ';
		$query .= ' JOIN `#__jevents_vevent` as ev ON rpt.eventid = ev.ev_id ';
		$query .= ' JOIN `#__jevents_vevdetail` AS detail ON rpt.eventdetail_id = detail.evdet_id ';
		$query .= 'LEFT JOIN `#__categories` as cat ON cat.id = ev.catid ';
		$query .= 'WHERE rpt.rp_id = '.intval($tag->id).' LIMIT 1';

		$event = acymailing_loadObject($query);

		//We just loaded the article but we may need to translate it depending on tag->lang...
		if(empty($tag->lang) && !empty($this->newslanguage) && !empty($this->newslanguage->lang_code)) $tag->lang = $this->newslanguage->lang_code.','.$this->newslanguage->lang_id;

		$this->acypluginsHelper->translateItem($event, $tag, 'jevents_vevdetail', $event->evdet_id);

		if(empty($event)){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('The event "'.$tag->id.'" could not be loaded', 'notice');
			return '';
		}

		//Do we need to load the location from somewhere else?
		if(file_exists(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_jevlocations') && !empty($event->location) && is_numeric($event->location)){
			$query = 'SELECT title,street,postcode,city,state,country FROM `#__jev_locations` WHERE loc_id = '.intval($event->location);
			$location = acymailing_loadObject($query);
			if(!empty($location)){
				foreach($location as $prop => $value){
					$event->$prop = $value;
				}
				$event->location = $location->title;
			}
		}

		$varFields = array();
		foreach($event as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}
		if(ACYMAILING_J16){
			$startdate = acymailing_date($event->startrepeat, acymailing_translation('DATE_FORMAT_LC'), null);
			$enddate = acymailing_date($event->endrepeat, acymailing_translation('DATE_FORMAT_LC'), null);
		}else{
			$startdate = acymailing_date(strtotime($event->startrepeat) - date('Z'), acymailing_translation('DATE_FORMAT_LC'), $this->timeoffset);
			$enddate = acymailing_date(strtotime($event->endrepeat) - date('Z'), acymailing_translation('DATE_FORMAT_LC'), $this->timeoffset);
		}
		$starttime = substr($event->startrepeat, 11, 5);
		$endtime = substr($event->endrepeat, 11, 5);

		if($starttime == '00:00'){
			$starttime = '';
			$endtime = '';
		}elseif($event->noendtime){
			$endtime = '';
		}

		$cfg = JComponentHelper::getParams("com_jevents");
		$useStdTime = $cfg->get('com_calUseStdTime');

		if(!empty($useStdTime)){
			if(!empty($starttime)) $starttime = strtolower(strftime("%#I:%M%p", strtotime($event->startrepeat)));
			if(!empty($endtime)) $endtime = strtolower(strftime("%#I:%M%p", strtotime($event->endrepeat)));
		}

		$date = $startdate;
		if(!empty($starttime)) $date .= ' '.$starttime;
		if($startdate == $enddate){
			if(!empty($endtime)) $date .= ' - '.$endtime;
		}else{
			$date .= ' - '.$enddate;
			if(!empty($endtime)) $date .= ' '.$endtime;
		}
		$varFields['{date}'] = $date;


		$link = ACYMAILING_LIVE.'index.php?option=com_jevents&task=icalrepeat.detail&evid='.intval($event->rp_id);
		if(!empty($tag->itemid)){
			$link .= '&Itemid='.intval($tag->itemid);
		}else{
			$areaCats = array();
			$areaCats[] = $event->catid;
			$cats = acymailing_loadObjectList('SELECT id, parent_id FROM #__categories', 'id');
			$position = $event->catid;
			while($cats[$position]->parent_id != 0){
				$areaCats[] = $cats[$position]->parent_id;
				$position = $cats[$position]->parent_id;
			}
			$menuId = '';
			$menus = acymailing_loadObjectList('SELECT id, params FROM #__menu WHERE link LIKE "index.php?option=com_jevents&view=cat&layout=listevents"');
			if(!empty($menus)){
				foreach($menus as $i => $menu){
					$menus[$i]->params = json_decode($menus[$i]->params);
					if(empty($menus[$i]->params->catidnew)) continue;
					foreach($menus[$i]->params->catidnew as $oneCatid){
						if(in_array($oneCatid, $areaCats)){
							$menuId = $menus[$i]->id;
							break;
						}
					}
					if($menuId != '') break;
				}
			}

			if(!empty($menuId)){
				$link .= '&Itemid='.intval($menuId);
			}else{
				$summary = str_replace('-', ' ', $event->summary);
				$summary = trim(strtolower($summary));
				$summary = preg_replace('/(\s|[^A-Za-z0-9\-])+/', '-', $summary);
				$summary = trim($summary, '-');
				$time = explode('-', substr($event->startrepeat, 0, strpos($event->startrepeat, ' ')));
				$link = 'index.php?option=com_jevents&task=icalrepeat.detail&evid='.intval($event->rp_id).'&year='.intval($time[0]).'&month='.intval($time[1]).'&day='.intval($time[2]).'&title='.$summary.'&uid='.$event->uid;
			}
		}
		if(!empty($tag->lang)) $link .= '&lang='.substr($tag->lang, 0, strpos($tag->lang, ','));
		$varFields['{link}'] = $link;

		$result = '<table cellspacing="0" cellpadding="0" border="0" width="100%">';

		$event->summary = '<h2 class="acymailing_title">'.$event->summary.'</h2>';
		if(!empty($tag->clickable)) $event->summary = '<a target="_blank" href="'.$link.'">'.$event->summary.'</a>';
		$result .= '<tr><td>'.$event->summary.'</td></tr>';

		$event->description = $this->acypluginsHelper->wrapText($event->description, $tag);
		$varFields['{wrapeddescription}'] = $event->description;

		if($tag->type == 'full'){
			$result .= '<tr><td><span class="eventdate">'.$date.'</span></td></tr>';

			$result .= '<tr><td class="eventdescription">'.$event->description.'</td></tr>';
			if(!empty($event->location)) $result .= '<tr><td><span class="eventlocation">'.acymailing_translation('JEV_EVENT_ADRESSE').' : '.$event->location.'</span></td></tr>';

			//handle custom fields
			if(!empty($tag->custom)){
				//extract wanted fields
				$tag->custom = explode(',', $tag->custom);
				foreach($tag->custom as $i => $oneField){
					$tag->custom[$i] = trim($oneField);
				}

				//first retrieve which template is selected in jevents plugin for custom fields
				$jevCFParams = acymailing_loadObject('SELECT params FROM #__extensions WHERE element = "jevcustomfields"');
				if(!empty($jevCFParams->params)) $template = json_decode($jevCFParams->params)->template;

				//load available custom fields
				if(!empty($template)){
					$xmlfile = JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevcustomfields'.DS.'customfields'.DS.'templates'.DS.$template;
					if(file_exists($xmlfile)){
						$xml = simplexml_load_file($xmlfile);
						$jevCf = $xml->xpath('//fields/fieldset/field');
						$customFields = array();
						foreach($jevCf as $i => $oneField){
							$name = (string)$oneField->attributes()->name;
							$customFields[$name] = new stdClass();
							$customFields[$name]->label = (string)$oneField->attributes()->label;
							$customFields[$name]->type = (string)$oneField->attributes()->type;

							if(empty($oneField->option)) continue;

							$customFields[$name]->options = array();
							foreach($oneField->option as $oneOption){
								$customFields[$name]->options[] = $oneOption;
							}
						}
					}
				}

				//load values
				$customVDB = acymailing_loadObjectList('SELECT name, value FROM #__jev_customfields WHERE evdet_id = '.intval($event->evdet_id));
				foreach($customVDB as $oneField){
					$varFields['{'.$oneField->name.'}'] = $oneField->value;
				}

				$customValues = array();
				foreach($customVDB as $oneCustomValue){
					$customValues[$oneCustomValue->name] = $oneCustomValue->value;
				}

				//display custom fields
				if(!empty($customValues)){
					foreach($tag->custom as $oneCustom){
						$label = (!empty($customFields[$oneCustom]->label)) ? $customFields[$oneCustom]->label : $oneCustom;
						//i.e. "if this fields have different possible values"
						if(!empty($customFields[$oneCustom]->options)){
							$multipleValues = explode(',', $customValues[$oneCustom]);

							//all this block is made to replace the keys by the label in the field's values
							$orderedValues = array();
							foreach($multipleValues as $oneValue){
								$orderedValues[$oneValue] = $oneValue;
							}

							$possibleValues = array();
							foreach($customFields[$oneCustom]->options as $oneOption){
								$possibleValues[(string)$oneOption->attributes()->value] = (string)$oneOption;
							}

							foreach($orderedValues as $key => $j){
								$orderedValues[$key] = $possibleValues[$key];
							}
							$customValues[$oneCustom] = implode(', ', $orderedValues);
						}elseif($customFields[$oneCustom]->type == 'jevrurl'){ //we want a link !
							$customValues[$oneCustom] = '<a href="'.$customValues[$oneCustom].'">'.$customValues[$oneCustom].'</a>';
						}elseif($customFields[$oneCustom]->type == 'jevrcalendar'){//comprehensible display
							$customValues[$oneCustom] = acymailing_getDate(acymailing_getTime($customValues[$oneCustom]), acymailing_translation('DATE_FORMAT_LC'));
						}elseif($customFields[$oneCustom]->type == 'jevruser'){//we do not want the user id but its name
							$user = acymailing_loadResultArray('SELECT name FROM #__users WHERE id = '.intval($customValues[$oneCustom]));
							$customValues[$oneCustom] = (empty($user[0])) ? $customValues[$oneCustom] : $user[0];
						}elseif($customFields[$oneCustom]->type == 'jevcfboolean'){
							$customValues[$oneCustom] = empty($customValues[$oneCustom]) ? acymailing_translation('JOOMEXT_NO') : acymailing_translation('JOOMEXT_YES');
						}

						if(empty($customValues[$oneCustom]) && in_array($customFields[$oneCustom]->type, array('jevcfuser', 'jevcfyoutube', 'jevcfupdatable', 'jevcfdblist', 'jevcftext', 'jevcfimage', 'jevcffile', 'jevcfhtml', 'jevcfeventflag', 'jevcfnotes'))){
							unset($customValues[$oneCustom]);
						}

						if(isset($customValues[$oneCustom])) $result .= '<tr><td><span class="jev_cf_"'.$oneCustom.'>'.$label.' : '.$customValues[$oneCustom].'</span></td></tr>';
					}
				}
			}
			if(!empty($event->contact)) $result .= '<tr><td><span class="eventcontact">'.$event->contact.'</span></td></tr>';
			if(!empty($event->extra_info)) $result .= '<tr><td><span class="eventextra">'.$event->extra_info.'</span></td></tr>';
		}

		if((ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles'.DS.'jevfiles.php')) || (!ACYMAILING_J16 && file_exists(JPATH_SITE.DS.'plugins'.DS.'jevents'.DS.'jevfiles.php'))){

			if(in_array(acymailing_getPrefix().'jev_files_combined', acymailing_getTableList())){
				$filesRow = acymailing_loadObject('SELECT * FROM `#__jev_files_combined` WHERE ev_id = (SELECT eventid FROM #__jevents_repetition WHERE rp_id = '.intval($tag->id).')');

				if(!empty($filesRow)){
					for($i = 1; $i < 30; $i++){
						if(!empty($filesRow->{'imagename'.$i})){
							$varFields['{imgpath'.$i.'}'] = $this->imgFolder.$filesRow->{'imagename'.$i};
							$result .= '<tr><td><a target="_blank" href="'.$varFields['{imgpath'.$i.'}'].'"><img src="'.$varFields['{imgpath'.$i.'}'].'"/></a></td></tr>';
						}

						if(!empty($filesRow->{'filename'.$i})){
							$varFields['{filepath'.$i.'}'] = $this->imgFolder.$filesRow->{'filename'.$i};
							if(!empty($tag->pluginFields)) $files[] = '<tr><td><a target="_blank" href="'.$varFields['{filepath'.$i.'}'].'">'.(empty($filesRow->{'filename'.$i}) ? : $filesRow->{'filetitle'.$i}).'</a></td></tr>';
						}
					}
					if(!empty($files)) $result .= implode('', $files);
				}
			}else{
				$files = acymailing_loadObjectList('SELECT * FROM `#__jev_files` WHERE ev_id = (SELECT eventid FROM #__jevents_repetition WHERE rp_id = '.intval($tag->id).') ORDER BY filetype DESC');

				if(!empty($files)){
					foreach($files as $i => $oneFile){
						if(empty($oneFile->filename)) continue;

						$varFields['{imgpath'.$i.'}'] = $this->imgFolder.$oneFile->filename;
						if($oneFile->filetype == 'file'){
							if(!empty($tag->pluginFields)) $result .= '<tr><td><a target="_blank" href="'.$varFields['{imgpath'.$i.'}'].'">'.$oneFile->filetitle.'</a></td></tr>';
						}else{
							$result .= '<tr><td><a target="_blank" href="'.$varFields['{imgpath'.$i.'}'].'"><img src="'.$varFields['{imgpath'.$i.'}'].'"/></a></td></tr>';
						}
					}
				}
			}
		}

		if(!empty($tag->readmore)){
			$readMoreText = empty($this->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : $this->readmore;
			$varFields['{readmore}'] = '<a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$readMoreText.'</span></a>';
			$result .= '<tr><td><br />'.$varFields['{readmore}'].'</td></tr>';
		}

		$result = '<div class="acymailing_content" >'.$result.'</table></div>';

		//Check if the template exists...
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'tagjevents.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.'tagjevents.php');
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		$result = $this->acypluginsHelper->removeJS($result);
		$result = $this->acypluginsHelper->managePicts($tag, $result);

		return $result;
	}

	function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);
		if(empty($this->tags)) return;
		$this->acypluginsHelper->replaceTags($email, $this->tags, true);
	}

	function _handleChildrens($parent_id){
		if(empty($this->cats[$parent_id])) return;
		foreach($this->cats[$parent_id] as $cat){
			$this->catvalues[] = $cat->id;
			$this->_handleChildrens($cat->id);
		}
	}

	function acymailing_generateautonews(&$email){
		$time = time();

		//load the tags
		$tags = $this->acypluginsHelper->extractTags($email, 'autojevents');
		$return = new stdClass();
		$return->status = true;
		$return->message = '';
		$this->tags = array();

		if(empty($tags)) return $return;

		$multicat = JComponentHelper::getParams('com_jevents')->get('multicategory', 0);

		foreach($tags as $oneTag => $parameter){
			if(isset($this->tags[$oneTag])) continue;

			$where = array();

			$query = 'SELECT DISTINCT rpt.rp_id FROM `#__jevents_repetition` AS rpt ';
			$query .= ' JOIN `#__jevents_vevent` AS ev ON rpt.eventid = ev.ev_id ';

			if(empty($parameter->order)) $parameter->order = 'startrepeat,ASC';
			if(empty($parameter->from)) $parameter->from = date('Y-m-d H:i:s', $time);

			if(!empty($parameter->id)){
				$allCats = explode('-', $parameter->id);
				array_pop($allCats);
				if(!empty($allCats)){
					acymailing_arrayToInteger($allCats);
					$catToSearch = implode(',', $allCats);
					if($multicat == 1){
						$query .= ' JOIN `#__jevents_catmap` AS cats ON ev.ev_id = cats.evid ';
						$where[] = 'cats.catid IN ('.$catToSearch.')';
					}else{
						$where[] = 'ev.catid IN ('.$catToSearch.')';
					}
				}
			}

			$parameterToSearch = ''; //Always initialize variables in a loop
			if(empty($parameter->location)){//If we don't set the location we check if the country/state/city have been set
				//We check in that order because city is more accurate than state and state is more accurate than country
				//Not empty country
				if(!empty($parameter->country)){
					$parameterToSearch = 'country';
				}
				//state
				if(!empty($parameter->state)){
					$parameterToSearch = 'state';
				}
				//city
				if(!empty($parameter->city)){
					$parameterToSearch = 'city';
				}
			}

			if(isset($parameter->priority) || isset($parameter->location) || isset($parameterToSearch) || strpos($parameter->order, 'summary') !== false){
				$query .= ' JOIN `#__jevents_vevdetail` as evdet ON ev.detail_id = evdet.evdet_id ';
			}
			if(!empty($parameterToSearch)){
				$query .= ' JOIN `#__jev_locations` AS evloc ON evdet.location = evloc.loc_id';
				$where[] = 'evloc.'.$parameterToSearch.' = '.acymailing_escapeDB($parameter->$parameterToSearch);
			}

			if(!empty($parameter->location)){
				$where[] = 'evdet.location = '.intval($parameter->location);
			}

			if(isset($parameter->priority)){
				//we check if the values are integer values
				$parameter->priority = explode(',', $parameter->priority);
				acymailing_arrayToInteger($parameter->priority);
				$where[] = 'evdet.priority IN ('.implode(',', $parameter->priority).')';
			}
			$where[] = 'ev.`state` = 1';

			if((empty($parameter->mindelay) || substr($parameter->mindelay, 0, 1) != '-') && (empty($parameter->delay) || substr($parameter->delay, 0, 1) != '-')) {
				if (!empty($parameter->addcurrent)) {
					//not finished and next events
					$where[] = 'rpt.`endrepeat` >= ' . acymailing_escapeDB($parameter->from);
				} else {
					//not started events
					$where[] = 'rpt.`startrepeat` >= ' . acymailing_escapeDB($parameter->from);
				}
			}

			//should we display only events starting in the sending day ?
			if(!empty($parameter->todaysevent)){
				$where[] = 'rpt.`startrepeat` <= '.acymailing_escapeDB(date('Y-m-d 23:59:59', $time));
			}

			if(!empty($parameter->mindelay)) $where[] = 'rpt.`startrepeat` >= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->mindelay));
			if(!empty($parameter->delay)) $where[] = 'rpt.`startrepeat` <= '.acymailing_escapeDB(date('Y-m-d H:i:s', $time + $parameter->delay));
			if(!empty($parameter->to)) $where[] = 'rpt.`startrepeat` <= '.acymailing_escapeDB($parameter->to);

			//This access level check should be done for J1.5 only
			if(!ACYMAILING_J16){
				if($this->params->get('contentaccess', 'registered') == 'registered'){
					$where[] = 'ev.`access` <= 1';
				}elseif($this->params->get('contentaccess', 'registered') == 'public') $where[] = 'ev.`access` = 0';
			}elseif(isset($parameter->access)){
				//We set it only if the access is defined in the tag
				$where[] = 'ev.`access` = '.intval($parameter->access);
			}

			if(!empty($parameter->created) && !empty($email->params['lastgenerateddate'])){
				$where[] = 'ev.created > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\' AND ev.created < \''.date('Y-m-d H:i:s', $time - date('Z')).'\'';
			}

			$query .= ' WHERE ('.implode(') AND (', $where).')';
			
			$ordering = explode(',', $parameter->order);
			if($ordering[0] == 'rand'){
				$query .= ' ORDER BY rand()';
			}else{
				//We add a second ordering in case of the user choose to order by category.
				$query .= ' ORDER BY '.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
			}

			if(!empty($parameter->max)) $query .= ' LIMIT '.intval($parameter->max);

			$allArticles = acymailing_loadResultArray($query);

			if(!empty($parameter->min) && count($allArticles) < $parameter->min){
				//We won't generate the Newsletter
				$return->status = false;
				$return->message = 'Not enough events for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
			}

			$stringTag = '';
			if(!empty($allArticles)){
				if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'autojevents.php')){
					ob_start();
					require(ACYMAILING_MEDIA.'plugins'.DS.'autojevents.php');
					$stringTag = ob_get_clean();
				}else{
					//we insert the article tag one after the other in a table as they are already sorted
					$arrayElements = array();
					foreach($allArticles as $oneArticleId){
						$stringTag .= '<tr><td>';
						$args = array();
						$args[] = 'jevents:'.$oneArticleId;
						if(isset($parameter->pluginFields)) $args[] = 'pluginFields:'.$parameter->pluginFields;
						if(!empty($parameter->custom)) $args[] = 'custom:'.$parameter->custom;
						if(isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
						if(!empty($parameter->lang)) $args[] = 'lang:'.$parameter->lang;
						if(!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
						if(!empty($parameter->clickable)) $args[] = 'clickable';
						if(isset($parameter->readmore)) $args[] = 'readmore';
						if(!empty($parameter->type)) $args[] = 'type:'.$parameter->type;
						if(!empty($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
						if(!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
						if(!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
						$arrayElements[] = '{'.implode('|', $args).'}';
					}
					$stringTag = $this->acypluginsHelper->getFormattedResult($arrayElements, $parameter);
				}
			}
			$this->tags[$oneTag] = $stringTag;
		}
		return $return;
	}

	function onAcyDisplayFilters(&$type){
		$acyconfig = acymailing_config();
		$type['jevents'] = 'JEvents & RSVP event';
		if(version_compare($acyconfig->get('version'), '4.9.4', '<')) return '<div id="filter__num__jevents">Please update AcyMailing, the Jevents plugin may not work properly with this version</div>';
		if(!$this->component_installed) return '<div id="filter__num__jevents">You must install JEvent and RSVP to use this filter</div>';
		if(!file_exists(JPATH_SITE.DS.'components'.DS.'com_rsvppro')) return '<div id="filter__num__jevents">This filter uses the JEvents\' RSVP plugin, you must install it first</div>';


		acymailing_loadLanguageFile('com_rsvppro', JPATH_ADMINISTRATOR);

		$allEvents = acymailing_loadObjectList('SELECT at.id, evdet.summary 
						FROM #__jevents_vevdetail AS evdet 
						JOIN #__jevents_vevent AS ev ON ev.detail_id = evdet.evdet_id
						JOIN #__jev_attendance AS at ON ev.ev_id = at.ev_id
						ORDER BY evdet.summary ASC');
		$eventList = array();
		if(!empty($allEvents)){
			foreach($allEvents as $oneEvent){
				$eventList[] = acymailing_selectOption($oneEvent->id, $oneEvent->summary);
			}
		}else{
			$eventList[] = acymailing_selectOption('<OPTGROUP>', "No event");
			$eventList[] = acymailing_selectOption('</OPTGROUP>');
		}

		$attend = array();
		$attend[] = acymailing_selectOption('-1', acymailing_translation('RSVP_ALL_REGISTERED_USERS'));
		$attend[] = acymailing_selectOption('1', acymailing_translation('RSVP_IS_CONFIRMED'));
		$attend[] = acymailing_selectOption('0', acymailing_translation('RSVP_PENDING'));

		$return = '<div id="filter__num__jevents">';
		$return .= acymailing_translation('JOOMEXT_EVENT').' '.acymailing_select($eventList, 'filter[__num__][jevents][id]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= '<br />'.acymailing_translation('RSVP_CONFIRMED').' '.acymailing_select($attend, 'filter[__num__][jevents][attending]', 'class="inputbox" onchange="countresults(__num__)" size="1"', 'value', 'text');
		$return .= '<br /><input type="text" name="filter[__num__][jevents][subdateinf]" onclick="displayDatePicker(this,event)" onchange="countresults(__num__)" style="width:70px;" /> < '.acymailing_translation('RSVP_EVENT_REGISTRATION_DATE').' < <input type="text" name="filter[__num__][jevents][subdatesup]" onclick="displayDatePicker(this,event)" onchange="countresults(__num__)" style="width:70px;"/></div>';
		return $return;
	}

	function onAcyProcessFilterCount_jevents(&$query, $filter, $num){
		$this->onAcyProcessFilter_jevents($query, $filter, $num);
		return acymailing_translation_sprintf('SELECTED_USERS', $query->count());
	}

	function onAcyProcessFilter_jevents(&$query, $filter, $num){
		if(!$this->component_installed) return;

		if(!empty($filter['subdateinf'])){
			$filter['subdateinf'] = acymailing_replaceDate($filter['subdateinf']);
			if(!is_numeric($filter['subdateinf'])) $filter['subdateinf'] = strtotime($filter['subdateinf']);
			if(!empty($filter['subdateinf'])) $query->where[] = 'jev_attendees'.$num.'.created > '.acymailing_escapeDB(date('Y-m-d H:i:s', $filter['subdateinf']));
		}

		if(!empty($filter['subdatesup'])){
			$filter['subdatesup'] = acymailing_replaceDate($filter['subdatesup']);
			if(!is_numeric($filter['subdatesup'])) $filter['subdatesup'] = strtotime($filter['subdatesup']);
			if(!empty($filter['subdatesup'])) $query->where[] = 'jev_attendees'.$num.'.created < '.acymailing_escapeDB(date('Y-m-d H:i:s', $filter['subdatesup']));
		}

		$myquery = '#__jev_attendees AS jev_attendees'.$num.' ON jev_attendees'.$num.'.email_address = sub.email OR (jev_attendees'.$num.'.user_id = sub.userid AND jev_attendees'.$num.'.user_id != 0)';
		$query->join[] = $myquery;
		$query->where[] = 'jev_attendees'.$num.'.at_id = '.intval($filter['id']);
		if($filter['attending'] != -1){
			$query->where[] = 'jev_attendees'.$num.'.attendstate = '.intval($filter['attending']);
		}
	}
}//endclass